import { fireEvent } from "../../event";
import { memoize } from "../../../utils/utils";
import { createClient } from "../client";
import { getConfig } from "../config";
import { _getBundleViaList } from "./list";
export function getBundleInventory(bundle) {
    return bundle.sku_list?.sku_list_items?.reduce((inventory, skuListItem) => {
        const quantity = skuListItem.sku?.inventory?.quantity == null
            ? undefined
            : Math.floor(skuListItem.sku?.inventory?.quantity /
                (skuListItem.quantity ?? 1));
        const available = skuListItem.sku.inventory?.available ?? false;
        return {
            available: (inventory.available ?? true) && available,
            levels: inventory.levels,
            quantity: quantity != null &&
                quantity < (inventory.quantity ?? Number.POSITIVE_INFINITY)
                ? quantity
                : inventory.quantity,
        };
    }, {
        available: true,
        levels: [],
    });
}
const getMemoizedBundle = memoize(async (code) => {
    const { id } = (await _getBundleViaList(code)) ?? {};
    if (id == null) {
        return undefined;
    }
    const client = await createClient(getConfig());
    const bundle = (await client.bundles.retrieve(id, {
        include: ["sku_list.sku_list_items.sku"],
    }));
    return {
        ...bundle,
        inventory: getBundleInventory(bundle),
    };
});
export const getBundle = async (code) => {
    const bundle = await getMemoizedBundle(code);
    fireEvent("cl-bundles-getbundle", [code], bundle);
    return bundle;
};
