import { jwtDecode, jwtIsSalesChannel } from "@commercelayer/js-auth";
import { getMfeConfig as mergeConfig, } from "@commercelayer/organization-config";
import merge from "lodash/merge";
import { memoize } from "../../utils/utils";
import { createClient, getAccessToken } from "./client";
const documentationLink = "Read more here: https://commercelayer.github.io/drop-in.js/?path=/docs/getting-started--docs";
const defaultLanguageCode = "en";
export function getConfig() {
    if (!("commercelayerConfig" in window)) {
        throw new Error(`"window.commercelayerConfig" is required.\n${documentationLink}\n`);
    }
    const commercelayerConfig = window.commercelayerConfig;
    if (typeof commercelayerConfig.clientId !== "string") {
        throw new Error(`"window.commercelayerConfig.clientId" is required.\n${documentationLink}\n`);
    }
    if (typeof commercelayerConfig.scope !== "string") {
        throw new Error(`"window.commercelayerConfig.scope" is required.\n${documentationLink}\n`);
    }
    if (![undefined, "none", "all"].includes(commercelayerConfig.debug)) {
        throw new Error(`"window.commercelayerConfig.debug" should one of 'none' (default) or 'all'.\n${documentationLink}\n`);
    }
    if (typeof commercelayerConfig.domain !== "string" ||
        commercelayerConfig.domain === "") {
        commercelayerConfig.domain = "commercelayer.io";
    }
    const debug = commercelayerConfig.debug ?? "none";
    // START-BLOCK // TODO: Remove deprecated properties in the next major version.
    commercelayerConfig.defaultAttributes ??= {};
    commercelayerConfig.defaultAttributes.orders ??= {};
    commercelayerConfig.defaultAttributes.orders.language_code ??=
        commercelayerConfig.languageCode ?? defaultLanguageCode;
    commercelayerConfig.defaultAttributes.orders.return_url ??=
        commercelayerConfig.orderReturnUrl;
    // END-BLOCK
    return {
        ...commercelayerConfig,
        debug,
    };
}
const getOrganization = memoize(async () => {
    const config = getConfig();
    const client = await createClient(config);
    return await client.organization.retrieve({
        fields: {
            organizations: ["config"],
        },
    });
});
export async function getOrganizationConfig(params) {
    const config = getConfig();
    const { accessToken } = await getAccessToken(config);
    const jwt = jwtDecode(accessToken);
    if (!("organization" in jwt.payload)) {
        throw new Error("The access token does not contain the organization information.");
    }
    const organization = await getOrganization();
    const domainPrefix = config.domain === "commercelayer.co" ? ".stg" : "";
    const appEndpoint = `https://:slug${domainPrefix}.commercelayer.app`;
    const defaultConfig = {
        mfe: {
            default: {
                links: {
                    cart: `${appEndpoint}/cart/:order_id?accessToken=:access_token`,
                    checkout: `${appEndpoint}/checkout/:order_id?accessToken=:access_token`,
                    my_account: `${appEndpoint}/my-account?accessToken=:access_token`,
                    identity: `${appEndpoint}/identity`,
                },
            },
        },
    };
    const mergeConfigOptions = {
        jsonConfig: merge({}, defaultConfig, organization.config),
        market: jwtIsSalesChannel(jwt.payload) && jwt.payload.market?.id[0] != null
            ? `market:id:${jwt.payload.market.id[0]}`
            : undefined,
        params: {
            ...params,
            accessToken,
            slug: jwt.payload.organization.slug,
            lang: config.defaultAttributes?.orders?.language_code ?? defaultLanguageCode,
        },
    };
    return mergeConfig(mergeConfigOptions);
}
