import { memoDebounce } from "../utils/debounce";
/**
 * Dispatch a custom event `type`, providing an array of `args` and a `response`.
 *
 * > **To avoid the same event being fired too often**, it implements a basic debouncing practice:
 * multiple identical events (i.e. with the same `args` and `response`) triggered
 * less than **10ms** one from the other are fired only once (the first time).
 */
const _fireEvent = (type, args, response) => {
    document.dispatchEvent(new CustomEvent(type, {
        detail: {
            request: {
                args,
            },
            response,
        },
    }));
};
export const fireEvent = memoDebounce(_fireEvent, 10, {
    leading: true,
    trailing: false,
});
/**
 * Listen to a custom event `type`.
 */
export function listenTo(type, listener, options) {
    document.addEventListener(type, function (evt) {
        void listener.apply(this, [
            evt,
        ]);
    }, options);
}
