import { Host, h, } from "@stencil/core";
import minBy from "lodash/minBy";
import { logUnion, unionToTuple } from "../../utils/validation-helpers";
export class ClAvailabilityInfo {
    host;
    typeList = unionToTuple()("min-days", "max-days", "min-hours", "max-hours", "shipping-method-name", "shipping-method-price");
    /**
     * The type of information to be displayed.
     */
    type;
    /**
     * Displayed text.
     */
    text;
    availabilityUpdateHandler(event) {
        if (this.type === undefined) {
            return;
        }
        const deliveryLeadTimes = event.detail?.sku?.inventory?.levels?.[0]?.delivery_lead_times;
        const deliveryLeadTime = event.detail.rule === "cheapest"
            ? deliveryLeadTimes?.[0]
            : minBy(deliveryLeadTimes, (o) => (o.min.hours + o.max.hours) / 2);
        switch (this.type) {
            case "min-days":
                this.text = deliveryLeadTime?.min.days.toFixed(0);
                break;
            case "min-hours":
                this.text = deliveryLeadTime?.min.hours.toFixed(0);
                break;
            case "max-days":
                this.text = deliveryLeadTime?.max.days.toFixed(0);
                break;
            case "max-hours":
                this.text = deliveryLeadTime?.max.hours.toFixed(0);
                break;
            case "shipping-method-name":
                this.text = deliveryLeadTime?.shipping_method.name;
                break;
            case "shipping-method-price":
                this.text = deliveryLeadTime?.shipping_method.formatted_price_amount;
                break;
        }
    }
    async componentWillLoad() {
        this.logType(this.type);
    }
    async watchTypeHandler(newValue) {
        this.logType(newValue);
    }
    logType(type) {
        logUnion(this.host, "type", type, this.typeList);
    }
    render() {
        return h(Host, { key: '7772932e4423f77db50fd4f7f8a26ab308451837' }, this.text);
    }
    static get is() { return "cl-availability-info"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "| \"min-days\"\n    | \"max-days\"\n    | \"min-hours\"\n    | \"max-hours\"\n    | \"shipping-method-name\"\n    | \"shipping-method-price\"\n    | undefined",
                    "resolved": "\"max-days\" | \"max-hours\" | \"min-days\" | \"min-hours\" | \"shipping-method-name\" | \"shipping-method-price\" | undefined",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The type of information to be displayed."
                },
                "getter": false,
                "setter": false,
                "reflect": true
            }
        };
    }
    static get states() {
        return {
            "text": {}
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "type",
                "methodName": "watchTypeHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "availabilityUpdate",
                "method": "availabilityUpdateHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
