import { Host, h, } from "@stencil/core";
import { logUnion } from "../../utils/validation-helpers";
export class ClAvailabilityStatus {
    host;
    typeList = [
        "available",
        "available-with-info",
        "unavailable",
    ];
    /**
     * The product availability status.
     * It determines the visibility of the inner message.
     */
    type;
    available;
    hasDeliveryLeadTimes;
    availabilityUpdateHandler(event) {
        const hasQuantity = event.detail?.sku?.inventory?.quantity === undefined ||
            event.detail.sku.inventory.quantity - event.detail.cartQuantity > 0;
        this.available =
            event.detail?.sku?.inventory?.available == null
                ? undefined
                : event.detail.sku.inventory.available && hasQuantity;
        this.hasDeliveryLeadTimes =
            (event.detail?.sku?.inventory?.levels?.[0]?.delivery_lead_times?.length ??
                0) > 0;
    }
    async componentWillLoad() {
        this.logType(this.type);
    }
    async watchTypeHandler(newValue) {
        this.logType(newValue);
    }
    logType(type) {
        logUnion(this.host, "type", type, this.typeList);
    }
    render() {
        if ((this.type === "available" && this.available === true) ||
            (this.type === "unavailable" && this.available === false) ||
            (this.type === "available-with-info" &&
                this.available === true &&
                this.hasDeliveryLeadTimes === true)) {
            return h("slot", null);
        }
        return h(Host, { "aria-disabled": "true" });
    }
    static get is() { return "cl-availability-status"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "| \"available\"\n    | \"available-with-info\"\n    | \"unavailable\"\n    | undefined",
                    "resolved": "\"available\" | \"available-with-info\" | \"unavailable\" | undefined",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The product availability status.\nIt determines the visibility of the inner message."
                },
                "getter": false,
                "setter": false,
                "reflect": true
            }
        };
    }
    static get states() {
        return {
            "available": {},
            "hasDeliveryLeadTimes": {}
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "type",
                "methodName": "watchTypeHandler"
            }];
    }
    static get listeners() {
        return [{
                "name": "availabilityUpdate",
                "method": "availabilityUpdateHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
