import { Host, h } from "@stencil/core";
import { getCart } from "../../apis/commercelayer/cart";
import { listenTo } from "../../apis/event";
export class ClCartCount {
    /**
     * Toggle this switch to hide the counter when the cart is empty instead of showing `0`.
     */
    hideWhenEmpty = false;
    count;
    async componentWillLoad() {
        listenTo("cl-cart-update", (event) => {
            void this.updateCart(event.detail.response);
        });
        listenTo("cl-cart-hostedcartupdate", (event) => {
            void this.updateCart(event.detail.response);
        });
        await this.updateCart(await getCart());
    }
    async updateCart(cart) {
        const itemCount = cart?.line_items
            ?.filter((item) => item.item_type === "skus" || item.item_type === "bundles")
            .reduce((count, item) => count + item.quantity, 0);
        // TODO: `skus_count` counts SKUs inside the bundle (this could be a future option).
        // if (cart?.skus_count != null && cart.skus_count > 0) {
        //   this.count = cart.skus_count
        // }
        if (itemCount != null && itemCount > 0) {
            this.count = itemCount;
        }
        else {
            this.count = undefined;
        }
    }
    render() {
        const value = this.count ?? (this.hideWhenEmpty ? undefined : 0);
        return h(Host, { key: '12961918bcb5a998660cb3cc77805ce50dc45a9b', quantity: this.count }, value);
    }
    static get is() { return "cl-cart-count"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "hideWhenEmpty": {
                "type": "boolean",
                "attribute": "hide-when-empty",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "Toggle this switch to hide the counter when the cart is empty instead of showing `0`."
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "false"
            }
        };
    }
    static get states() {
        return {
            "count": {}
        };
    }
}
