import { Host, h, } from "@stencil/core";
import { getCartUrl, isValidUrl } from "../../apis/commercelayer/cart";
import { listenTo } from "../../apis/event";
export class ClCartLink {
    host;
    /**
     * The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;).
     */
    target = "_self";
    minicart = null;
    href;
    componentWillLoad() {
        this.host.setAttribute("cl-hydrated", "");
        this.minicart = this.host.querySelector("cl-cart");
        if (this.minicart !== null) {
            this.minicart.type = "mini";
        }
        listenTo("cl-cart-update", async () => {
            if (this.href === undefined || !(await isValidUrl(this.href))) {
                this.href = await getCartUrl();
            }
        });
        void getCartUrl().then((cartUrl) => {
            this.href = cartUrl;
        });
    }
    async handleClick(event) {
        if (this.href === undefined || !(await isValidUrl(this.href))) {
            event.preventDefault();
            this.href = await getCartUrl(true);
            window.open(this.href, this.target);
        }
    }
    handleKeyDown(event) {
        if (event.key === "Enter" || event.key === " ") {
            this.handleOpenMinicart();
        }
    }
    handleOpenMinicart() {
        if (this.minicart !== null) {
            this.minicart.open = true;
        }
    }
    render() {
        if (this.minicart !== null) {
            return (h(Host, { role: "button", tabindex: "0", onKeyDown: (event) => {
                    this.handleKeyDown(event);
                }, onClick: () => {
                    this.handleOpenMinicart();
                } }, h("slot", null)));
        }
        return (h(Host, { "aria-disabled": this.href !== undefined ? undefined : "true" }, h("a", { target: this.target, href: this.href, onClick: (e) => {
                this.handleClick(e).catch((error) => {
                    throw error;
                });
            } }, h("slot", null))));
    }
    static get is() { return "cl-cart-link"; }
    static get properties() {
        return {
            "target": {
                "type": "string",
                "attribute": "target",
                "mutable": false,
                "complexType": {
                    "original": "\"_self\" | \"_blank\" | \"_parent\" | \"_top\"",
                    "resolved": "\"_blank\" | \"_parent\" | \"_self\" | \"_top\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;)."
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "\"_self\""
            }
        };
    }
    static get states() {
        return {
            "minicart": {},
            "href": {}
        };
    }
    static get elementRef() { return "host"; }
}
