import { Host, h, } from "@stencil/core";
import { getIdentityUrl } from "../../apis/commercelayer/account";
import { logout } from "../../apis/commercelayer/client";
import { isValidUnion, logUnion, unionToTuple } from "../../utils/validation-helpers";
export class ClIdentityLink {
    host;
    typeList = unionToTuple()("login", "signup", "logout");
    /**
     * The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;).
     */
    target = "_self";
    /**
     * The user account access action.
     */
    type;
    /**
     * Enable a custom reset password link visible on the login form page.
     * When set, a "Forgot password?" link will be shown on the right below the Password field.
     */
    resetPasswordUrl;
    /**
     * Your sales channel [scope](https://docs.commercelayer.io/core/authentication#authorization-scopes)
     * (used to restrict the dataset of your application to a market and/or stock location).
     * If specified, it will override the default scope set in the drop-in library configuration.
     * Otherwise, the default scope taken from the drop-in library configuration will be used.
     */
    scope;
    href;
    async componentWillLoad() {
        await this.updateUrl(this.type);
    }
    async watchTypeHandler(newValue) {
        await this.updateUrl(newValue);
    }
    async updateUrl(type) {
        this.href = isValidUnion(type, this.typeList)
            ? await getIdentityUrl(type, this.scope, this.resetPasswordUrl)
            : undefined;
        logUnion(this.host, "type", type, this.typeList);
    }
    render() {
        return (h(Host, { key: '16138f455ae22c86b083044d676e0f613de461a7', "aria-disabled": isValidUnion(this.type, this.typeList) && this.href !== undefined
                ? undefined
                : "true" }, h("a", { key: '24821ad870bc6ebd29e7185c0279fa3335a92906', target: this.target, href: this.href, onClick: (event) => {
                if (this.type === "logout") {
                    event.preventDefault();
                    void logout().then(() => {
                        location.reload();
                    });
                }
            } }, h("slot", { key: 'd95bfbe55a581be24e09bff5886d0dba5543cc27' }))));
    }
    static get is() { return "cl-identity-link"; }
    static get properties() {
        return {
            "target": {
                "type": "string",
                "attribute": "target",
                "mutable": false,
                "complexType": {
                    "original": "\"_self\" | \"_blank\" | \"_parent\" | \"_top\"",
                    "resolved": "\"_blank\" | \"_parent\" | \"_self\" | \"_top\"",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;)."
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "\"_self\""
            },
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "\"login\" | \"signup\" | \"logout\" | undefined",
                    "resolved": "\"login\" | \"logout\" | \"signup\" | undefined",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The user account access action."
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "resetPasswordUrl": {
                "type": "string",
                "attribute": "reset-password-url",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Enable a custom reset password link visible on the login form page.\nWhen set, a \"Forgot password?\" link will be shown on the right below the Password field."
                },
                "getter": false,
                "setter": false,
                "reflect": true
            },
            "scope": {
                "type": "string",
                "attribute": "scope",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Your sales channel [scope](https://docs.commercelayer.io/core/authentication#authorization-scopes)\n(used to restrict the dataset of your application to a market and/or stock location).\nIf specified, it will override the default scope set in the drop-in library configuration.\nOtherwise, the default scope taken from the drop-in library configuration will be used."
                },
                "getter": false,
                "setter": false,
                "reflect": true
            }
        };
    }
    static get states() {
        return {
            "href": {}
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "type",
                "methodName": "watchTypeHandler"
            }];
    }
}
