import { Host, h, } from "@stencil/core";
import { getAccessToken } from "../../apis/commercelayer/client";
import { getConfig } from "../../apis/commercelayer/config";
import { listenTo } from "../../apis/event";
import { isValidUnion, logUnion, unionToTuple } from "../../utils/validation-helpers";
export class ClIdentityStatus {
    host;
    typeList = unionToTuple()("guest", "customer");
    /**
     * The user identity status (logged in or not logged in).
     * It determines the visibility of the inner message based on the stored token.
     */
    type;
    status;
    async componentWillLoad() {
        listenTo("cl-identity-gettoken", (event) => {
            this.status = event.detail.response.type;
        });
        const config = getConfig();
        this.status = (await getAccessToken(config)).type;
        this.logType(this.type);
    }
    async watchTypeHandler(newValue) {
        this.logType(newValue);
    }
    logType(type) {
        logUnion(this.host, "type", type, this.typeList);
    }
    render() {
        if (isValidUnion(this.type, this.typeList) &&
            isValidUnion(this.status, this.typeList) &&
            this.type === this.status) {
            return h("slot", null);
        }
        return h(Host, { "aria-disabled": "true" });
    }
    static get is() { return "cl-identity-status"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "type": {
                "type": "string",
                "attribute": "type",
                "mutable": false,
                "complexType": {
                    "original": "\"guest\" | \"customer\" | undefined",
                    "resolved": "\"customer\" | \"guest\" | undefined",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The user identity status (logged in or not logged in).\nIt determines the visibility of the inner message based on the stored token."
                },
                "getter": false,
                "setter": false,
                "reflect": true
            }
        };
    }
    static get states() {
        return {
            "status": {}
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "type",
                "methodName": "watchTypeHandler"
            }];
    }
}
