import { h } from "@stencil/core";
import debounce from "lodash/debounce";
import { getPrice as getBundlePrice } from "../../apis/commercelayer/bundles/index";
import { getPrice as getSkuPrice } from "../../apis/commercelayer/skus/index";
import { isValidCode, logCode, logUnion, unionToTuple, } from "../../utils/validation-helpers";
export class ClPrice {
    host;
    kindList = unionToTuple()("sku", "bundle");
    kindDefault = "sku";
    /**
     * Indicates whether the code refers to a `sku` or a `bundle`.
     * @default sku
     */
    kind = "sku";
    /**
     * The SKU or bundle code (i.e. the unique identifier of the product or bundle whose price you want to display).
     */
    code;
    async componentWillLoad() {
        logCode(this.host, this.code);
        await this.updatePrice(this.kind, this.code);
    }
    async watchKindHandler(newValue) {
        if (newValue == null) {
            this.kind = this.kindDefault;
            return;
        }
        logUnion(this.host, "kind", newValue, this.kindList);
        await this.debouncedUpdatePrice(newValue, this.code);
    }
    async watchCodeHandler(newValue) {
        logCode(this.host, newValue);
        await this.debouncedUpdatePrice(this.kind, newValue);
    }
    updatePrice = async (kind, code) => {
        let price;
        if (isValidCode(code)) {
            switch (kind) {
                case "bundle":
                    price = await getBundlePrice(code);
                    break;
                default:
                    price = await getSkuPrice(code);
                    break;
            }
        }
        this.host.querySelectorAll("cl-price-amount").forEach((element) => {
            element.dispatchEvent(new CustomEvent("priceUpdate", { detail: price }));
        });
    };
    debouncedUpdatePrice = debounce(this.updatePrice, 10);
    render() {
        return h("slot", { key: 'd76a2f12bd0e53447f787c25ee3cfaa0786dcf36' });
    }
    static get is() { return "cl-price"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "kind": {
                "type": "string",
                "attribute": "kind",
                "mutable": true,
                "complexType": {
                    "original": "\"sku\" | \"bundle\"",
                    "resolved": "\"bundle\" | \"sku\" | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "default",
                            "text": "sku"
                        }],
                    "text": "Indicates whether the code refers to a `sku` or a `bundle`."
                },
                "getter": false,
                "setter": false,
                "reflect": true,
                "defaultValue": "\"sku\""
            },
            "code": {
                "type": "string",
                "attribute": "code",
                "mutable": false,
                "complexType": {
                    "original": "string | undefined",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": "The SKU or bundle code (i.e. the unique identifier of the product or bundle whose price you want to display)."
                },
                "getter": false,
                "setter": false,
                "reflect": true
            }
        };
    }
    static get elementRef() { return "host"; }
    static get watchers() {
        return [{
                "propName": "kind",
                "methodName": "watchKindHandler"
            }, {
                "propName": "code",
                "methodName": "watchCodeHandler"
            }];
    }
}
