import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { b as logUnion } from './validation-helpers.js';

const ClAvailabilityStatus$1 = /*@__PURE__*/ proxyCustomElement(class ClAvailabilityStatus extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
    }
    get host() { return this; }
    typeList = [
        "available",
        "available-with-info",
        "unavailable",
    ];
    /**
     * The product availability status.
     * It determines the visibility of the inner message.
     */
    type;
    available;
    hasDeliveryLeadTimes;
    availabilityUpdateHandler(event) {
        const hasQuantity = event.detail?.sku?.inventory?.quantity === undefined ||
            event.detail.sku.inventory.quantity - event.detail.cartQuantity > 0;
        this.available =
            event.detail?.sku?.inventory?.available == null
                ? undefined
                : event.detail.sku.inventory.available && hasQuantity;
        this.hasDeliveryLeadTimes =
            (event.detail?.sku?.inventory?.levels?.[0]?.delivery_lead_times?.length ??
                0) > 0;
    }
    async componentWillLoad() {
        this.logType(this.type);
    }
    async watchTypeHandler(newValue) {
        this.logType(newValue);
    }
    logType(type) {
        logUnion(this.host, "type", type, this.typeList);
    }
    render() {
        if ((this.type === "available" && this.available === true) ||
            (this.type === "unavailable" && this.available === false) ||
            (this.type === "available-with-info" &&
                this.available === true &&
                this.hasDeliveryLeadTimes === true)) {
            return h("slot", null);
        }
        return h(Host, { "aria-disabled": "true" });
    }
    static get watchers() { return {
        "type": ["watchTypeHandler"]
    }; }
}, [1, "cl-availability-status", {
        "type": [513],
        "available": [32],
        "hasDeliveryLeadTimes": [32]
    }, [[0, "availabilityUpdate", "availabilityUpdateHandler"]], {
        "type": ["watchTypeHandler"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cl-availability-status"];
    components.forEach(tagName => { switch (tagName) {
        case "cl-availability-status":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ClAvailabilityStatus$1);
            }
            break;
    } });
}
defineCustomElement$1();

const ClAvailabilityStatus = ClAvailabilityStatus$1;
const defineCustomElement = defineCustomElement$1;

export { ClAvailabilityStatus, defineCustomElement };
