import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { l as listenTo, k as debounce } from './config.js';
import { g as getCart, a as getCartQuantity } from './cart.js';
import './list.js';
import { g as getSku } from './skus.js';
import { u as unionToTuple, a as logCode, b as logUnion, i as isValidCode } from './validation-helpers.js';

const ClAvailability$1 = /*@__PURE__*/ proxyCustomElement(class ClAvailability extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
    }
    get host() { return this; }
    kindList = unionToTuple()("sku", "bundle");
    kindDefault = "sku";
    /**
     * Indicates whether the code refers to a `sku` or a `bundle`.
     *
     * _⚠️ `bundle` is not fully implemented._
     *
     * @default sku
     */
    kind = "sku";
    /**
     * The SKU or bundle code (i.e. the unique identifier of the product or bundle whose availability you want to display).
     */
    code;
    /**
     * The rule used to determine the information that will be displayed.
     * `cheapest` is the delivery lead time associated with the lower shipping method cost,
     * `fastest` is the delivery lead time associated with the lower average time to delivery.
     */
    rule = "cheapest";
    cart;
    async componentWillLoad() {
        logCode(this.host, this.code);
        this.cart = (await getCart()) ?? undefined;
        await this.updateAvailability(this.kind, this.code);
        listenTo("cl-cart-update", (event) => {
            this.cart = event.detail.response;
            void this.updateAvailability(this.kind, this.code);
        });
        listenTo("cl-cart-hostedcartupdate", (event) => {
            this.cart = event.detail.response;
            void this.updateAvailability(this.kind, this.code);
        });
    }
    async watchKindHandler(newValue) {
        if (newValue == null) {
            this.kind = this.kindDefault;
            return;
        }
        logUnion(this.host, "kind", newValue, this.kindList);
        await this.debouncedUpdateAvailability(newValue, this.code);
    }
    async watchPropHandler(newValue) {
        logCode(this.host, newValue);
        await this.debouncedUpdateAvailability(this.kind, newValue);
    }
    updateAvailability = async (kind, code) => {
        let sku;
        if (kind !== "bundle" && isValidCode(code)) {
            sku = await getSku(code);
        }
        this.host
            .querySelectorAll("cl-availability-status, cl-availability-info")
            .forEach((element) => {
            element.dispatchEvent(new CustomEvent("availabilityUpdate", {
                detail: {
                    sku,
                    rule: this.rule,
                    cartQuantity: getCartQuantity(this.cart, kind, code),
                },
            }));
        });
    };
    debouncedUpdateAvailability = debounce(this.updateAvailability, 10);
    render() {
        return h("slot", { key: '50f44a10f705b608676b3d7963ffe6c3046174a9' });
    }
    static get watchers() { return {
        "kind": ["watchKindHandler"],
        "code": ["watchPropHandler"]
    }; }
}, [1, "cl-availability", {
        "kind": [1537],
        "code": [513],
        "rule": [513],
        "cart": [32]
    }, undefined, {
        "kind": ["watchKindHandler"],
        "code": ["watchPropHandler"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cl-availability"];
    components.forEach(tagName => { switch (tagName) {
        case "cl-availability":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ClAvailability$1);
            }
            break;
    } });
}
defineCustomElement$1();

const ClAvailability = ClAvailability$1;
const defineCustomElement = defineCustomElement$1;

export { ClAvailability, defineCustomElement };
