import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { g as getCart } from './cart.js';
import { l as listenTo } from './config.js';

const ClCartCount$1 = /*@__PURE__*/ proxyCustomElement(class ClCartCount extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
    }
    /**
     * Toggle this switch to hide the counter when the cart is empty instead of showing `0`.
     */
    hideWhenEmpty = false;
    count;
    async componentWillLoad() {
        listenTo("cl-cart-update", (event) => {
            void this.updateCart(event.detail.response);
        });
        listenTo("cl-cart-hostedcartupdate", (event) => {
            void this.updateCart(event.detail.response);
        });
        await this.updateCart(await getCart());
    }
    async updateCart(cart) {
        const itemCount = cart?.line_items
            ?.filter((item) => item.item_type === "skus" || item.item_type === "bundles")
            .reduce((count, item) => count + item.quantity, 0);
        // TODO: `skus_count` counts SKUs inside the bundle (this could be a future option).
        // if (cart?.skus_count != null && cart.skus_count > 0) {
        //   this.count = cart.skus_count
        // }
        if (itemCount != null && itemCount > 0) {
            this.count = itemCount;
        }
        else {
            this.count = undefined;
        }
    }
    render() {
        const value = this.count ?? (this.hideWhenEmpty ? undefined : 0);
        return h(Host, { key: '12961918bcb5a998660cb3cc77805ce50dc45a9b', quantity: this.count }, value);
    }
}, [1, "cl-cart-count", {
        "hideWhenEmpty": [516, "hide-when-empty"],
        "count": [32]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cl-cart-count"];
    components.forEach(tagName => { switch (tagName) {
        case "cl-cart-count":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ClCartCount$1);
            }
            break;
    } });
}
defineCustomElement$1();

const ClCartCount = ClCartCount$1;
const defineCustomElement = defineCustomElement$1;

export { ClCartCount, defineCustomElement };
