import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { i as isValidUrl, b as getCartUrl } from './cart.js';
import { l as listenTo } from './config.js';

const ClCartLink$1 = /*@__PURE__*/ proxyCustomElement(class ClCartLink extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
    }
    get host() { return this; }
    /**
     * The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;).
     */
    target = "_self";
    minicart = null;
    href;
    componentWillLoad() {
        this.host.setAttribute("cl-hydrated", "");
        this.minicart = this.host.querySelector("cl-cart");
        if (this.minicart !== null) {
            this.minicart.type = "mini";
        }
        listenTo("cl-cart-update", async () => {
            if (this.href === undefined || !(await isValidUrl(this.href))) {
                this.href = await getCartUrl();
            }
        });
        void getCartUrl().then((cartUrl) => {
            this.href = cartUrl;
        });
    }
    async handleClick(event) {
        if (this.href === undefined || !(await isValidUrl(this.href))) {
            event.preventDefault();
            this.href = await getCartUrl(true);
            window.open(this.href, this.target);
        }
    }
    handleKeyDown(event) {
        if (event.key === "Enter" || event.key === " ") {
            this.handleOpenMinicart();
        }
    }
    handleOpenMinicart() {
        if (this.minicart !== null) {
            this.minicart.open = true;
        }
    }
    render() {
        if (this.minicart !== null) {
            return (h(Host, { role: "button", tabindex: "0", onKeyDown: (event) => {
                    this.handleKeyDown(event);
                }, onClick: () => {
                    this.handleOpenMinicart();
                } }, h("slot", null)));
        }
        return (h(Host, { "aria-disabled": this.href !== undefined ? undefined : "true" }, h("a", { target: this.target, href: this.href, onClick: (e) => {
                this.handleClick(e).catch((error) => {
                    throw error;
                });
            } }, h("slot", null))));
    }
}, [4, "cl-cart-link", {
        "target": [513],
        "minicart": [32],
        "href": [32]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cl-cart-link"];
    components.forEach(tagName => { switch (tagName) {
        case "cl-cart-link":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ClCartLink$1);
            }
            break;
    } });
}
defineCustomElement$1();

const ClCartLink = ClCartLink$1;
const defineCustomElement = defineCustomElement$1;

export { ClCartLink, defineCustomElement };
