import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { g as getIdentityUrl } from './account.js';
import { n as logout } from './config.js';
import { u as unionToTuple, c as isValidUnion, b as logUnion } from './validation-helpers.js';

const ClIdentityLink$1 = /*@__PURE__*/ proxyCustomElement(class ClIdentityLink extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
    }
    get host() { return this; }
    typeList = unionToTuple()("login", "signup", "logout");
    /**
     * The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;).
     */
    target = "_self";
    /**
     * The user account access action.
     */
    type;
    /**
     * Enable a custom reset password link visible on the login form page.
     * When set, a "Forgot password?" link will be shown on the right below the Password field.
     */
    resetPasswordUrl;
    /**
     * Your sales channel [scope](https://docs.commercelayer.io/core/authentication#authorization-scopes)
     * (used to restrict the dataset of your application to a market and/or stock location).
     * If specified, it will override the default scope set in the drop-in library configuration.
     * Otherwise, the default scope taken from the drop-in library configuration will be used.
     */
    scope;
    href;
    async componentWillLoad() {
        await this.updateUrl(this.type);
    }
    async watchTypeHandler(newValue) {
        await this.updateUrl(newValue);
    }
    async updateUrl(type) {
        this.href = isValidUnion(type, this.typeList)
            ? await getIdentityUrl(type, this.scope, this.resetPasswordUrl)
            : undefined;
        logUnion(this.host, "type", type, this.typeList);
    }
    render() {
        return (h(Host, { key: '16138f455ae22c86b083044d676e0f613de461a7', "aria-disabled": isValidUnion(this.type, this.typeList) && this.href !== undefined
                ? undefined
                : "true" }, h("a", { key: '24821ad870bc6ebd29e7185c0279fa3335a92906', target: this.target, href: this.href, onClick: (event) => {
                if (this.type === "logout") {
                    event.preventDefault();
                    void logout().then(() => {
                        location.reload();
                    });
                }
            } }, h("slot", { key: 'd95bfbe55a581be24e09bff5886d0dba5543cc27' }))));
    }
    static get watchers() { return {
        "type": ["watchTypeHandler"]
    }; }
}, [4, "cl-identity-link", {
        "target": [513],
        "type": [513],
        "resetPasswordUrl": [513, "reset-password-url"],
        "scope": [513],
        "href": [32]
    }, undefined, {
        "type": ["watchTypeHandler"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cl-identity-link"];
    components.forEach(tagName => { switch (tagName) {
        case "cl-identity-link":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ClIdentityLink$1);
            }
            break;
    } });
}
defineCustomElement$1();

const ClIdentityLink = ClIdentityLink$1;
const defineCustomElement = defineCustomElement$1;

export { ClIdentityLink, defineCustomElement };
