import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { l as listenTo, g as getConfig, b as getAccessToken } from './config.js';
import { u as unionToTuple, b as logUnion, c as isValidUnion } from './validation-helpers.js';

const ClIdentityStatus$1 = /*@__PURE__*/ proxyCustomElement(class ClIdentityStatus extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
    }
    get host() { return this; }
    typeList = unionToTuple()("guest", "customer");
    /**
     * The user identity status (logged in or not logged in).
     * It determines the visibility of the inner message based on the stored token.
     */
    type;
    status;
    async componentWillLoad() {
        listenTo("cl-identity-gettoken", (event) => {
            this.status = event.detail.response.type;
        });
        const config = getConfig();
        this.status = (await getAccessToken(config)).type;
        this.logType(this.type);
    }
    async watchTypeHandler(newValue) {
        this.logType(newValue);
    }
    logType(type) {
        logUnion(this.host, "type", type, this.typeList);
    }
    render() {
        if (isValidUnion(this.type, this.typeList) &&
            isValidUnion(this.status, this.typeList) &&
            this.type === this.status) {
            return h("slot", null);
        }
        return h(Host, { "aria-disabled": "true" });
    }
    static get watchers() { return {
        "type": ["watchTypeHandler"]
    }; }
}, [1, "cl-identity-status", {
        "type": [513],
        "status": [32]
    }, undefined, {
        "type": ["watchTypeHandler"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cl-identity-status"];
    components.forEach(tagName => { switch (tagName) {
        case "cl-identity-status":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ClIdentityStatus$1);
            }
            break;
    } });
}
defineCustomElement$1();

const ClIdentityStatus = ClIdentityStatus$1;
const defineCustomElement = defineCustomElement$1;

export { ClIdentityStatus, defineCustomElement };
