import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { m as memoize, f as fireEvent, k as debounce } from './config.js';
import { _ as _getBundleViaList } from './list2.js';
import { g as getPrice$1 } from './list.js';
import { u as unionToTuple, a as logCode, b as logUnion, i as isValidCode } from './validation-helpers.js';

const getMemoizedPrice = memoize(async (code) => {
    return await _getBundleViaList(code).then((bundle) => {
        if (bundle?.price_amount_cents == null) {
            return undefined;
        }
        const price = {
            amount_cents: bundle.price_amount_cents,
            amount_float: bundle.price_amount_float,
            compare_at_amount_cents: bundle.compare_at_amount_cents,
            compare_at_amount_float: bundle.compare_at_amount_float,
            created_at: bundle.created_at,
            formatted_amount: bundle.formatted_price_amount,
            formatted_compare_at_amount: bundle.formatted_compare_at_amount,
            id: bundle.id,
            type: "prices",
            updated_at: bundle.updated_at,
            currency_code: bundle.currency_code,
        };
        return price;
    });
});
const getPrice = async (code) => {
    const price = await getMemoizedPrice(code);
    fireEvent("cl-bundles-getprice", [code], price);
    return price;
};

const ClPrice$1 = /*@__PURE__*/ proxyCustomElement(class ClPrice extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
    }
    get host() { return this; }
    kindList = unionToTuple()("sku", "bundle");
    kindDefault = "sku";
    /**
     * Indicates whether the code refers to a `sku` or a `bundle`.
     * @default sku
     */
    kind = "sku";
    /**
     * The SKU or bundle code (i.e. the unique identifier of the product or bundle whose price you want to display).
     */
    code;
    async componentWillLoad() {
        logCode(this.host, this.code);
        await this.updatePrice(this.kind, this.code);
    }
    async watchKindHandler(newValue) {
        if (newValue == null) {
            this.kind = this.kindDefault;
            return;
        }
        logUnion(this.host, "kind", newValue, this.kindList);
        await this.debouncedUpdatePrice(newValue, this.code);
    }
    async watchCodeHandler(newValue) {
        logCode(this.host, newValue);
        await this.debouncedUpdatePrice(this.kind, newValue);
    }
    updatePrice = async (kind, code) => {
        let price;
        if (isValidCode(code)) {
            switch (kind) {
                case "bundle":
                    price = await getPrice(code);
                    break;
                default:
                    price = await getPrice$1(code);
                    break;
            }
        }
        this.host.querySelectorAll("cl-price-amount").forEach((element) => {
            element.dispatchEvent(new CustomEvent("priceUpdate", { detail: price }));
        });
    };
    debouncedUpdatePrice = debounce(this.updatePrice, 10);
    render() {
        return h("slot", { key: 'd76a2f12bd0e53447f787c25ee3cfaa0786dcf36' });
    }
    static get watchers() { return {
        "kind": ["watchKindHandler"],
        "code": ["watchCodeHandler"]
    }; }
}, [1, "cl-price", {
        "kind": [1537],
        "code": [513]
    }, undefined, {
        "kind": ["watchKindHandler"],
        "code": ["watchCodeHandler"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["cl-price"];
    components.forEach(tagName => { switch (tagName) {
        case "cl-price":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ClPrice$1);
            }
            break;
    } });
}
defineCustomElement$1();

const ClPrice = ClPrice$1;
const defineCustomElement = defineCustomElement$1;

export { ClPrice, defineCustomElement };
