export type DropInArgs = {
  /**  */
  ['cl-add-to-cart'] : {
    /** The SKU or bundle code (i.e. the unique identifier of the product or bundle you want to add to the shopping cart). */
    ['code']: string | undefined
    /** The frequency which generates a [subscription](https://docs.commercelayer.io/core/v/how-tos/placing-orders/subscriptions). The value must be supported by the associated subscription model. */
    ['frequency']: string | undefined
    /** A custom image URL for the product or bundle that will be added to the cart.
If not provided, the image URL will be taken from the item being added. */
    ['image-url']: string | undefined
    /** Indicates whether the code refers to a `sku` or a `bundle`. */
    ['kind']: "bundle" | "sku" | undefined
    /** A custom name for the product or bundle that will be added to the cart.
If not provided, the name will be taken from the item being added. */
    ['name']: string | undefined
    /** The number of units of the selected product you want to add to the shopping cart. */
    ['quantity']: number
  }
  /**  */
  ['cl-availability'] : {
    /** The SKU or bundle code (i.e. the unique identifier of the product or bundle whose availability you want to display). */
    ['code']: string | undefined
    /** Indicates whether the code refers to a `sku` or a `bundle`.

_⚠️ `bundle` is not fully implemented._ */
    ['kind']: "bundle" | "sku" | undefined
    /** The rule used to determine the information that will be displayed.
`cheapest` is the delivery lead time associated with the lower shipping method cost,
`fastest` is the delivery lead time associated with the lower average time to delivery. */
    ['rule']: "cheapest" | "fastest"
  }
  /**  */
  ['cl-availability-info'] : {
    /** The type of information to be displayed. */
    ['type']: "max-days" | "max-hours" | "min-days" | "min-hours" | "shipping-method-name" | "shipping-method-price" | undefined
  }
  /**  */
  ['cl-availability-status'] : {
    /** The product availability status.
It determines the visibility of the inner message. */
    ['type']: "available" | "available-with-info" | "unavailable" | undefined
  }
  /**  */
  ['cl-cart'] : {
    /** Indicate whether the minicart is open or not
(available _only_ when the `cl-cart` component is used as _minicart_). */
    ['open']: boolean
    /** If `true` the minicart automatically opens as soon as an item is added to the shopping cart
(available _only_ when the `cl-cart` component is used as _minicart_). */
    ['open-on-add']: boolean
    /** By default the `cl-cart` is directly displayed in-place.
Setting the `type` to `mini` will change the behavior to be a minicart. */
    ['type']: "mini" | undefined
  }
  /**  */
  ['cl-cart-count'] : {
    /** Toggle this switch to hide the counter when the cart is empty instead of showing `0`. */
    ['hide-when-empty']: boolean
  }
  /**  */
  ['cl-cart-link'] : {
    /** The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;). */
    ['target']: "_blank" | "_parent" | "_self" | "_top"
  }
  /**  */
  ['cl-checkout-link'] : {
    /** The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;). */
    ['target']: "_blank" | "_parent" | "_self" | "_top"
  }
  /**  */
  ['cl-identity-link'] : {
    /** Enable a custom reset password link visible on the login form page.
When set, a "Forgot password?" link will be shown on the right below the Password field. */
    ['reset-password-url']: string | undefined
    /** Your sales channel [scope](https://docs.commercelayer.io/core/authentication#authorization-scopes)
(used to restrict the dataset of your application to a market and/or stock location).
If specified, it will override the default scope set in the drop-in library configuration.
Otherwise, the default scope taken from the drop-in library configuration will be used. */
    ['scope']: string | undefined
    /** The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;). */
    ['target']: "_blank" | "_parent" | "_self" | "_top"
    /** The user account access action. */
    ['type']: "login" | "logout" | "signup" | undefined
  }
  /**  */
  ['cl-identity-status'] : {
    /** The user identity status (logged in or not logged in).
It determines the visibility of the inner message based on the stored token. */
    ['type']: "customer" | "guest" | undefined
  }
  /**  */
  ['cl-my-account-link'] : {
    /** The browsing context in which to open the linked URL (a tab, a window, or an &lt;iframe&gt;). */
    ['target']: "_blank" | "_parent" | "_self" | "_top"
  }
  /**  */
  ['cl-price'] : {
    /** The SKU or bundle code (i.e. the unique identifier of the product or bundle whose price you want to display). */
    ['code']: string | undefined
    /** Indicates whether the code refers to a `sku` or a `bundle`. */
    ['kind']: "bundle" | "sku" | undefined
  }
  /**  */
  ['cl-price-amount'] : {
    /** The type of price amount to be displayed. */
    ['type']: "compare-at" | "price"
  }
}
