import type { Order } from "@commercelayer/sdk";
import type { AddItem, TriggerCartUpdate, TriggerHostedCartUpdate } from "../types";
export declare function isValidForCheckout(order: Order): boolean;
export declare function isValidUrl(url: string): Promise<boolean>;
/**
 * Get the Hosted Cart url.
 * @param forceCartToExist When true it will create an empty cart if not existing before.
 * @returns Returns the Hosted Cart url.
 */
export declare function getCartUrl(forceCartToExist?: boolean): Promise<string>;
export declare function getCheckoutUrl(): Promise<string | undefined>;
export declare function _getCart(): Promise<Order | null>;
export declare const getCart: (() => Promise<Order | null>) & import("lodash").MemoizedFunction;
/**
 * Trigger the `cartUpdate` event.
 */
export declare const triggerCartUpdate: TriggerCartUpdate;
/**
 * Trigger the `hostedCartUpdate` event.
 * @param iframeId iFrame ID who triggered the event
 */
export declare const triggerHostedCartUpdate: TriggerHostedCartUpdate;
export declare const addItem: AddItem;
/**
 * Update the `cart_url` property of the cart on Commerce Layer.
 * `cart_url` is used in the Hosted Checkout as a link for "< Return to cart".
 * @param cartUrl new cart_url
 */
export declare function updateCartUrl(cartUrl: string): Promise<void>;
/**
 * Get quantity of a specific item in the cart, by reading the `line_items`.
 */
export declare function getCartQuantity(cart: Order | undefined, kind: "sku" | "bundle" | undefined, code: string | undefined): number;
