import type { Order } from "@commercelayer/sdk";
import { type JSX } from "../../stencil-public-runtime";
import type { Inventory } from "../../apis/types";
export declare class ClAddToCart {
    host: HTMLClAddToCartElement;
    private readonly kindList;
    private readonly kindDefault;
    /**
     * Indicates whether the code refers to a `sku` or a `bundle`.
     * @default sku
     */
    kind?: "sku" | "bundle";
    /**
     * The SKU or bundle code (i.e. the unique identifier of the product or bundle you want to add to the shopping cart).
     */
    code: string | undefined;
    /**
     * The number of units of the selected product you want to add to the shopping cart.
     * @default 1
     */
    quantity: number;
    /**
     * A custom name for the product or bundle that will be added to the cart.
     * If not provided, the name will be taken from the item being added.
     */
    name: string | undefined;
    /**
     * A custom image URL for the product or bundle that will be added to the cart.
     * If not provided, the image URL will be taken from the item being added.
     */
    imageUrl: string | undefined;
    /**
     * The frequency which generates a [subscription](https://docs.commercelayer.io/core/v/how-tos/placing-orders/subscriptions). The value must be supported by the associated subscription model.
     */
    frequency: string | undefined;
    /**
     * The item is currently being added to the cart.
     * @default false
     */
    busy: boolean;
    inventory: Inventory | undefined;
    cart: Order | undefined;
    componentWillLoad(): Promise<void>;
    watchKindHandler(newValue: typeof this.kind): Promise<void>;
    watchCodeHandler(newValue: typeof this.code): Promise<void>;
    watchQuantityHandler(newValue: typeof this.quantity): Promise<void>;
    private readonly updateSku;
    private readonly debouncedUpdateSku;
    private updateQuantity;
    handleKeyPress(event: KeyboardEvent): void;
    handleAddItem(): void;
    /**
     * Check whether the sku is soldable.
     * @returns Returns true when item is soldable.
     */
    canBeSold(): boolean;
    render(): JSX.Element;
}
