import { type JSX } from "../../stencil-public-runtime";
export declare class ClCart {
    host: HTMLClCartElement;
    private iframe;
    /**
     * By default the `cl-cart` is directly displayed in-place.
     * Setting the `type` to `mini` will change the behavior to be a minicart.
     */
    type: "mini" | undefined;
    /**
     * If `true` the minicart automatically opens as soon as an item is added to the shopping cart
     * (available _only_ when the `cl-cart` component is used as _minicart_).
     */
    openOnAdd: boolean;
    /**
     * Indicate whether the minicart is open or not
     * (available _only_ when the `cl-cart` component is used as _minicart_).
     */
    open: boolean;
    /** Current hosted cart url */
    href: string | undefined;
    isMinicart: boolean;
    /**
     * Used for:
     * 1. As query parameter that re-open the minicart when clicking on `< Return to cart` (Hosted Cart link).
     * 2. As body class when the minicart is open to disable page scrolling.
     */
    readonly openDirective: "cl-cart--open";
    private flag_listenForHostedCartUpdateResponse;
    componentWillLoad(): Promise<void>;
    private updateUrl;
    /**
     * Get the current page url.
     * When the component is rendered as `minicart` the cart page url will be the current page url, plus a dedicated query parameter.
     * @returns Current page url ( + query parameter when rendered as `minicart` )
     */
    getCartPageUrl(): string;
    /**
     * Check whether the current url has the `openDirective` query parameter.
     * @returns Whether the current url has the `openDirective`
     */
    private checkLocationHrefForOpenDirective;
    private updateMinicartUrl;
    watchOpenHandler(opened: boolean): void;
    componentDidLoad(): void;
    handleKeyDown(event: KeyboardEvent): void;
    private handleCloseMinicart;
    render(): JSX.Element;
}
