import type { DebounceSettings, DebouncedFunc } from "lodash";
interface Options {
    wait: number;
    maxWait: number;
}
type PromiseDebouncedFunc<T extends (...args: any[]) => any> = (...args: Parameters<T>) => Promise<Awaited<ReturnType<T>>>;
export declare const pDebounce: <T extends (arg: any[]) => any>(input: T, options?: Options) => PromiseDebouncedFunc<T>;
/**
 * Creates a memoized-debounced function that delays invoking `func` until after `wait` milliseconds
 * have elapsed since the last time the memoized-debounced function was invoked.
 *
 * The function is also **memoized** using all arguments as the map cache key. You can override this
 * default by providing a `resolver` function.
 * @param func The function to debounce.
 * @param wait The number of milliseconds to delay.
 * @param options The options object.
 * @param resolver The function to resolve the cache key (for memoized function).
 * @returns Returns the new memoized function debounced.
 */
export declare function memoDebounce<F extends (...args: any[]) => any>(func: F, wait?: number, options?: DebounceSettings, resolver?: (...args: Parameters<F>) => unknown): DebouncedFunc<F>;
export {};
