var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

function getDefaultExportFromCjs (x) {
	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
}

/**
 * Checks if `value` is the
 * [language type](http://www.ecma-international.org/ecma-262/7.0/#sec-ecmascript-language-types)
 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
 * @example
 *
 * _.isObject({});
 * // => true
 *
 * _.isObject([1, 2, 3]);
 * // => true
 *
 * _.isObject(_.noop);
 * // => true
 *
 * _.isObject(null);
 * // => false
 */

var isObject_1;
var hasRequiredIsObject;

function requireIsObject () {
	if (hasRequiredIsObject) return isObject_1;
	hasRequiredIsObject = 1;
	function isObject(value) {
	  var type = typeof value;
	  return value != null && (type == 'object' || type == 'function');
	}

	isObject_1 = isObject;
	return isObject_1;
}

/** Detect free variable `global` from Node.js. */

var _freeGlobal;
var hasRequired_freeGlobal;

function require_freeGlobal () {
	if (hasRequired_freeGlobal) return _freeGlobal;
	hasRequired_freeGlobal = 1;
	var freeGlobal = typeof commonjsGlobal == 'object' && commonjsGlobal && commonjsGlobal.Object === Object && commonjsGlobal;

	_freeGlobal = freeGlobal;
	return _freeGlobal;
}

var _root;
var hasRequired_root;

function require_root () {
	if (hasRequired_root) return _root;
	hasRequired_root = 1;
	var freeGlobal = require_freeGlobal();

	/** Detect free variable `self`. */
	var freeSelf = typeof self == 'object' && self && self.Object === Object && self;

	/** Used as a reference to the global object. */
	var root = freeGlobal || freeSelf || Function('return this')();

	_root = root;
	return _root;
}

var now_1;
var hasRequiredNow;

function requireNow () {
	if (hasRequiredNow) return now_1;
	hasRequiredNow = 1;
	var root = require_root();

	/**
	 * Gets the timestamp of the number of milliseconds that have elapsed since
	 * the Unix epoch (1 January 1970 00:00:00 UTC).
	 *
	 * @static
	 * @memberOf _
	 * @since 2.4.0
	 * @category Date
	 * @returns {number} Returns the timestamp.
	 * @example
	 *
	 * _.defer(function(stamp) {
	 *   console.log(_.now() - stamp);
	 * }, _.now());
	 * // => Logs the number of milliseconds it took for the deferred invocation.
	 */
	var now = function() {
	  return root.Date.now();
	};

	now_1 = now;
	return now_1;
}

/** Used to match a single whitespace character. */

var _trimmedEndIndex;
var hasRequired_trimmedEndIndex;

function require_trimmedEndIndex () {
	if (hasRequired_trimmedEndIndex) return _trimmedEndIndex;
	hasRequired_trimmedEndIndex = 1;
	var reWhitespace = /\s/;

	/**
	 * Used by `_.trim` and `_.trimEnd` to get the index of the last non-whitespace
	 * character of `string`.
	 *
	 * @private
	 * @param {string} string The string to inspect.
	 * @returns {number} Returns the index of the last non-whitespace character.
	 */
	function trimmedEndIndex(string) {
	  var index = string.length;

	  while (index-- && reWhitespace.test(string.charAt(index))) {}
	  return index;
	}

	_trimmedEndIndex = trimmedEndIndex;
	return _trimmedEndIndex;
}

var _baseTrim;
var hasRequired_baseTrim;

function require_baseTrim () {
	if (hasRequired_baseTrim) return _baseTrim;
	hasRequired_baseTrim = 1;
	var trimmedEndIndex = require_trimmedEndIndex();

	/** Used to match leading whitespace. */
	var reTrimStart = /^\s+/;

	/**
	 * The base implementation of `_.trim`.
	 *
	 * @private
	 * @param {string} string The string to trim.
	 * @returns {string} Returns the trimmed string.
	 */
	function baseTrim(string) {
	  return string
	    ? string.slice(0, trimmedEndIndex(string) + 1).replace(reTrimStart, '')
	    : string;
	}

	_baseTrim = baseTrim;
	return _baseTrim;
}

var _Symbol;
var hasRequired_Symbol;

function require_Symbol () {
	if (hasRequired_Symbol) return _Symbol;
	hasRequired_Symbol = 1;
	var root = require_root();

	/** Built-in value references. */
	var Symbol = root.Symbol;

	_Symbol = Symbol;
	return _Symbol;
}

var _getRawTag;
var hasRequired_getRawTag;

function require_getRawTag () {
	if (hasRequired_getRawTag) return _getRawTag;
	hasRequired_getRawTag = 1;
	var Symbol = require_Symbol();

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var nativeObjectToString = objectProto.toString;

	/** Built-in value references. */
	var symToStringTag = Symbol ? Symbol.toStringTag : undefined;

	/**
	 * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
	 *
	 * @private
	 * @param {*} value The value to query.
	 * @returns {string} Returns the raw `toStringTag`.
	 */
	function getRawTag(value) {
	  var isOwn = hasOwnProperty.call(value, symToStringTag),
	      tag = value[symToStringTag];

	  try {
	    value[symToStringTag] = undefined;
	    var unmasked = true;
	  } catch (e) {}

	  var result = nativeObjectToString.call(value);
	  if (unmasked) {
	    if (isOwn) {
	      value[symToStringTag] = tag;
	    } else {
	      delete value[symToStringTag];
	    }
	  }
	  return result;
	}

	_getRawTag = getRawTag;
	return _getRawTag;
}

/** Used for built-in method references. */

var _objectToString;
var hasRequired_objectToString;

function require_objectToString () {
	if (hasRequired_objectToString) return _objectToString;
	hasRequired_objectToString = 1;
	var objectProto = Object.prototype;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/7.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var nativeObjectToString = objectProto.toString;

	/**
	 * Converts `value` to a string using `Object.prototype.toString`.
	 *
	 * @private
	 * @param {*} value The value to convert.
	 * @returns {string} Returns the converted string.
	 */
	function objectToString(value) {
	  return nativeObjectToString.call(value);
	}

	_objectToString = objectToString;
	return _objectToString;
}

var _baseGetTag;
var hasRequired_baseGetTag;

function require_baseGetTag () {
	if (hasRequired_baseGetTag) return _baseGetTag;
	hasRequired_baseGetTag = 1;
	var Symbol = require_Symbol(),
	    getRawTag = require_getRawTag(),
	    objectToString = require_objectToString();

	/** `Object#toString` result references. */
	var nullTag = '[object Null]',
	    undefinedTag = '[object Undefined]';

	/** Built-in value references. */
	var symToStringTag = Symbol ? Symbol.toStringTag : undefined;

	/**
	 * The base implementation of `getTag` without fallbacks for buggy environments.
	 *
	 * @private
	 * @param {*} value The value to query.
	 * @returns {string} Returns the `toStringTag`.
	 */
	function baseGetTag(value) {
	  if (value == null) {
	    return value === undefined ? undefinedTag : nullTag;
	  }
	  return (symToStringTag && symToStringTag in Object(value))
	    ? getRawTag(value)
	    : objectToString(value);
	}

	_baseGetTag = baseGetTag;
	return _baseGetTag;
}

/**
 * Checks if `value` is object-like. A value is object-like if it's not `null`
 * and has a `typeof` result of "object".
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
 * @example
 *
 * _.isObjectLike({});
 * // => true
 *
 * _.isObjectLike([1, 2, 3]);
 * // => true
 *
 * _.isObjectLike(_.noop);
 * // => false
 *
 * _.isObjectLike(null);
 * // => false
 */

var isObjectLike_1;
var hasRequiredIsObjectLike;

function requireIsObjectLike () {
	if (hasRequiredIsObjectLike) return isObjectLike_1;
	hasRequiredIsObjectLike = 1;
	function isObjectLike(value) {
	  return value != null && typeof value == 'object';
	}

	isObjectLike_1 = isObjectLike;
	return isObjectLike_1;
}

var isSymbol_1;
var hasRequiredIsSymbol;

function requireIsSymbol () {
	if (hasRequiredIsSymbol) return isSymbol_1;
	hasRequiredIsSymbol = 1;
	var baseGetTag = require_baseGetTag(),
	    isObjectLike = requireIsObjectLike();

	/** `Object#toString` result references. */
	var symbolTag = '[object Symbol]';

	/**
	 * Checks if `value` is classified as a `Symbol` primitive or object.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a symbol, else `false`.
	 * @example
	 *
	 * _.isSymbol(Symbol.iterator);
	 * // => true
	 *
	 * _.isSymbol('abc');
	 * // => false
	 */
	function isSymbol(value) {
	  return typeof value == 'symbol' ||
	    (isObjectLike(value) && baseGetTag(value) == symbolTag);
	}

	isSymbol_1 = isSymbol;
	return isSymbol_1;
}

var toNumber_1;
var hasRequiredToNumber;

function requireToNumber () {
	if (hasRequiredToNumber) return toNumber_1;
	hasRequiredToNumber = 1;
	var baseTrim = require_baseTrim(),
	    isObject = requireIsObject(),
	    isSymbol = requireIsSymbol();

	/** Used as references for various `Number` constants. */
	var NAN = 0 / 0;

	/** Used to detect bad signed hexadecimal string values. */
	var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

	/** Used to detect binary string values. */
	var reIsBinary = /^0b[01]+$/i;

	/** Used to detect octal string values. */
	var reIsOctal = /^0o[0-7]+$/i;

	/** Built-in method references without a dependency on `root`. */
	var freeParseInt = parseInt;

	/**
	 * Converts `value` to a number.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to process.
	 * @returns {number} Returns the number.
	 * @example
	 *
	 * _.toNumber(3.2);
	 * // => 3.2
	 *
	 * _.toNumber(Number.MIN_VALUE);
	 * // => 5e-324
	 *
	 * _.toNumber(Infinity);
	 * // => Infinity
	 *
	 * _.toNumber('3.2');
	 * // => 3.2
	 */
	function toNumber(value) {
	  if (typeof value == 'number') {
	    return value;
	  }
	  if (isSymbol(value)) {
	    return NAN;
	  }
	  if (isObject(value)) {
	    var other = typeof value.valueOf == 'function' ? value.valueOf() : value;
	    value = isObject(other) ? (other + '') : other;
	  }
	  if (typeof value != 'string') {
	    return value === 0 ? value : +value;
	  }
	  value = baseTrim(value);
	  var isBinary = reIsBinary.test(value);
	  return (isBinary || reIsOctal.test(value))
	    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
	    : (reIsBadHex.test(value) ? NAN : +value);
	}

	toNumber_1 = toNumber;
	return toNumber_1;
}

var debounce_1;
var hasRequiredDebounce;

function requireDebounce () {
	if (hasRequiredDebounce) return debounce_1;
	hasRequiredDebounce = 1;
	var isObject = requireIsObject(),
	    now = requireNow(),
	    toNumber = requireToNumber();

	/** Error message constants. */
	var FUNC_ERROR_TEXT = 'Expected a function';

	/* Built-in method references for those with the same name as other `lodash` methods. */
	var nativeMax = Math.max,
	    nativeMin = Math.min;

	/**
	 * Creates a debounced function that delays invoking `func` until after `wait`
	 * milliseconds have elapsed since the last time the debounced function was
	 * invoked. The debounced function comes with a `cancel` method to cancel
	 * delayed `func` invocations and a `flush` method to immediately invoke them.
	 * Provide `options` to indicate whether `func` should be invoked on the
	 * leading and/or trailing edge of the `wait` timeout. The `func` is invoked
	 * with the last arguments provided to the debounced function. Subsequent
	 * calls to the debounced function return the result of the last `func`
	 * invocation.
	 *
	 * **Note:** If `leading` and `trailing` options are `true`, `func` is
	 * invoked on the trailing edge of the timeout only if the debounced function
	 * is invoked more than once during the `wait` timeout.
	 *
	 * If `wait` is `0` and `leading` is `false`, `func` invocation is deferred
	 * until to the next tick, similar to `setTimeout` with a timeout of `0`.
	 *
	 * See [David Corbacho's article](https://css-tricks.com/debouncing-throttling-explained-examples/)
	 * for details over the differences between `_.debounce` and `_.throttle`.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Function
	 * @param {Function} func The function to debounce.
	 * @param {number} [wait=0] The number of milliseconds to delay.
	 * @param {Object} [options={}] The options object.
	 * @param {boolean} [options.leading=false]
	 *  Specify invoking on the leading edge of the timeout.
	 * @param {number} [options.maxWait]
	 *  The maximum time `func` is allowed to be delayed before it's invoked.
	 * @param {boolean} [options.trailing=true]
	 *  Specify invoking on the trailing edge of the timeout.
	 * @returns {Function} Returns the new debounced function.
	 * @example
	 *
	 * // Avoid costly calculations while the window size is in flux.
	 * jQuery(window).on('resize', _.debounce(calculateLayout, 150));
	 *
	 * // Invoke `sendMail` when clicked, debouncing subsequent calls.
	 * jQuery(element).on('click', _.debounce(sendMail, 300, {
	 *   'leading': true,
	 *   'trailing': false
	 * }));
	 *
	 * // Ensure `batchLog` is invoked once after 1 second of debounced calls.
	 * var debounced = _.debounce(batchLog, 250, { 'maxWait': 1000 });
	 * var source = new EventSource('/stream');
	 * jQuery(source).on('message', debounced);
	 *
	 * // Cancel the trailing debounced invocation.
	 * jQuery(window).on('popstate', debounced.cancel);
	 */
	function debounce(func, wait, options) {
	  var lastArgs,
	      lastThis,
	      maxWait,
	      result,
	      timerId,
	      lastCallTime,
	      lastInvokeTime = 0,
	      leading = false,
	      maxing = false,
	      trailing = true;

	  if (typeof func != 'function') {
	    throw new TypeError(FUNC_ERROR_TEXT);
	  }
	  wait = toNumber(wait) || 0;
	  if (isObject(options)) {
	    leading = !!options.leading;
	    maxing = 'maxWait' in options;
	    maxWait = maxing ? nativeMax(toNumber(options.maxWait) || 0, wait) : maxWait;
	    trailing = 'trailing' in options ? !!options.trailing : trailing;
	  }

	  function invokeFunc(time) {
	    var args = lastArgs,
	        thisArg = lastThis;

	    lastArgs = lastThis = undefined;
	    lastInvokeTime = time;
	    result = func.apply(thisArg, args);
	    return result;
	  }

	  function leadingEdge(time) {
	    // Reset any `maxWait` timer.
	    lastInvokeTime = time;
	    // Start the timer for the trailing edge.
	    timerId = setTimeout(timerExpired, wait);
	    // Invoke the leading edge.
	    return leading ? invokeFunc(time) : result;
	  }

	  function remainingWait(time) {
	    var timeSinceLastCall = time - lastCallTime,
	        timeSinceLastInvoke = time - lastInvokeTime,
	        timeWaiting = wait - timeSinceLastCall;

	    return maxing
	      ? nativeMin(timeWaiting, maxWait - timeSinceLastInvoke)
	      : timeWaiting;
	  }

	  function shouldInvoke(time) {
	    var timeSinceLastCall = time - lastCallTime,
	        timeSinceLastInvoke = time - lastInvokeTime;

	    // Either this is the first call, activity has stopped and we're at the
	    // trailing edge, the system time has gone backwards and we're treating
	    // it as the trailing edge, or we've hit the `maxWait` limit.
	    return (lastCallTime === undefined || (timeSinceLastCall >= wait) ||
	      (timeSinceLastCall < 0) || (maxing && timeSinceLastInvoke >= maxWait));
	  }

	  function timerExpired() {
	    var time = now();
	    if (shouldInvoke(time)) {
	      return trailingEdge(time);
	    }
	    // Restart the timer.
	    timerId = setTimeout(timerExpired, remainingWait(time));
	  }

	  function trailingEdge(time) {
	    timerId = undefined;

	    // Only invoke if we have `lastArgs` which means `func` has been
	    // debounced at least once.
	    if (trailing && lastArgs) {
	      return invokeFunc(time);
	    }
	    lastArgs = lastThis = undefined;
	    return result;
	  }

	  function cancel() {
	    if (timerId !== undefined) {
	      clearTimeout(timerId);
	    }
	    lastInvokeTime = 0;
	    lastArgs = lastCallTime = lastThis = timerId = undefined;
	  }

	  function flush() {
	    return timerId === undefined ? result : trailingEdge(now());
	  }

	  function debounced() {
	    var time = now(),
	        isInvoking = shouldInvoke(time);

	    lastArgs = arguments;
	    lastThis = this;
	    lastCallTime = time;

	    if (isInvoking) {
	      if (timerId === undefined) {
	        return leadingEdge(lastCallTime);
	      }
	      if (maxing) {
	        // Handle invocations in a tight loop.
	        clearTimeout(timerId);
	        timerId = setTimeout(timerExpired, wait);
	        return invokeFunc(lastCallTime);
	      }
	    }
	    if (timerId === undefined) {
	      timerId = setTimeout(timerExpired, wait);
	    }
	    return result;
	  }
	  debounced.cancel = cancel;
	  debounced.flush = flush;
	  return debounced;
	}

	debounce_1 = debounce;
	return debounce_1;
}

var debounceExports = requireDebounce();
var debounce = /*@__PURE__*/getDefaultExportFromCjs(debounceExports);

var isFunction_1;
var hasRequiredIsFunction;

function requireIsFunction () {
	if (hasRequiredIsFunction) return isFunction_1;
	hasRequiredIsFunction = 1;
	var baseGetTag = require_baseGetTag(),
	    isObject = requireIsObject();

	/** `Object#toString` result references. */
	var asyncTag = '[object AsyncFunction]',
	    funcTag = '[object Function]',
	    genTag = '[object GeneratorFunction]',
	    proxyTag = '[object Proxy]';

	/**
	 * Checks if `value` is classified as a `Function` object.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a function, else `false`.
	 * @example
	 *
	 * _.isFunction(_);
	 * // => true
	 *
	 * _.isFunction(/abc/);
	 * // => false
	 */
	function isFunction(value) {
	  if (!isObject(value)) {
	    return false;
	  }
	  // The use of `Object#toString` avoids issues with the `typeof` operator
	  // in Safari 9 which returns 'object' for typed arrays and other constructors.
	  var tag = baseGetTag(value);
	  return tag == funcTag || tag == genTag || tag == asyncTag || tag == proxyTag;
	}

	isFunction_1 = isFunction;
	return isFunction_1;
}

var _coreJsData;
var hasRequired_coreJsData;

function require_coreJsData () {
	if (hasRequired_coreJsData) return _coreJsData;
	hasRequired_coreJsData = 1;
	var root = require_root();

	/** Used to detect overreaching core-js shims. */
	var coreJsData = root['__core-js_shared__'];

	_coreJsData = coreJsData;
	return _coreJsData;
}

var _isMasked;
var hasRequired_isMasked;

function require_isMasked () {
	if (hasRequired_isMasked) return _isMasked;
	hasRequired_isMasked = 1;
	var coreJsData = require_coreJsData();

	/** Used to detect methods masquerading as native. */
	var maskSrcKey = (function() {
	  var uid = /[^.]+$/.exec(coreJsData && coreJsData.keys && coreJsData.keys.IE_PROTO || '');
	  return uid ? ('Symbol(src)_1.' + uid) : '';
	}());

	/**
	 * Checks if `func` has its source masked.
	 *
	 * @private
	 * @param {Function} func The function to check.
	 * @returns {boolean} Returns `true` if `func` is masked, else `false`.
	 */
	function isMasked(func) {
	  return !!maskSrcKey && (maskSrcKey in func);
	}

	_isMasked = isMasked;
	return _isMasked;
}

/** Used for built-in method references. */

var _toSource;
var hasRequired_toSource;

function require_toSource () {
	if (hasRequired_toSource) return _toSource;
	hasRequired_toSource = 1;
	var funcProto = Function.prototype;

	/** Used to resolve the decompiled source of functions. */
	var funcToString = funcProto.toString;

	/**
	 * Converts `func` to its source code.
	 *
	 * @private
	 * @param {Function} func The function to convert.
	 * @returns {string} Returns the source code.
	 */
	function toSource(func) {
	  if (func != null) {
	    try {
	      return funcToString.call(func);
	    } catch (e) {}
	    try {
	      return (func + '');
	    } catch (e) {}
	  }
	  return '';
	}

	_toSource = toSource;
	return _toSource;
}

var _baseIsNative;
var hasRequired_baseIsNative;

function require_baseIsNative () {
	if (hasRequired_baseIsNative) return _baseIsNative;
	hasRequired_baseIsNative = 1;
	var isFunction = requireIsFunction(),
	    isMasked = require_isMasked(),
	    isObject = requireIsObject(),
	    toSource = require_toSource();

	/**
	 * Used to match `RegExp`
	 * [syntax characters](http://ecma-international.org/ecma-262/7.0/#sec-patterns).
	 */
	var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;

	/** Used to detect host constructors (Safari). */
	var reIsHostCtor = /^\[object .+?Constructor\]$/;

	/** Used for built-in method references. */
	var funcProto = Function.prototype,
	    objectProto = Object.prototype;

	/** Used to resolve the decompiled source of functions. */
	var funcToString = funcProto.toString;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/** Used to detect if a method is native. */
	var reIsNative = RegExp('^' +
	  funcToString.call(hasOwnProperty).replace(reRegExpChar, '\\$&')
	  .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
	);

	/**
	 * The base implementation of `_.isNative` without bad shim checks.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a native function,
	 *  else `false`.
	 */
	function baseIsNative(value) {
	  if (!isObject(value) || isMasked(value)) {
	    return false;
	  }
	  var pattern = isFunction(value) ? reIsNative : reIsHostCtor;
	  return pattern.test(toSource(value));
	}

	_baseIsNative = baseIsNative;
	return _baseIsNative;
}

/**
 * Gets the value at `key` of `object`.
 *
 * @private
 * @param {Object} [object] The object to query.
 * @param {string} key The key of the property to get.
 * @returns {*} Returns the property value.
 */

var _getValue;
var hasRequired_getValue;

function require_getValue () {
	if (hasRequired_getValue) return _getValue;
	hasRequired_getValue = 1;
	function getValue(object, key) {
	  return object == null ? undefined : object[key];
	}

	_getValue = getValue;
	return _getValue;
}

var _getNative;
var hasRequired_getNative;

function require_getNative () {
	if (hasRequired_getNative) return _getNative;
	hasRequired_getNative = 1;
	var baseIsNative = require_baseIsNative(),
	    getValue = require_getValue();

	/**
	 * Gets the native function at `key` of `object`.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {string} key The key of the method to get.
	 * @returns {*} Returns the function if it's native, else `undefined`.
	 */
	function getNative(object, key) {
	  var value = getValue(object, key);
	  return baseIsNative(value) ? value : undefined;
	}

	_getNative = getNative;
	return _getNative;
}

var _nativeCreate;
var hasRequired_nativeCreate;

function require_nativeCreate () {
	if (hasRequired_nativeCreate) return _nativeCreate;
	hasRequired_nativeCreate = 1;
	var getNative = require_getNative();

	/* Built-in method references that are verified to be native. */
	var nativeCreate = getNative(Object, 'create');

	_nativeCreate = nativeCreate;
	return _nativeCreate;
}

var _hashClear;
var hasRequired_hashClear;

function require_hashClear () {
	if (hasRequired_hashClear) return _hashClear;
	hasRequired_hashClear = 1;
	var nativeCreate = require_nativeCreate();

	/**
	 * Removes all key-value entries from the hash.
	 *
	 * @private
	 * @name clear
	 * @memberOf Hash
	 */
	function hashClear() {
	  this.__data__ = nativeCreate ? nativeCreate(null) : {};
	  this.size = 0;
	}

	_hashClear = hashClear;
	return _hashClear;
}

/**
 * Removes `key` and its value from the hash.
 *
 * @private
 * @name delete
 * @memberOf Hash
 * @param {Object} hash The hash to modify.
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */

var _hashDelete;
var hasRequired_hashDelete;

function require_hashDelete () {
	if (hasRequired_hashDelete) return _hashDelete;
	hasRequired_hashDelete = 1;
	function hashDelete(key) {
	  var result = this.has(key) && delete this.__data__[key];
	  this.size -= result ? 1 : 0;
	  return result;
	}

	_hashDelete = hashDelete;
	return _hashDelete;
}

var _hashGet;
var hasRequired_hashGet;

function require_hashGet () {
	if (hasRequired_hashGet) return _hashGet;
	hasRequired_hashGet = 1;
	var nativeCreate = require_nativeCreate();

	/** Used to stand-in for `undefined` hash values. */
	var HASH_UNDEFINED = '__lodash_hash_undefined__';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Gets the hash value for `key`.
	 *
	 * @private
	 * @name get
	 * @memberOf Hash
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function hashGet(key) {
	  var data = this.__data__;
	  if (nativeCreate) {
	    var result = data[key];
	    return result === HASH_UNDEFINED ? undefined : result;
	  }
	  return hasOwnProperty.call(data, key) ? data[key] : undefined;
	}

	_hashGet = hashGet;
	return _hashGet;
}

var _hashHas;
var hasRequired_hashHas;

function require_hashHas () {
	if (hasRequired_hashHas) return _hashHas;
	hasRequired_hashHas = 1;
	var nativeCreate = require_nativeCreate();

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Checks if a hash value for `key` exists.
	 *
	 * @private
	 * @name has
	 * @memberOf Hash
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function hashHas(key) {
	  var data = this.__data__;
	  return nativeCreate ? (data[key] !== undefined) : hasOwnProperty.call(data, key);
	}

	_hashHas = hashHas;
	return _hashHas;
}

var _hashSet;
var hasRequired_hashSet;

function require_hashSet () {
	if (hasRequired_hashSet) return _hashSet;
	hasRequired_hashSet = 1;
	var nativeCreate = require_nativeCreate();

	/** Used to stand-in for `undefined` hash values. */
	var HASH_UNDEFINED = '__lodash_hash_undefined__';

	/**
	 * Sets the hash `key` to `value`.
	 *
	 * @private
	 * @name set
	 * @memberOf Hash
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 * @returns {Object} Returns the hash instance.
	 */
	function hashSet(key, value) {
	  var data = this.__data__;
	  this.size += this.has(key) ? 0 : 1;
	  data[key] = (nativeCreate && value === undefined) ? HASH_UNDEFINED : value;
	  return this;
	}

	_hashSet = hashSet;
	return _hashSet;
}

var _Hash;
var hasRequired_Hash;

function require_Hash () {
	if (hasRequired_Hash) return _Hash;
	hasRequired_Hash = 1;
	var hashClear = require_hashClear(),
	    hashDelete = require_hashDelete(),
	    hashGet = require_hashGet(),
	    hashHas = require_hashHas(),
	    hashSet = require_hashSet();

	/**
	 * Creates a hash object.
	 *
	 * @private
	 * @constructor
	 * @param {Array} [entries] The key-value pairs to cache.
	 */
	function Hash(entries) {
	  var index = -1,
	      length = entries == null ? 0 : entries.length;

	  this.clear();
	  while (++index < length) {
	    var entry = entries[index];
	    this.set(entry[0], entry[1]);
	  }
	}

	// Add methods to `Hash`.
	Hash.prototype.clear = hashClear;
	Hash.prototype['delete'] = hashDelete;
	Hash.prototype.get = hashGet;
	Hash.prototype.has = hashHas;
	Hash.prototype.set = hashSet;

	_Hash = Hash;
	return _Hash;
}

/**
 * Removes all key-value entries from the list cache.
 *
 * @private
 * @name clear
 * @memberOf ListCache
 */

var _listCacheClear;
var hasRequired_listCacheClear;

function require_listCacheClear () {
	if (hasRequired_listCacheClear) return _listCacheClear;
	hasRequired_listCacheClear = 1;
	function listCacheClear() {
	  this.__data__ = [];
	  this.size = 0;
	}

	_listCacheClear = listCacheClear;
	return _listCacheClear;
}

/**
 * Performs a
 * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * comparison between two values to determine if they are equivalent.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to compare.
 * @param {*} other The other value to compare.
 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
 * @example
 *
 * var object = { 'a': 1 };
 * var other = { 'a': 1 };
 *
 * _.eq(object, object);
 * // => true
 *
 * _.eq(object, other);
 * // => false
 *
 * _.eq('a', 'a');
 * // => true
 *
 * _.eq('a', Object('a'));
 * // => false
 *
 * _.eq(NaN, NaN);
 * // => true
 */

var eq_1;
var hasRequiredEq;

function requireEq () {
	if (hasRequiredEq) return eq_1;
	hasRequiredEq = 1;
	function eq(value, other) {
	  return value === other || (value !== value && other !== other);
	}

	eq_1 = eq;
	return eq_1;
}

var _assocIndexOf;
var hasRequired_assocIndexOf;

function require_assocIndexOf () {
	if (hasRequired_assocIndexOf) return _assocIndexOf;
	hasRequired_assocIndexOf = 1;
	var eq = requireEq();

	/**
	 * Gets the index at which the `key` is found in `array` of key-value pairs.
	 *
	 * @private
	 * @param {Array} array The array to inspect.
	 * @param {*} key The key to search for.
	 * @returns {number} Returns the index of the matched value, else `-1`.
	 */
	function assocIndexOf(array, key) {
	  var length = array.length;
	  while (length--) {
	    if (eq(array[length][0], key)) {
	      return length;
	    }
	  }
	  return -1;
	}

	_assocIndexOf = assocIndexOf;
	return _assocIndexOf;
}

var _listCacheDelete;
var hasRequired_listCacheDelete;

function require_listCacheDelete () {
	if (hasRequired_listCacheDelete) return _listCacheDelete;
	hasRequired_listCacheDelete = 1;
	var assocIndexOf = require_assocIndexOf();

	/** Used for built-in method references. */
	var arrayProto = Array.prototype;

	/** Built-in value references. */
	var splice = arrayProto.splice;

	/**
	 * Removes `key` and its value from the list cache.
	 *
	 * @private
	 * @name delete
	 * @memberOf ListCache
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function listCacheDelete(key) {
	  var data = this.__data__,
	      index = assocIndexOf(data, key);

	  if (index < 0) {
	    return false;
	  }
	  var lastIndex = data.length - 1;
	  if (index == lastIndex) {
	    data.pop();
	  } else {
	    splice.call(data, index, 1);
	  }
	  --this.size;
	  return true;
	}

	_listCacheDelete = listCacheDelete;
	return _listCacheDelete;
}

var _listCacheGet;
var hasRequired_listCacheGet;

function require_listCacheGet () {
	if (hasRequired_listCacheGet) return _listCacheGet;
	hasRequired_listCacheGet = 1;
	var assocIndexOf = require_assocIndexOf();

	/**
	 * Gets the list cache value for `key`.
	 *
	 * @private
	 * @name get
	 * @memberOf ListCache
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function listCacheGet(key) {
	  var data = this.__data__,
	      index = assocIndexOf(data, key);

	  return index < 0 ? undefined : data[index][1];
	}

	_listCacheGet = listCacheGet;
	return _listCacheGet;
}

var _listCacheHas;
var hasRequired_listCacheHas;

function require_listCacheHas () {
	if (hasRequired_listCacheHas) return _listCacheHas;
	hasRequired_listCacheHas = 1;
	var assocIndexOf = require_assocIndexOf();

	/**
	 * Checks if a list cache value for `key` exists.
	 *
	 * @private
	 * @name has
	 * @memberOf ListCache
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function listCacheHas(key) {
	  return assocIndexOf(this.__data__, key) > -1;
	}

	_listCacheHas = listCacheHas;
	return _listCacheHas;
}

var _listCacheSet;
var hasRequired_listCacheSet;

function require_listCacheSet () {
	if (hasRequired_listCacheSet) return _listCacheSet;
	hasRequired_listCacheSet = 1;
	var assocIndexOf = require_assocIndexOf();

	/**
	 * Sets the list cache `key` to `value`.
	 *
	 * @private
	 * @name set
	 * @memberOf ListCache
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 * @returns {Object} Returns the list cache instance.
	 */
	function listCacheSet(key, value) {
	  var data = this.__data__,
	      index = assocIndexOf(data, key);

	  if (index < 0) {
	    ++this.size;
	    data.push([key, value]);
	  } else {
	    data[index][1] = value;
	  }
	  return this;
	}

	_listCacheSet = listCacheSet;
	return _listCacheSet;
}

var _ListCache;
var hasRequired_ListCache;

function require_ListCache () {
	if (hasRequired_ListCache) return _ListCache;
	hasRequired_ListCache = 1;
	var listCacheClear = require_listCacheClear(),
	    listCacheDelete = require_listCacheDelete(),
	    listCacheGet = require_listCacheGet(),
	    listCacheHas = require_listCacheHas(),
	    listCacheSet = require_listCacheSet();

	/**
	 * Creates an list cache object.
	 *
	 * @private
	 * @constructor
	 * @param {Array} [entries] The key-value pairs to cache.
	 */
	function ListCache(entries) {
	  var index = -1,
	      length = entries == null ? 0 : entries.length;

	  this.clear();
	  while (++index < length) {
	    var entry = entries[index];
	    this.set(entry[0], entry[1]);
	  }
	}

	// Add methods to `ListCache`.
	ListCache.prototype.clear = listCacheClear;
	ListCache.prototype['delete'] = listCacheDelete;
	ListCache.prototype.get = listCacheGet;
	ListCache.prototype.has = listCacheHas;
	ListCache.prototype.set = listCacheSet;

	_ListCache = ListCache;
	return _ListCache;
}

var _Map;
var hasRequired_Map;

function require_Map () {
	if (hasRequired_Map) return _Map;
	hasRequired_Map = 1;
	var getNative = require_getNative(),
	    root = require_root();

	/* Built-in method references that are verified to be native. */
	var Map = getNative(root, 'Map');

	_Map = Map;
	return _Map;
}

var _mapCacheClear;
var hasRequired_mapCacheClear;

function require_mapCacheClear () {
	if (hasRequired_mapCacheClear) return _mapCacheClear;
	hasRequired_mapCacheClear = 1;
	var Hash = require_Hash(),
	    ListCache = require_ListCache(),
	    Map = require_Map();

	/**
	 * Removes all key-value entries from the map.
	 *
	 * @private
	 * @name clear
	 * @memberOf MapCache
	 */
	function mapCacheClear() {
	  this.size = 0;
	  this.__data__ = {
	    'hash': new Hash,
	    'map': new (Map || ListCache),
	    'string': new Hash
	  };
	}

	_mapCacheClear = mapCacheClear;
	return _mapCacheClear;
}

/**
 * Checks if `value` is suitable for use as unique object key.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
 */

var _isKeyable;
var hasRequired_isKeyable;

function require_isKeyable () {
	if (hasRequired_isKeyable) return _isKeyable;
	hasRequired_isKeyable = 1;
	function isKeyable(value) {
	  var type = typeof value;
	  return (type == 'string' || type == 'number' || type == 'symbol' || type == 'boolean')
	    ? (value !== '__proto__')
	    : (value === null);
	}

	_isKeyable = isKeyable;
	return _isKeyable;
}

var _getMapData;
var hasRequired_getMapData;

function require_getMapData () {
	if (hasRequired_getMapData) return _getMapData;
	hasRequired_getMapData = 1;
	var isKeyable = require_isKeyable();

	/**
	 * Gets the data for `map`.
	 *
	 * @private
	 * @param {Object} map The map to query.
	 * @param {string} key The reference key.
	 * @returns {*} Returns the map data.
	 */
	function getMapData(map, key) {
	  var data = map.__data__;
	  return isKeyable(key)
	    ? data[typeof key == 'string' ? 'string' : 'hash']
	    : data.map;
	}

	_getMapData = getMapData;
	return _getMapData;
}

var _mapCacheDelete;
var hasRequired_mapCacheDelete;

function require_mapCacheDelete () {
	if (hasRequired_mapCacheDelete) return _mapCacheDelete;
	hasRequired_mapCacheDelete = 1;
	var getMapData = require_getMapData();

	/**
	 * Removes `key` and its value from the map.
	 *
	 * @private
	 * @name delete
	 * @memberOf MapCache
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function mapCacheDelete(key) {
	  var result = getMapData(this, key)['delete'](key);
	  this.size -= result ? 1 : 0;
	  return result;
	}

	_mapCacheDelete = mapCacheDelete;
	return _mapCacheDelete;
}

var _mapCacheGet;
var hasRequired_mapCacheGet;

function require_mapCacheGet () {
	if (hasRequired_mapCacheGet) return _mapCacheGet;
	hasRequired_mapCacheGet = 1;
	var getMapData = require_getMapData();

	/**
	 * Gets the map value for `key`.
	 *
	 * @private
	 * @name get
	 * @memberOf MapCache
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function mapCacheGet(key) {
	  return getMapData(this, key).get(key);
	}

	_mapCacheGet = mapCacheGet;
	return _mapCacheGet;
}

var _mapCacheHas;
var hasRequired_mapCacheHas;

function require_mapCacheHas () {
	if (hasRequired_mapCacheHas) return _mapCacheHas;
	hasRequired_mapCacheHas = 1;
	var getMapData = require_getMapData();

	/**
	 * Checks if a map value for `key` exists.
	 *
	 * @private
	 * @name has
	 * @memberOf MapCache
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function mapCacheHas(key) {
	  return getMapData(this, key).has(key);
	}

	_mapCacheHas = mapCacheHas;
	return _mapCacheHas;
}

var _mapCacheSet;
var hasRequired_mapCacheSet;

function require_mapCacheSet () {
	if (hasRequired_mapCacheSet) return _mapCacheSet;
	hasRequired_mapCacheSet = 1;
	var getMapData = require_getMapData();

	/**
	 * Sets the map `key` to `value`.
	 *
	 * @private
	 * @name set
	 * @memberOf MapCache
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 * @returns {Object} Returns the map cache instance.
	 */
	function mapCacheSet(key, value) {
	  var data = getMapData(this, key),
	      size = data.size;

	  data.set(key, value);
	  this.size += data.size == size ? 0 : 1;
	  return this;
	}

	_mapCacheSet = mapCacheSet;
	return _mapCacheSet;
}

var _MapCache;
var hasRequired_MapCache;

function require_MapCache () {
	if (hasRequired_MapCache) return _MapCache;
	hasRequired_MapCache = 1;
	var mapCacheClear = require_mapCacheClear(),
	    mapCacheDelete = require_mapCacheDelete(),
	    mapCacheGet = require_mapCacheGet(),
	    mapCacheHas = require_mapCacheHas(),
	    mapCacheSet = require_mapCacheSet();

	/**
	 * Creates a map cache object to store key-value pairs.
	 *
	 * @private
	 * @constructor
	 * @param {Array} [entries] The key-value pairs to cache.
	 */
	function MapCache(entries) {
	  var index = -1,
	      length = entries == null ? 0 : entries.length;

	  this.clear();
	  while (++index < length) {
	    var entry = entries[index];
	    this.set(entry[0], entry[1]);
	  }
	}

	// Add methods to `MapCache`.
	MapCache.prototype.clear = mapCacheClear;
	MapCache.prototype['delete'] = mapCacheDelete;
	MapCache.prototype.get = mapCacheGet;
	MapCache.prototype.has = mapCacheHas;
	MapCache.prototype.set = mapCacheSet;

	_MapCache = MapCache;
	return _MapCache;
}

var memoize_1;
var hasRequiredMemoize;

function requireMemoize () {
	if (hasRequiredMemoize) return memoize_1;
	hasRequiredMemoize = 1;
	var MapCache = require_MapCache();

	/** Error message constants. */
	var FUNC_ERROR_TEXT = 'Expected a function';

	/**
	 * Creates a function that memoizes the result of `func`. If `resolver` is
	 * provided, it determines the cache key for storing the result based on the
	 * arguments provided to the memoized function. By default, the first argument
	 * provided to the memoized function is used as the map cache key. The `func`
	 * is invoked with the `this` binding of the memoized function.
	 *
	 * **Note:** The cache is exposed as the `cache` property on the memoized
	 * function. Its creation may be customized by replacing the `_.memoize.Cache`
	 * constructor with one whose instances implement the
	 * [`Map`](http://ecma-international.org/ecma-262/7.0/#sec-properties-of-the-map-prototype-object)
	 * method interface of `clear`, `delete`, `get`, `has`, and `set`.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Function
	 * @param {Function} func The function to have its output memoized.
	 * @param {Function} [resolver] The function to resolve the cache key.
	 * @returns {Function} Returns the new memoized function.
	 * @example
	 *
	 * var object = { 'a': 1, 'b': 2 };
	 * var other = { 'c': 3, 'd': 4 };
	 *
	 * var values = _.memoize(_.values);
	 * values(object);
	 * // => [1, 2]
	 *
	 * values(other);
	 * // => [3, 4]
	 *
	 * object.a = 2;
	 * values(object);
	 * // => [1, 2]
	 *
	 * // Modify the result cache.
	 * values.cache.set(object, ['a', 'b']);
	 * values(object);
	 * // => ['a', 'b']
	 *
	 * // Replace `_.memoize.Cache`.
	 * _.memoize.Cache = WeakMap;
	 */
	function memoize(func, resolver) {
	  if (typeof func != 'function' || (resolver != null && typeof resolver != 'function')) {
	    throw new TypeError(FUNC_ERROR_TEXT);
	  }
	  var memoized = function() {
	    var args = arguments,
	        key = resolver ? resolver.apply(this, args) : args[0],
	        cache = memoized.cache;

	    if (cache.has(key)) {
	      return cache.get(key);
	    }
	    var result = func.apply(this, args);
	    memoized.cache = cache.set(key, result) || cache;
	    return result;
	  };
	  memoized.cache = new (memoize.Cache || MapCache);
	  return memoized;
	}

	// Expose `MapCache`.
	memoize.Cache = MapCache;

	memoize_1 = memoize;
	return memoize_1;
}

var memoizeExports = requireMemoize();
var memoize$1 = /*@__PURE__*/getDefaultExportFromCjs(memoizeExports);

const pDebounce = (input, options) => {
    const incrementalArgs = [];
    const incrementalResolve = [];
    const fn = async (resolves) => {
        const result = await input(incrementalArgs);
        resolves.forEach((resolve) => {
            resolve(result);
        });
        incrementalResolve.length = 0;
        incrementalArgs.length = 0;
    };
    const debounced = debounce(fn, options?.wait, { maxWait: options?.maxWait });
    return async (item) => {
        if (item !== undefined) {
            incrementalArgs.push(...item);
        }
        return await new Promise((resolve) => {
            incrementalResolve.push(resolve);
            void debounced(incrementalResolve);
        });
    };
};
/**
 * Creates a memoized-debounced function that delays invoking `func` until after `wait` milliseconds
 * have elapsed since the last time the memoized-debounced function was invoked.
 *
 * The function is also **memoized** using all arguments as the map cache key. You can override this
 * default by providing a `resolver` function.
 * @param func The function to debounce.
 * @param wait The number of milliseconds to delay.
 * @param options The options object.
 * @param resolver The function to resolve the cache key (for memoized function).
 * @returns Returns the new memoized function debounced.
 */
function memoDebounce(func, wait = 0, options = {}, resolver = (...args) => JSON.stringify(args)) {
    const debounceMemo = memoize$1((..._args) => debounce(func, wait, options), resolver);
    function wrappedFunction(...args) {
        return debounceMemo(...args)(...args);
    }
    wrappedFunction.flush = (...args) => {
        return debounceMemo(...args).flush();
    };
    wrappedFunction.cancel = (...args) => {
        debounceMemo(...args).cancel();
    };
    return wrappedFunction;
}

/**
 * Dispatch a custom event `type`, providing an array of `args` and a `response`.
 *
 * > **To avoid the same event being fired too often**, it implements a basic debouncing practice:
 * multiple identical events (i.e. with the same `args` and `response`) triggered
 * less than **10ms** one from the other are fired only once (the first time).
 */
const _fireEvent = (type, args, response) => {
    document.dispatchEvent(new CustomEvent(type, {
        detail: {
            request: {
                args,
            },
            response,
        },
    }));
};
const fireEvent = memoDebounce(_fireEvent, 10, {
    leading: true,
    trailing: false,
});
/**
 * Listen to a custom event `type`.
 */
function listenTo(type, listener, options) {
    document.addEventListener(type, function (evt) {
        void listener.apply(this, [
            evt,
        ]);
    }, options);
}

/**
 * Creates an array of elements split into groups the length of `size`. If `array` can't be split evenly, the final chunk will be the remaining elements.
 * @param array The array to process.
 * @param size The length of each chunk.
 * @returns Returns the new array of chunks.
 */
function chunk(array, size = 1) {
    if (size < 1) {
        return [];
    }
    return array.reduce((resultArray, item, index) => {
        const chunkIndex = Math.floor(index / size);
        resultArray[chunkIndex] ||= [];
        resultArray[chunkIndex]?.push(item);
        return resultArray;
    }, []);
}
/**
 * Creates a duplicate-free version of an array.
 * @param array The array to inspect.
 * @returns Returns the new duplicate free array.
 */
function uniq(array) {
    return [...new Set(array)];
}
/**
 * Creates a function that memoizes the result of func.
 * @param func The function to have its output memoized.
 * @returns Returns the new memoized function.
 */
const memoize = (func) => {
    const cache = {};
    return (...args) => {
        const cacheKey = JSON.stringify(args);
        if (cache[cacheKey] === undefined) {
            cache[cacheKey] = func(...args);
        }
        return cache[cacheKey];
    };
};

function y$1(e){return e.replace(/[A-Z]/g,t=>`_${t.toLowerCase()}`)}function l$1(e,t){return Object.keys(e).reduce((n,r)=>{let o=t(r);return n[o]=e[r],n},{})}function T$1(e){return e.replace(/([-_][a-z])/g,t=>t.toUpperCase().replace("-","").replace("_",""))}async function x$1(e,{domain:t="commercelayer.io",headers:n,...r}){let o=l$1({grant_type:e,...r},y$1),c=await(await fetch(`https://auth.${t}/oauth/token`,{method:"POST",headers:{"Content-Type":"application/json",Accept:"application/json",...n},body:JSON.stringify(o)})).json();return c.errors==null&&(c.expires=new Date(Date.now()+c.expires_in*1e3)),l$1(c,T$1)}var s=class extends Error{constructor(t){super(t),this.name="TokenError";}};var a$1=class a extends s{constructor(t){super(t),this.name="InvalidTokenError";}};function u$1(e,t){if(typeof atob<"u"){let n=atob(e.replaceAll("-","+").replaceAll("_","/").padEnd(e.length+(4-e.length%4)%4,"="));if(t==="utf-8"){let r=new Uint8Array([...n].map(o=>o.charCodeAt(0)));return new TextDecoder().decode(r)}return n}return Buffer.from(e,"base64url").toString(t)}function i(e){let[t,n,r]=`${e}`.split(".");if(t==null||n==null||r==null)throw new a$1("Invalid token format");return {header:JSON.parse(u$1(t,"binary")),payload:JSON.parse(u$1(n,"utf-8")),signature:r}}function S$1(e){return e.application.kind==="sales_channel"}function d(e){return e?.payload?.iss?.startsWith("https://auth.")?e.payload.iss:"https://auth.commercelayer.io"}async function A$1(e){let t=l$1(e,y$1),n=i(e.token),r=d(n);return await(await fetch(`${r}/oauth/revoke`,{method:"POST",headers:{"Content-Type":"application/json",Accept:"application/json"},body:JSON.stringify(t)})).json()}

var cjs$1 = {};

var cjs = {};

var hasRequiredCjs$1;

function requireCjs$1 () {
	if (hasRequiredCjs$1) return cjs;
	hasRequiredCjs$1 = 1;

	function getType(payload) {
	  return Object.prototype.toString.call(payload).slice(8, -1);
	}

	function isAnyObject(payload) {
	  return getType(payload) === "Object";
	}

	function isArray(payload) {
	  return getType(payload) === "Array";
	}

	function isBlob(payload) {
	  return getType(payload) === "Blob";
	}

	function isBoolean(payload) {
	  return getType(payload) === "Boolean";
	}

	function isDate(payload) {
	  return getType(payload) === "Date" && !isNaN(payload);
	}

	function isEmptyArray(payload) {
	  return isArray(payload) && payload.length === 0;
	}

	function isPlainObject(payload) {
	  if (getType(payload) !== "Object")
	    return false;
	  const prototype = Object.getPrototypeOf(payload);
	  return !!prototype && prototype.constructor === Object && prototype === Object.prototype;
	}

	function isEmptyObject(payload) {
	  return isPlainObject(payload) && Object.keys(payload).length === 0;
	}

	function isEmptyString(payload) {
	  return payload === "";
	}

	function isError(payload) {
	  return getType(payload) === "Error" || payload instanceof Error;
	}

	function isFile(payload) {
	  return getType(payload) === "File";
	}

	function isFullArray(payload) {
	  return isArray(payload) && payload.length > 0;
	}

	function isFullObject(payload) {
	  return isPlainObject(payload) && Object.keys(payload).length > 0;
	}

	function isString(payload) {
	  return getType(payload) === "String";
	}

	function isFullString(payload) {
	  return isString(payload) && payload !== "";
	}

	function isFunction(payload) {
	  return typeof payload === "function";
	}

	function isType(payload, type) {
	  if (!(type instanceof Function)) {
	    throw new TypeError("Type must be a function");
	  }
	  if (!Object.prototype.hasOwnProperty.call(type, "prototype")) {
	    throw new TypeError("Type is not a class");
	  }
	  const name = type.name;
	  return getType(payload) === name || Boolean(payload && payload.constructor === type);
	}

	function isInstanceOf(value, classOrClassName) {
	  if (typeof classOrClassName === "function") {
	    for (let p = value; p; p = Object.getPrototypeOf(p)) {
	      if (isType(p, classOrClassName)) {
	        return true;
	      }
	    }
	    return false;
	  } else {
	    for (let p = value; p; p = Object.getPrototypeOf(p)) {
	      if (getType(p) === classOrClassName) {
	        return true;
	      }
	    }
	    return false;
	  }
	}

	function isMap(payload) {
	  return getType(payload) === "Map";
	}

	function isNaNValue(payload) {
	  return getType(payload) === "Number" && isNaN(payload);
	}

	function isNumber(payload) {
	  return getType(payload) === "Number" && !isNaN(payload);
	}

	function isNegativeNumber(payload) {
	  return isNumber(payload) && payload < 0;
	}

	function isNull(payload) {
	  return getType(payload) === "Null";
	}

	function isOneOf(a, b, c, d, e) {
	  return (value) => a(value) || b(value) || !!c && c(value) || !!d && d(value) || !!e && e(value);
	}

	function isUndefined(payload) {
	  return getType(payload) === "Undefined";
	}

	const isNullOrUndefined = isOneOf(isNull, isUndefined);

	function isObject(payload) {
	  return isPlainObject(payload);
	}

	function isObjectLike(payload) {
	  return isAnyObject(payload);
	}

	function isPositiveNumber(payload) {
	  return isNumber(payload) && payload > 0;
	}

	function isSymbol(payload) {
	  return getType(payload) === "Symbol";
	}

	function isPrimitive(payload) {
	  return isBoolean(payload) || isNull(payload) || isUndefined(payload) || isNumber(payload) || isString(payload) || isSymbol(payload);
	}

	function isPromise(payload) {
	  return getType(payload) === "Promise";
	}

	function isRegExp(payload) {
	  return getType(payload) === "RegExp";
	}

	function isSet(payload) {
	  return getType(payload) === "Set";
	}

	function isWeakMap(payload) {
	  return getType(payload) === "WeakMap";
	}

	function isWeakSet(payload) {
	  return getType(payload) === "WeakSet";
	}

	cjs.getType = getType;
	cjs.isAnyObject = isAnyObject;
	cjs.isArray = isArray;
	cjs.isBlob = isBlob;
	cjs.isBoolean = isBoolean;
	cjs.isDate = isDate;
	cjs.isEmptyArray = isEmptyArray;
	cjs.isEmptyObject = isEmptyObject;
	cjs.isEmptyString = isEmptyString;
	cjs.isError = isError;
	cjs.isFile = isFile;
	cjs.isFullArray = isFullArray;
	cjs.isFullObject = isFullObject;
	cjs.isFullString = isFullString;
	cjs.isFunction = isFunction;
	cjs.isInstanceOf = isInstanceOf;
	cjs.isMap = isMap;
	cjs.isNaNValue = isNaNValue;
	cjs.isNegativeNumber = isNegativeNumber;
	cjs.isNull = isNull;
	cjs.isNullOrUndefined = isNullOrUndefined;
	cjs.isNumber = isNumber;
	cjs.isObject = isObject;
	cjs.isObjectLike = isObjectLike;
	cjs.isOneOf = isOneOf;
	cjs.isPlainObject = isPlainObject;
	cjs.isPositiveNumber = isPositiveNumber;
	cjs.isPrimitive = isPrimitive;
	cjs.isPromise = isPromise;
	cjs.isRegExp = isRegExp;
	cjs.isSet = isSet;
	cjs.isString = isString;
	cjs.isSymbol = isSymbol;
	cjs.isType = isType;
	cjs.isUndefined = isUndefined;
	cjs.isWeakMap = isWeakMap;
	cjs.isWeakSet = isWeakSet;
	return cjs;
}

var hasRequiredCjs;

function requireCjs () {
	if (hasRequiredCjs) return cjs$1;
	hasRequiredCjs = 1;

	const isWhat = /*@__PURE__*/ requireCjs$1();

	function concatArrays(originVal, newVal) {
	  if (isWhat.isArray(originVal) && isWhat.isArray(newVal)) {
	    return originVal.concat(newVal);
	  }
	  return newVal;
	}

	function assignProp(carry, key, newVal, originalObject) {
	  const propType = {}.propertyIsEnumerable.call(originalObject, key) ? "enumerable" : "nonenumerable";
	  if (propType === "enumerable")
	    carry[key] = newVal;
	  if (propType === "nonenumerable") {
	    Object.defineProperty(carry, key, {
	      value: newVal,
	      enumerable: false,
	      writable: true,
	      configurable: true
	    });
	  }
	}
	function mergeRecursively(origin, newComer, compareFn) {
	  if (!isWhat.isPlainObject(newComer))
	    return newComer;
	  let newObject = {};
	  if (isWhat.isPlainObject(origin)) {
	    const props2 = Object.getOwnPropertyNames(origin);
	    const symbols2 = Object.getOwnPropertySymbols(origin);
	    newObject = [...props2, ...symbols2].reduce((carry, key) => {
	      const targetVal = origin[key];
	      if (!isWhat.isSymbol(key) && !Object.getOwnPropertyNames(newComer).includes(key) || isWhat.isSymbol(key) && !Object.getOwnPropertySymbols(newComer).includes(key)) {
	        assignProp(
	          carry,
	          key,
	          targetVal,
	          origin
	        );
	      }
	      return carry;
	    }, {});
	  }
	  const props = Object.getOwnPropertyNames(newComer);
	  const symbols = Object.getOwnPropertySymbols(newComer);
	  const result = [...props, ...symbols].reduce((carry, key) => {
	    let newVal = newComer[key];
	    const targetVal = isWhat.isPlainObject(origin) ? origin[key] : void 0;
	    if (targetVal !== void 0 && isWhat.isPlainObject(newVal)) {
	      newVal = mergeRecursively(targetVal, newVal, compareFn);
	    }
	    const propToAssign = compareFn ? compareFn(targetVal, newVal, key) : newVal;
	    assignProp(
	      carry,
	      key,
	      propToAssign,
	      newComer
	    );
	    return carry;
	  }, newObject);
	  return result;
	}
	function merge(object, ...otherObjects) {
	  return otherObjects.reduce((result, newComer) => {
	    return mergeRecursively(result, newComer);
	  }, object);
	}
	function mergeAndCompare(compareFn, object, ...otherObjects) {
	  return otherObjects.reduce((result, newComer) => {
	    return mergeRecursively(result, newComer, compareFn);
	  }, object);
	}
	function mergeAndConcat(object, ...otherObjects) {
	  return otherObjects.reduce((result, newComer) => {
	    return mergeRecursively(result, newComer, concatArrays);
	  }, object);
	}

	cjs$1.concatArrays = concatArrays;
	cjs$1.merge = merge;
	cjs$1.mergeAndCompare = mergeAndCompare;
	cjs$1.mergeAndConcat = mergeAndConcat;
	return cjs$1;
}

var cjsExports = /*@__PURE__*/ requireCjs();

function I$1({jsonConfig:l,market:t,params:e}){var n,i,f;if((l==null?void 0:l.mfe)==null)return null;let N=(i=(n=l==null?void 0:l.mfe)==null?void 0:n.default)!=null?i:{},k=t!=null?(f=l==null?void 0:l.mfe[t])!=null?f:{}:{};function M(T){var u,g,o,r,c,d,y;let b=JSON.stringify(T).replace(/:lang/g,(u=e==null?void 0:e.lang)!=null?u:":lang").replace(/:slug/g,(g=e==null?void 0:e.slug)!=null?g:":slug").replace(/:token/g,(o=e==null?void 0:e.token)!=null?o:":token").replace(/:access_token/g,(r=e==null?void 0:e.accessToken)!=null?r:":access_token").replace(/:order_id/g,(c=e==null?void 0:e.orderId)!=null?c:":order_id").replace(/:sku_list_id/g,(d=e==null?void 0:e.skuListId)!=null?d:":sku_list_id").replace(/:sku_id/g,(y=e==null?void 0:e.skuId)!=null?y:":sku_id");return JSON.parse(b)}let C=cjsExports.merge(JSON.parse(JSON.stringify(N)),k);return M(C)}

var _stackClear;
var hasRequired_stackClear;

function require_stackClear () {
	if (hasRequired_stackClear) return _stackClear;
	hasRequired_stackClear = 1;
	var ListCache = require_ListCache();

	/**
	 * Removes all key-value entries from the stack.
	 *
	 * @private
	 * @name clear
	 * @memberOf Stack
	 */
	function stackClear() {
	  this.__data__ = new ListCache;
	  this.size = 0;
	}

	_stackClear = stackClear;
	return _stackClear;
}

/**
 * Removes `key` and its value from the stack.
 *
 * @private
 * @name delete
 * @memberOf Stack
 * @param {string} key The key of the value to remove.
 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
 */

var _stackDelete;
var hasRequired_stackDelete;

function require_stackDelete () {
	if (hasRequired_stackDelete) return _stackDelete;
	hasRequired_stackDelete = 1;
	function stackDelete(key) {
	  var data = this.__data__,
	      result = data['delete'](key);

	  this.size = data.size;
	  return result;
	}

	_stackDelete = stackDelete;
	return _stackDelete;
}

/**
 * Gets the stack value for `key`.
 *
 * @private
 * @name get
 * @memberOf Stack
 * @param {string} key The key of the value to get.
 * @returns {*} Returns the entry value.
 */

var _stackGet;
var hasRequired_stackGet;

function require_stackGet () {
	if (hasRequired_stackGet) return _stackGet;
	hasRequired_stackGet = 1;
	function stackGet(key) {
	  return this.__data__.get(key);
	}

	_stackGet = stackGet;
	return _stackGet;
}

/**
 * Checks if a stack value for `key` exists.
 *
 * @private
 * @name has
 * @memberOf Stack
 * @param {string} key The key of the entry to check.
 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
 */

var _stackHas;
var hasRequired_stackHas;

function require_stackHas () {
	if (hasRequired_stackHas) return _stackHas;
	hasRequired_stackHas = 1;
	function stackHas(key) {
	  return this.__data__.has(key);
	}

	_stackHas = stackHas;
	return _stackHas;
}

var _stackSet;
var hasRequired_stackSet;

function require_stackSet () {
	if (hasRequired_stackSet) return _stackSet;
	hasRequired_stackSet = 1;
	var ListCache = require_ListCache(),
	    Map = require_Map(),
	    MapCache = require_MapCache();

	/** Used as the size to enable large array optimizations. */
	var LARGE_ARRAY_SIZE = 200;

	/**
	 * Sets the stack `key` to `value`.
	 *
	 * @private
	 * @name set
	 * @memberOf Stack
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 * @returns {Object} Returns the stack cache instance.
	 */
	function stackSet(key, value) {
	  var data = this.__data__;
	  if (data instanceof ListCache) {
	    var pairs = data.__data__;
	    if (!Map || (pairs.length < LARGE_ARRAY_SIZE - 1)) {
	      pairs.push([key, value]);
	      this.size = ++data.size;
	      return this;
	    }
	    data = this.__data__ = new MapCache(pairs);
	  }
	  data.set(key, value);
	  this.size = data.size;
	  return this;
	}

	_stackSet = stackSet;
	return _stackSet;
}

var _Stack;
var hasRequired_Stack;

function require_Stack () {
	if (hasRequired_Stack) return _Stack;
	hasRequired_Stack = 1;
	var ListCache = require_ListCache(),
	    stackClear = require_stackClear(),
	    stackDelete = require_stackDelete(),
	    stackGet = require_stackGet(),
	    stackHas = require_stackHas(),
	    stackSet = require_stackSet();

	/**
	 * Creates a stack cache object to store key-value pairs.
	 *
	 * @private
	 * @constructor
	 * @param {Array} [entries] The key-value pairs to cache.
	 */
	function Stack(entries) {
	  var data = this.__data__ = new ListCache(entries);
	  this.size = data.size;
	}

	// Add methods to `Stack`.
	Stack.prototype.clear = stackClear;
	Stack.prototype['delete'] = stackDelete;
	Stack.prototype.get = stackGet;
	Stack.prototype.has = stackHas;
	Stack.prototype.set = stackSet;

	_Stack = Stack;
	return _Stack;
}

var _defineProperty;
var hasRequired_defineProperty;

function require_defineProperty () {
	if (hasRequired_defineProperty) return _defineProperty;
	hasRequired_defineProperty = 1;
	var getNative = require_getNative();

	var defineProperty = (function() {
	  try {
	    var func = getNative(Object, 'defineProperty');
	    func({}, '', {});
	    return func;
	  } catch (e) {}
	}());

	_defineProperty = defineProperty;
	return _defineProperty;
}

var _baseAssignValue;
var hasRequired_baseAssignValue;

function require_baseAssignValue () {
	if (hasRequired_baseAssignValue) return _baseAssignValue;
	hasRequired_baseAssignValue = 1;
	var defineProperty = require_defineProperty();

	/**
	 * The base implementation of `assignValue` and `assignMergeValue` without
	 * value checks.
	 *
	 * @private
	 * @param {Object} object The object to modify.
	 * @param {string} key The key of the property to assign.
	 * @param {*} value The value to assign.
	 */
	function baseAssignValue(object, key, value) {
	  if (key == '__proto__' && defineProperty) {
	    defineProperty(object, key, {
	      'configurable': true,
	      'enumerable': true,
	      'value': value,
	      'writable': true
	    });
	  } else {
	    object[key] = value;
	  }
	}

	_baseAssignValue = baseAssignValue;
	return _baseAssignValue;
}

var _assignMergeValue;
var hasRequired_assignMergeValue;

function require_assignMergeValue () {
	if (hasRequired_assignMergeValue) return _assignMergeValue;
	hasRequired_assignMergeValue = 1;
	var baseAssignValue = require_baseAssignValue(),
	    eq = requireEq();

	/**
	 * This function is like `assignValue` except that it doesn't assign
	 * `undefined` values.
	 *
	 * @private
	 * @param {Object} object The object to modify.
	 * @param {string} key The key of the property to assign.
	 * @param {*} value The value to assign.
	 */
	function assignMergeValue(object, key, value) {
	  if ((value !== undefined && !eq(object[key], value)) ||
	      (value === undefined && !(key in object))) {
	    baseAssignValue(object, key, value);
	  }
	}

	_assignMergeValue = assignMergeValue;
	return _assignMergeValue;
}

/**
 * Creates a base function for methods like `_.forIn` and `_.forOwn`.
 *
 * @private
 * @param {boolean} [fromRight] Specify iterating from right to left.
 * @returns {Function} Returns the new base function.
 */

var _createBaseFor;
var hasRequired_createBaseFor;

function require_createBaseFor () {
	if (hasRequired_createBaseFor) return _createBaseFor;
	hasRequired_createBaseFor = 1;
	function createBaseFor(fromRight) {
	  return function(object, iteratee, keysFunc) {
	    var index = -1,
	        iterable = Object(object),
	        props = keysFunc(object),
	        length = props.length;

	    while (length--) {
	      var key = props[fromRight ? length : ++index];
	      if (iteratee(iterable[key], key, iterable) === false) {
	        break;
	      }
	    }
	    return object;
	  };
	}

	_createBaseFor = createBaseFor;
	return _createBaseFor;
}

var _baseFor;
var hasRequired_baseFor;

function require_baseFor () {
	if (hasRequired_baseFor) return _baseFor;
	hasRequired_baseFor = 1;
	var createBaseFor = require_createBaseFor();

	/**
	 * The base implementation of `baseForOwn` which iterates over `object`
	 * properties returned by `keysFunc` and invokes `iteratee` for each property.
	 * Iteratee functions may exit iteration early by explicitly returning `false`.
	 *
	 * @private
	 * @param {Object} object The object to iterate over.
	 * @param {Function} iteratee The function invoked per iteration.
	 * @param {Function} keysFunc The function to get the keys of `object`.
	 * @returns {Object} Returns `object`.
	 */
	var baseFor = createBaseFor();

	_baseFor = baseFor;
	return _baseFor;
}

var _cloneBuffer = {exports: {}};

var hasRequired_cloneBuffer;

function require_cloneBuffer () {
	if (hasRequired_cloneBuffer) return _cloneBuffer.exports;
	hasRequired_cloneBuffer = 1;
	(function (module, exports) {
		var root = require_root();

		/** Detect free variable `exports`. */
		var freeExports = exports && !exports.nodeType && exports;

		/** Detect free variable `module`. */
		var freeModule = freeExports && 'object' == 'object' && module && !module.nodeType && module;

		/** Detect the popular CommonJS extension `module.exports`. */
		var moduleExports = freeModule && freeModule.exports === freeExports;

		/** Built-in value references. */
		var Buffer = moduleExports ? root.Buffer : undefined,
		    allocUnsafe = Buffer ? Buffer.allocUnsafe : undefined;

		/**
		 * Creates a clone of  `buffer`.
		 *
		 * @private
		 * @param {Buffer} buffer The buffer to clone.
		 * @param {boolean} [isDeep] Specify a deep clone.
		 * @returns {Buffer} Returns the cloned buffer.
		 */
		function cloneBuffer(buffer, isDeep) {
		  if (isDeep) {
		    return buffer.slice();
		  }
		  var length = buffer.length,
		      result = allocUnsafe ? allocUnsafe(length) : new buffer.constructor(length);

		  buffer.copy(result);
		  return result;
		}

		module.exports = cloneBuffer; 
	} (_cloneBuffer, _cloneBuffer.exports));
	return _cloneBuffer.exports;
}

var _Uint8Array;
var hasRequired_Uint8Array;

function require_Uint8Array () {
	if (hasRequired_Uint8Array) return _Uint8Array;
	hasRequired_Uint8Array = 1;
	var root = require_root();

	/** Built-in value references. */
	var Uint8Array = root.Uint8Array;

	_Uint8Array = Uint8Array;
	return _Uint8Array;
}

var _cloneArrayBuffer;
var hasRequired_cloneArrayBuffer;

function require_cloneArrayBuffer () {
	if (hasRequired_cloneArrayBuffer) return _cloneArrayBuffer;
	hasRequired_cloneArrayBuffer = 1;
	var Uint8Array = require_Uint8Array();

	/**
	 * Creates a clone of `arrayBuffer`.
	 *
	 * @private
	 * @param {ArrayBuffer} arrayBuffer The array buffer to clone.
	 * @returns {ArrayBuffer} Returns the cloned array buffer.
	 */
	function cloneArrayBuffer(arrayBuffer) {
	  var result = new arrayBuffer.constructor(arrayBuffer.byteLength);
	  new Uint8Array(result).set(new Uint8Array(arrayBuffer));
	  return result;
	}

	_cloneArrayBuffer = cloneArrayBuffer;
	return _cloneArrayBuffer;
}

var _cloneTypedArray;
var hasRequired_cloneTypedArray;

function require_cloneTypedArray () {
	if (hasRequired_cloneTypedArray) return _cloneTypedArray;
	hasRequired_cloneTypedArray = 1;
	var cloneArrayBuffer = require_cloneArrayBuffer();

	/**
	 * Creates a clone of `typedArray`.
	 *
	 * @private
	 * @param {Object} typedArray The typed array to clone.
	 * @param {boolean} [isDeep] Specify a deep clone.
	 * @returns {Object} Returns the cloned typed array.
	 */
	function cloneTypedArray(typedArray, isDeep) {
	  var buffer = isDeep ? cloneArrayBuffer(typedArray.buffer) : typedArray.buffer;
	  return new typedArray.constructor(buffer, typedArray.byteOffset, typedArray.length);
	}

	_cloneTypedArray = cloneTypedArray;
	return _cloneTypedArray;
}

/**
 * Copies the values of `source` to `array`.
 *
 * @private
 * @param {Array} source The array to copy values from.
 * @param {Array} [array=[]] The array to copy values to.
 * @returns {Array} Returns `array`.
 */

var _copyArray;
var hasRequired_copyArray;

function require_copyArray () {
	if (hasRequired_copyArray) return _copyArray;
	hasRequired_copyArray = 1;
	function copyArray(source, array) {
	  var index = -1,
	      length = source.length;

	  array || (array = Array(length));
	  while (++index < length) {
	    array[index] = source[index];
	  }
	  return array;
	}

	_copyArray = copyArray;
	return _copyArray;
}

var _baseCreate;
var hasRequired_baseCreate;

function require_baseCreate () {
	if (hasRequired_baseCreate) return _baseCreate;
	hasRequired_baseCreate = 1;
	var isObject = requireIsObject();

	/** Built-in value references. */
	var objectCreate = Object.create;

	/**
	 * The base implementation of `_.create` without support for assigning
	 * properties to the created object.
	 *
	 * @private
	 * @param {Object} proto The object to inherit from.
	 * @returns {Object} Returns the new object.
	 */
	var baseCreate = (function() {
	  function object() {}
	  return function(proto) {
	    if (!isObject(proto)) {
	      return {};
	    }
	    if (objectCreate) {
	      return objectCreate(proto);
	    }
	    object.prototype = proto;
	    var result = new object;
	    object.prototype = undefined;
	    return result;
	  };
	}());

	_baseCreate = baseCreate;
	return _baseCreate;
}

/**
 * Creates a unary function that invokes `func` with its argument transformed.
 *
 * @private
 * @param {Function} func The function to wrap.
 * @param {Function} transform The argument transform.
 * @returns {Function} Returns the new function.
 */

var _overArg;
var hasRequired_overArg;

function require_overArg () {
	if (hasRequired_overArg) return _overArg;
	hasRequired_overArg = 1;
	function overArg(func, transform) {
	  return function(arg) {
	    return func(transform(arg));
	  };
	}

	_overArg = overArg;
	return _overArg;
}

var _getPrototype;
var hasRequired_getPrototype;

function require_getPrototype () {
	if (hasRequired_getPrototype) return _getPrototype;
	hasRequired_getPrototype = 1;
	var overArg = require_overArg();

	/** Built-in value references. */
	var getPrototype = overArg(Object.getPrototypeOf, Object);

	_getPrototype = getPrototype;
	return _getPrototype;
}

/** Used for built-in method references. */

var _isPrototype;
var hasRequired_isPrototype;

function require_isPrototype () {
	if (hasRequired_isPrototype) return _isPrototype;
	hasRequired_isPrototype = 1;
	var objectProto = Object.prototype;

	/**
	 * Checks if `value` is likely a prototype object.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
	 */
	function isPrototype(value) {
	  var Ctor = value && value.constructor,
	      proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto;

	  return value === proto;
	}

	_isPrototype = isPrototype;
	return _isPrototype;
}

var _initCloneObject;
var hasRequired_initCloneObject;

function require_initCloneObject () {
	if (hasRequired_initCloneObject) return _initCloneObject;
	hasRequired_initCloneObject = 1;
	var baseCreate = require_baseCreate(),
	    getPrototype = require_getPrototype(),
	    isPrototype = require_isPrototype();

	/**
	 * Initializes an object clone.
	 *
	 * @private
	 * @param {Object} object The object to clone.
	 * @returns {Object} Returns the initialized clone.
	 */
	function initCloneObject(object) {
	  return (typeof object.constructor == 'function' && !isPrototype(object))
	    ? baseCreate(getPrototype(object))
	    : {};
	}

	_initCloneObject = initCloneObject;
	return _initCloneObject;
}

var _baseIsArguments;
var hasRequired_baseIsArguments;

function require_baseIsArguments () {
	if (hasRequired_baseIsArguments) return _baseIsArguments;
	hasRequired_baseIsArguments = 1;
	var baseGetTag = require_baseGetTag(),
	    isObjectLike = requireIsObjectLike();

	/** `Object#toString` result references. */
	var argsTag = '[object Arguments]';

	/**
	 * The base implementation of `_.isArguments`.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
	 */
	function baseIsArguments(value) {
	  return isObjectLike(value) && baseGetTag(value) == argsTag;
	}

	_baseIsArguments = baseIsArguments;
	return _baseIsArguments;
}

var isArguments_1;
var hasRequiredIsArguments;

function requireIsArguments () {
	if (hasRequiredIsArguments) return isArguments_1;
	hasRequiredIsArguments = 1;
	var baseIsArguments = require_baseIsArguments(),
	    isObjectLike = requireIsObjectLike();

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/** Built-in value references. */
	var propertyIsEnumerable = objectProto.propertyIsEnumerable;

	/**
	 * Checks if `value` is likely an `arguments` object.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is an `arguments` object,
	 *  else `false`.
	 * @example
	 *
	 * _.isArguments(function() { return arguments; }());
	 * // => true
	 *
	 * _.isArguments([1, 2, 3]);
	 * // => false
	 */
	var isArguments = baseIsArguments(function() { return arguments; }()) ? baseIsArguments : function(value) {
	  return isObjectLike(value) && hasOwnProperty.call(value, 'callee') &&
	    !propertyIsEnumerable.call(value, 'callee');
	};

	isArguments_1 = isArguments;
	return isArguments_1;
}

/**
 * Checks if `value` is classified as an `Array` object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array, else `false`.
 * @example
 *
 * _.isArray([1, 2, 3]);
 * // => true
 *
 * _.isArray(document.body.children);
 * // => false
 *
 * _.isArray('abc');
 * // => false
 *
 * _.isArray(_.noop);
 * // => false
 */

var isArray_1;
var hasRequiredIsArray;

function requireIsArray () {
	if (hasRequiredIsArray) return isArray_1;
	hasRequiredIsArray = 1;
	var isArray = Array.isArray;

	isArray_1 = isArray;
	return isArray_1;
}

/** Used as references for various `Number` constants. */

var isLength_1;
var hasRequiredIsLength;

function requireIsLength () {
	if (hasRequiredIsLength) return isLength_1;
	hasRequiredIsLength = 1;
	var MAX_SAFE_INTEGER = 9007199254740991;

	/**
	 * Checks if `value` is a valid array-like length.
	 *
	 * **Note:** This method is loosely based on
	 * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a valid length, else `false`.
	 * @example
	 *
	 * _.isLength(3);
	 * // => true
	 *
	 * _.isLength(Number.MIN_VALUE);
	 * // => false
	 *
	 * _.isLength(Infinity);
	 * // => false
	 *
	 * _.isLength('3');
	 * // => false
	 */
	function isLength(value) {
	  return typeof value == 'number' &&
	    value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
	}

	isLength_1 = isLength;
	return isLength_1;
}

var isArrayLike_1;
var hasRequiredIsArrayLike;

function requireIsArrayLike () {
	if (hasRequiredIsArrayLike) return isArrayLike_1;
	hasRequiredIsArrayLike = 1;
	var isFunction = requireIsFunction(),
	    isLength = requireIsLength();

	/**
	 * Checks if `value` is array-like. A value is considered array-like if it's
	 * not a function and has a `value.length` that's an integer greater than or
	 * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
	 * @example
	 *
	 * _.isArrayLike([1, 2, 3]);
	 * // => true
	 *
	 * _.isArrayLike(document.body.children);
	 * // => true
	 *
	 * _.isArrayLike('abc');
	 * // => true
	 *
	 * _.isArrayLike(_.noop);
	 * // => false
	 */
	function isArrayLike(value) {
	  return value != null && isLength(value.length) && !isFunction(value);
	}

	isArrayLike_1 = isArrayLike;
	return isArrayLike_1;
}

var isArrayLikeObject_1;
var hasRequiredIsArrayLikeObject;

function requireIsArrayLikeObject () {
	if (hasRequiredIsArrayLikeObject) return isArrayLikeObject_1;
	hasRequiredIsArrayLikeObject = 1;
	var isArrayLike = requireIsArrayLike(),
	    isObjectLike = requireIsObjectLike();

	/**
	 * This method is like `_.isArrayLike` except that it also checks if `value`
	 * is an object.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is an array-like object,
	 *  else `false`.
	 * @example
	 *
	 * _.isArrayLikeObject([1, 2, 3]);
	 * // => true
	 *
	 * _.isArrayLikeObject(document.body.children);
	 * // => true
	 *
	 * _.isArrayLikeObject('abc');
	 * // => false
	 *
	 * _.isArrayLikeObject(_.noop);
	 * // => false
	 */
	function isArrayLikeObject(value) {
	  return isObjectLike(value) && isArrayLike(value);
	}

	isArrayLikeObject_1 = isArrayLikeObject;
	return isArrayLikeObject_1;
}

var isBuffer = {exports: {}};

/**
 * This method returns `false`.
 *
 * @static
 * @memberOf _
 * @since 4.13.0
 * @category Util
 * @returns {boolean} Returns `false`.
 * @example
 *
 * _.times(2, _.stubFalse);
 * // => [false, false]
 */

var stubFalse_1;
var hasRequiredStubFalse;

function requireStubFalse () {
	if (hasRequiredStubFalse) return stubFalse_1;
	hasRequiredStubFalse = 1;
	function stubFalse() {
	  return false;
	}

	stubFalse_1 = stubFalse;
	return stubFalse_1;
}

var hasRequiredIsBuffer;

function requireIsBuffer () {
	if (hasRequiredIsBuffer) return isBuffer.exports;
	hasRequiredIsBuffer = 1;
	(function (module, exports) {
		var root = require_root(),
		    stubFalse = requireStubFalse();

		/** Detect free variable `exports`. */
		var freeExports = exports && !exports.nodeType && exports;

		/** Detect free variable `module`. */
		var freeModule = freeExports && 'object' == 'object' && module && !module.nodeType && module;

		/** Detect the popular CommonJS extension `module.exports`. */
		var moduleExports = freeModule && freeModule.exports === freeExports;

		/** Built-in value references. */
		var Buffer = moduleExports ? root.Buffer : undefined;

		/* Built-in method references for those with the same name as other `lodash` methods. */
		var nativeIsBuffer = Buffer ? Buffer.isBuffer : undefined;

		/**
		 * Checks if `value` is a buffer.
		 *
		 * @static
		 * @memberOf _
		 * @since 4.3.0
		 * @category Lang
		 * @param {*} value The value to check.
		 * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
		 * @example
		 *
		 * _.isBuffer(new Buffer(2));
		 * // => true
		 *
		 * _.isBuffer(new Uint8Array(2));
		 * // => false
		 */
		var isBuffer = nativeIsBuffer || stubFalse;

		module.exports = isBuffer; 
	} (isBuffer, isBuffer.exports));
	return isBuffer.exports;
}

var isPlainObject_1;
var hasRequiredIsPlainObject;

function requireIsPlainObject () {
	if (hasRequiredIsPlainObject) return isPlainObject_1;
	hasRequiredIsPlainObject = 1;
	var baseGetTag = require_baseGetTag(),
	    getPrototype = require_getPrototype(),
	    isObjectLike = requireIsObjectLike();

	/** `Object#toString` result references. */
	var objectTag = '[object Object]';

	/** Used for built-in method references. */
	var funcProto = Function.prototype,
	    objectProto = Object.prototype;

	/** Used to resolve the decompiled source of functions. */
	var funcToString = funcProto.toString;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/** Used to infer the `Object` constructor. */
	var objectCtorString = funcToString.call(Object);

	/**
	 * Checks if `value` is a plain object, that is, an object created by the
	 * `Object` constructor or one with a `[[Prototype]]` of `null`.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.8.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
	 * @example
	 *
	 * function Foo() {
	 *   this.a = 1;
	 * }
	 *
	 * _.isPlainObject(new Foo);
	 * // => false
	 *
	 * _.isPlainObject([1, 2, 3]);
	 * // => false
	 *
	 * _.isPlainObject({ 'x': 0, 'y': 0 });
	 * // => true
	 *
	 * _.isPlainObject(Object.create(null));
	 * // => true
	 */
	function isPlainObject(value) {
	  if (!isObjectLike(value) || baseGetTag(value) != objectTag) {
	    return false;
	  }
	  var proto = getPrototype(value);
	  if (proto === null) {
	    return true;
	  }
	  var Ctor = hasOwnProperty.call(proto, 'constructor') && proto.constructor;
	  return typeof Ctor == 'function' && Ctor instanceof Ctor &&
	    funcToString.call(Ctor) == objectCtorString;
	}

	isPlainObject_1 = isPlainObject;
	return isPlainObject_1;
}

var _baseIsTypedArray;
var hasRequired_baseIsTypedArray;

function require_baseIsTypedArray () {
	if (hasRequired_baseIsTypedArray) return _baseIsTypedArray;
	hasRequired_baseIsTypedArray = 1;
	var baseGetTag = require_baseGetTag(),
	    isLength = requireIsLength(),
	    isObjectLike = requireIsObjectLike();

	/** `Object#toString` result references. */
	var argsTag = '[object Arguments]',
	    arrayTag = '[object Array]',
	    boolTag = '[object Boolean]',
	    dateTag = '[object Date]',
	    errorTag = '[object Error]',
	    funcTag = '[object Function]',
	    mapTag = '[object Map]',
	    numberTag = '[object Number]',
	    objectTag = '[object Object]',
	    regexpTag = '[object RegExp]',
	    setTag = '[object Set]',
	    stringTag = '[object String]',
	    weakMapTag = '[object WeakMap]';

	var arrayBufferTag = '[object ArrayBuffer]',
	    dataViewTag = '[object DataView]',
	    float32Tag = '[object Float32Array]',
	    float64Tag = '[object Float64Array]',
	    int8Tag = '[object Int8Array]',
	    int16Tag = '[object Int16Array]',
	    int32Tag = '[object Int32Array]',
	    uint8Tag = '[object Uint8Array]',
	    uint8ClampedTag = '[object Uint8ClampedArray]',
	    uint16Tag = '[object Uint16Array]',
	    uint32Tag = '[object Uint32Array]';

	/** Used to identify `toStringTag` values of typed arrays. */
	var typedArrayTags = {};
	typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
	typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
	typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
	typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
	typedArrayTags[uint32Tag] = true;
	typedArrayTags[argsTag] = typedArrayTags[arrayTag] =
	typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
	typedArrayTags[dataViewTag] = typedArrayTags[dateTag] =
	typedArrayTags[errorTag] = typedArrayTags[funcTag] =
	typedArrayTags[mapTag] = typedArrayTags[numberTag] =
	typedArrayTags[objectTag] = typedArrayTags[regexpTag] =
	typedArrayTags[setTag] = typedArrayTags[stringTag] =
	typedArrayTags[weakMapTag] = false;

	/**
	 * The base implementation of `_.isTypedArray` without Node.js optimizations.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
	 */
	function baseIsTypedArray(value) {
	  return isObjectLike(value) &&
	    isLength(value.length) && !!typedArrayTags[baseGetTag(value)];
	}

	_baseIsTypedArray = baseIsTypedArray;
	return _baseIsTypedArray;
}

/**
 * The base implementation of `_.unary` without support for storing metadata.
 *
 * @private
 * @param {Function} func The function to cap arguments for.
 * @returns {Function} Returns the new capped function.
 */

var _baseUnary;
var hasRequired_baseUnary;

function require_baseUnary () {
	if (hasRequired_baseUnary) return _baseUnary;
	hasRequired_baseUnary = 1;
	function baseUnary(func) {
	  return function(value) {
	    return func(value);
	  };
	}

	_baseUnary = baseUnary;
	return _baseUnary;
}

var _nodeUtil = {exports: {}};

var hasRequired_nodeUtil;

function require_nodeUtil () {
	if (hasRequired_nodeUtil) return _nodeUtil.exports;
	hasRequired_nodeUtil = 1;
	(function (module, exports) {
		var freeGlobal = require_freeGlobal();

		/** Detect free variable `exports`. */
		var freeExports = exports && !exports.nodeType && exports;

		/** Detect free variable `module`. */
		var freeModule = freeExports && 'object' == 'object' && module && !module.nodeType && module;

		/** Detect the popular CommonJS extension `module.exports`. */
		var moduleExports = freeModule && freeModule.exports === freeExports;

		/** Detect free variable `process` from Node.js. */
		var freeProcess = moduleExports && freeGlobal.process;

		/** Used to access faster Node.js helpers. */
		var nodeUtil = (function() {
		  try {
		    // Use `util.types` for Node.js 10+.
		    var types = freeModule && freeModule.require && freeModule.require('util').types;

		    if (types) {
		      return types;
		    }

		    // Legacy `process.binding('util')` for Node.js < 10.
		    return freeProcess && freeProcess.binding && freeProcess.binding('util');
		  } catch (e) {}
		}());

		module.exports = nodeUtil; 
	} (_nodeUtil, _nodeUtil.exports));
	return _nodeUtil.exports;
}

var isTypedArray_1;
var hasRequiredIsTypedArray;

function requireIsTypedArray () {
	if (hasRequiredIsTypedArray) return isTypedArray_1;
	hasRequiredIsTypedArray = 1;
	var baseIsTypedArray = require_baseIsTypedArray(),
	    baseUnary = require_baseUnary(),
	    nodeUtil = require_nodeUtil();

	/* Node.js helper references. */
	var nodeIsTypedArray = nodeUtil && nodeUtil.isTypedArray;

	/**
	 * Checks if `value` is classified as a typed array.
	 *
	 * @static
	 * @memberOf _
	 * @since 3.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a typed array, else `false`.
	 * @example
	 *
	 * _.isTypedArray(new Uint8Array);
	 * // => true
	 *
	 * _.isTypedArray([]);
	 * // => false
	 */
	var isTypedArray = nodeIsTypedArray ? baseUnary(nodeIsTypedArray) : baseIsTypedArray;

	isTypedArray_1 = isTypedArray;
	return isTypedArray_1;
}

/**
 * Gets the value at `key`, unless `key` is "__proto__" or "constructor".
 *
 * @private
 * @param {Object} object The object to query.
 * @param {string} key The key of the property to get.
 * @returns {*} Returns the property value.
 */

var _safeGet;
var hasRequired_safeGet;

function require_safeGet () {
	if (hasRequired_safeGet) return _safeGet;
	hasRequired_safeGet = 1;
	function safeGet(object, key) {
	  if (key === 'constructor' && typeof object[key] === 'function') {
	    return;
	  }

	  if (key == '__proto__') {
	    return;
	  }

	  return object[key];
	}

	_safeGet = safeGet;
	return _safeGet;
}

var _assignValue;
var hasRequired_assignValue;

function require_assignValue () {
	if (hasRequired_assignValue) return _assignValue;
	hasRequired_assignValue = 1;
	var baseAssignValue = require_baseAssignValue(),
	    eq = requireEq();

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Assigns `value` to `key` of `object` if the existing value is not equivalent
	 * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
	 * for equality comparisons.
	 *
	 * @private
	 * @param {Object} object The object to modify.
	 * @param {string} key The key of the property to assign.
	 * @param {*} value The value to assign.
	 */
	function assignValue(object, key, value) {
	  var objValue = object[key];
	  if (!(hasOwnProperty.call(object, key) && eq(objValue, value)) ||
	      (value === undefined && !(key in object))) {
	    baseAssignValue(object, key, value);
	  }
	}

	_assignValue = assignValue;
	return _assignValue;
}

var _copyObject;
var hasRequired_copyObject;

function require_copyObject () {
	if (hasRequired_copyObject) return _copyObject;
	hasRequired_copyObject = 1;
	var assignValue = require_assignValue(),
	    baseAssignValue = require_baseAssignValue();

	/**
	 * Copies properties of `source` to `object`.
	 *
	 * @private
	 * @param {Object} source The object to copy properties from.
	 * @param {Array} props The property identifiers to copy.
	 * @param {Object} [object={}] The object to copy properties to.
	 * @param {Function} [customizer] The function to customize copied values.
	 * @returns {Object} Returns `object`.
	 */
	function copyObject(source, props, object, customizer) {
	  var isNew = !object;
	  object || (object = {});

	  var index = -1,
	      length = props.length;

	  while (++index < length) {
	    var key = props[index];

	    var newValue = customizer
	      ? customizer(object[key], source[key], key, object, source)
	      : undefined;

	    if (newValue === undefined) {
	      newValue = source[key];
	    }
	    if (isNew) {
	      baseAssignValue(object, key, newValue);
	    } else {
	      assignValue(object, key, newValue);
	    }
	  }
	  return object;
	}

	_copyObject = copyObject;
	return _copyObject;
}

/**
 * The base implementation of `_.times` without support for iteratee shorthands
 * or max array length checks.
 *
 * @private
 * @param {number} n The number of times to invoke `iteratee`.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the array of results.
 */

var _baseTimes;
var hasRequired_baseTimes;

function require_baseTimes () {
	if (hasRequired_baseTimes) return _baseTimes;
	hasRequired_baseTimes = 1;
	function baseTimes(n, iteratee) {
	  var index = -1,
	      result = Array(n);

	  while (++index < n) {
	    result[index] = iteratee(index);
	  }
	  return result;
	}

	_baseTimes = baseTimes;
	return _baseTimes;
}

/** Used as references for various `Number` constants. */

var _isIndex;
var hasRequired_isIndex;

function require_isIndex () {
	if (hasRequired_isIndex) return _isIndex;
	hasRequired_isIndex = 1;
	var MAX_SAFE_INTEGER = 9007199254740991;

	/** Used to detect unsigned integer values. */
	var reIsUint = /^(?:0|[1-9]\d*)$/;

	/**
	 * Checks if `value` is a valid array-like index.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
	 * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
	 */
	function isIndex(value, length) {
	  var type = typeof value;
	  length = length == null ? MAX_SAFE_INTEGER : length;

	  return !!length &&
	    (type == 'number' ||
	      (type != 'symbol' && reIsUint.test(value))) &&
	        (value > -1 && value % 1 == 0 && value < length);
	}

	_isIndex = isIndex;
	return _isIndex;
}

var _arrayLikeKeys;
var hasRequired_arrayLikeKeys;

function require_arrayLikeKeys () {
	if (hasRequired_arrayLikeKeys) return _arrayLikeKeys;
	hasRequired_arrayLikeKeys = 1;
	var baseTimes = require_baseTimes(),
	    isArguments = requireIsArguments(),
	    isArray = requireIsArray(),
	    isBuffer = requireIsBuffer(),
	    isIndex = require_isIndex(),
	    isTypedArray = requireIsTypedArray();

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Creates an array of the enumerable property names of the array-like `value`.
	 *
	 * @private
	 * @param {*} value The value to query.
	 * @param {boolean} inherited Specify returning inherited property names.
	 * @returns {Array} Returns the array of property names.
	 */
	function arrayLikeKeys(value, inherited) {
	  var isArr = isArray(value),
	      isArg = !isArr && isArguments(value),
	      isBuff = !isArr && !isArg && isBuffer(value),
	      isType = !isArr && !isArg && !isBuff && isTypedArray(value),
	      skipIndexes = isArr || isArg || isBuff || isType,
	      result = skipIndexes ? baseTimes(value.length, String) : [],
	      length = result.length;

	  for (var key in value) {
	    if ((inherited || hasOwnProperty.call(value, key)) &&
	        !(skipIndexes && (
	           // Safari 9 has enumerable `arguments.length` in strict mode.
	           key == 'length' ||
	           // Node.js 0.10 has enumerable non-index properties on buffers.
	           (isBuff && (key == 'offset' || key == 'parent')) ||
	           // PhantomJS 2 has enumerable non-index properties on typed arrays.
	           (isType && (key == 'buffer' || key == 'byteLength' || key == 'byteOffset')) ||
	           // Skip index properties.
	           isIndex(key, length)
	        ))) {
	      result.push(key);
	    }
	  }
	  return result;
	}

	_arrayLikeKeys = arrayLikeKeys;
	return _arrayLikeKeys;
}

/**
 * This function is like
 * [`Object.keys`](http://ecma-international.org/ecma-262/7.0/#sec-object.keys)
 * except that it includes inherited enumerable properties.
 *
 * @private
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 */

var _nativeKeysIn;
var hasRequired_nativeKeysIn;

function require_nativeKeysIn () {
	if (hasRequired_nativeKeysIn) return _nativeKeysIn;
	hasRequired_nativeKeysIn = 1;
	function nativeKeysIn(object) {
	  var result = [];
	  if (object != null) {
	    for (var key in Object(object)) {
	      result.push(key);
	    }
	  }
	  return result;
	}

	_nativeKeysIn = nativeKeysIn;
	return _nativeKeysIn;
}

var _baseKeysIn;
var hasRequired_baseKeysIn;

function require_baseKeysIn () {
	if (hasRequired_baseKeysIn) return _baseKeysIn;
	hasRequired_baseKeysIn = 1;
	var isObject = requireIsObject(),
	    isPrototype = require_isPrototype(),
	    nativeKeysIn = require_nativeKeysIn();

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * The base implementation of `_.keysIn` which doesn't treat sparse arrays as dense.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @returns {Array} Returns the array of property names.
	 */
	function baseKeysIn(object) {
	  if (!isObject(object)) {
	    return nativeKeysIn(object);
	  }
	  var isProto = isPrototype(object),
	      result = [];

	  for (var key in object) {
	    if (!(key == 'constructor' && (isProto || !hasOwnProperty.call(object, key)))) {
	      result.push(key);
	    }
	  }
	  return result;
	}

	_baseKeysIn = baseKeysIn;
	return _baseKeysIn;
}

var keysIn_1;
var hasRequiredKeysIn;

function requireKeysIn () {
	if (hasRequiredKeysIn) return keysIn_1;
	hasRequiredKeysIn = 1;
	var arrayLikeKeys = require_arrayLikeKeys(),
	    baseKeysIn = require_baseKeysIn(),
	    isArrayLike = requireIsArrayLike();

	/**
	 * Creates an array of the own and inherited enumerable property names of `object`.
	 *
	 * **Note:** Non-object values are coerced to objects.
	 *
	 * @static
	 * @memberOf _
	 * @since 3.0.0
	 * @category Object
	 * @param {Object} object The object to query.
	 * @returns {Array} Returns the array of property names.
	 * @example
	 *
	 * function Foo() {
	 *   this.a = 1;
	 *   this.b = 2;
	 * }
	 *
	 * Foo.prototype.c = 3;
	 *
	 * _.keysIn(new Foo);
	 * // => ['a', 'b', 'c'] (iteration order is not guaranteed)
	 */
	function keysIn(object) {
	  return isArrayLike(object) ? arrayLikeKeys(object, true) : baseKeysIn(object);
	}

	keysIn_1 = keysIn;
	return keysIn_1;
}

var toPlainObject_1;
var hasRequiredToPlainObject;

function requireToPlainObject () {
	if (hasRequiredToPlainObject) return toPlainObject_1;
	hasRequiredToPlainObject = 1;
	var copyObject = require_copyObject(),
	    keysIn = requireKeysIn();

	/**
	 * Converts `value` to a plain object flattening inherited enumerable string
	 * keyed properties of `value` to own properties of the plain object.
	 *
	 * @static
	 * @memberOf _
	 * @since 3.0.0
	 * @category Lang
	 * @param {*} value The value to convert.
	 * @returns {Object} Returns the converted plain object.
	 * @example
	 *
	 * function Foo() {
	 *   this.b = 2;
	 * }
	 *
	 * Foo.prototype.c = 3;
	 *
	 * _.assign({ 'a': 1 }, new Foo);
	 * // => { 'a': 1, 'b': 2 }
	 *
	 * _.assign({ 'a': 1 }, _.toPlainObject(new Foo));
	 * // => { 'a': 1, 'b': 2, 'c': 3 }
	 */
	function toPlainObject(value) {
	  return copyObject(value, keysIn(value));
	}

	toPlainObject_1 = toPlainObject;
	return toPlainObject_1;
}

var _baseMergeDeep;
var hasRequired_baseMergeDeep;

function require_baseMergeDeep () {
	if (hasRequired_baseMergeDeep) return _baseMergeDeep;
	hasRequired_baseMergeDeep = 1;
	var assignMergeValue = require_assignMergeValue(),
	    cloneBuffer = require_cloneBuffer(),
	    cloneTypedArray = require_cloneTypedArray(),
	    copyArray = require_copyArray(),
	    initCloneObject = require_initCloneObject(),
	    isArguments = requireIsArguments(),
	    isArray = requireIsArray(),
	    isArrayLikeObject = requireIsArrayLikeObject(),
	    isBuffer = requireIsBuffer(),
	    isFunction = requireIsFunction(),
	    isObject = requireIsObject(),
	    isPlainObject = requireIsPlainObject(),
	    isTypedArray = requireIsTypedArray(),
	    safeGet = require_safeGet(),
	    toPlainObject = requireToPlainObject();

	/**
	 * A specialized version of `baseMerge` for arrays and objects which performs
	 * deep merges and tracks traversed objects enabling objects with circular
	 * references to be merged.
	 *
	 * @private
	 * @param {Object} object The destination object.
	 * @param {Object} source The source object.
	 * @param {string} key The key of the value to merge.
	 * @param {number} srcIndex The index of `source`.
	 * @param {Function} mergeFunc The function to merge values.
	 * @param {Function} [customizer] The function to customize assigned values.
	 * @param {Object} [stack] Tracks traversed source values and their merged
	 *  counterparts.
	 */
	function baseMergeDeep(object, source, key, srcIndex, mergeFunc, customizer, stack) {
	  var objValue = safeGet(object, key),
	      srcValue = safeGet(source, key),
	      stacked = stack.get(srcValue);

	  if (stacked) {
	    assignMergeValue(object, key, stacked);
	    return;
	  }
	  var newValue = customizer
	    ? customizer(objValue, srcValue, (key + ''), object, source, stack)
	    : undefined;

	  var isCommon = newValue === undefined;

	  if (isCommon) {
	    var isArr = isArray(srcValue),
	        isBuff = !isArr && isBuffer(srcValue),
	        isTyped = !isArr && !isBuff && isTypedArray(srcValue);

	    newValue = srcValue;
	    if (isArr || isBuff || isTyped) {
	      if (isArray(objValue)) {
	        newValue = objValue;
	      }
	      else if (isArrayLikeObject(objValue)) {
	        newValue = copyArray(objValue);
	      }
	      else if (isBuff) {
	        isCommon = false;
	        newValue = cloneBuffer(srcValue, true);
	      }
	      else if (isTyped) {
	        isCommon = false;
	        newValue = cloneTypedArray(srcValue, true);
	      }
	      else {
	        newValue = [];
	      }
	    }
	    else if (isPlainObject(srcValue) || isArguments(srcValue)) {
	      newValue = objValue;
	      if (isArguments(objValue)) {
	        newValue = toPlainObject(objValue);
	      }
	      else if (!isObject(objValue) || isFunction(objValue)) {
	        newValue = initCloneObject(srcValue);
	      }
	    }
	    else {
	      isCommon = false;
	    }
	  }
	  if (isCommon) {
	    // Recursively merge objects and arrays (susceptible to call stack limits).
	    stack.set(srcValue, newValue);
	    mergeFunc(newValue, srcValue, srcIndex, customizer, stack);
	    stack['delete'](srcValue);
	  }
	  assignMergeValue(object, key, newValue);
	}

	_baseMergeDeep = baseMergeDeep;
	return _baseMergeDeep;
}

var _baseMerge;
var hasRequired_baseMerge;

function require_baseMerge () {
	if (hasRequired_baseMerge) return _baseMerge;
	hasRequired_baseMerge = 1;
	var Stack = require_Stack(),
	    assignMergeValue = require_assignMergeValue(),
	    baseFor = require_baseFor(),
	    baseMergeDeep = require_baseMergeDeep(),
	    isObject = requireIsObject(),
	    keysIn = requireKeysIn(),
	    safeGet = require_safeGet();

	/**
	 * The base implementation of `_.merge` without support for multiple sources.
	 *
	 * @private
	 * @param {Object} object The destination object.
	 * @param {Object} source The source object.
	 * @param {number} srcIndex The index of `source`.
	 * @param {Function} [customizer] The function to customize merged values.
	 * @param {Object} [stack] Tracks traversed source values and their merged
	 *  counterparts.
	 */
	function baseMerge(object, source, srcIndex, customizer, stack) {
	  if (object === source) {
	    return;
	  }
	  baseFor(source, function(srcValue, key) {
	    stack || (stack = new Stack);
	    if (isObject(srcValue)) {
	      baseMergeDeep(object, source, key, srcIndex, baseMerge, customizer, stack);
	    }
	    else {
	      var newValue = customizer
	        ? customizer(safeGet(object, key), srcValue, (key + ''), object, source, stack)
	        : undefined;

	      if (newValue === undefined) {
	        newValue = srcValue;
	      }
	      assignMergeValue(object, key, newValue);
	    }
	  }, keysIn);
	}

	_baseMerge = baseMerge;
	return _baseMerge;
}

/**
 * This method returns the first argument it receives.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Util
 * @param {*} value Any value.
 * @returns {*} Returns `value`.
 * @example
 *
 * var object = { 'a': 1 };
 *
 * console.log(_.identity(object) === object);
 * // => true
 */

var identity_1;
var hasRequiredIdentity;

function requireIdentity () {
	if (hasRequiredIdentity) return identity_1;
	hasRequiredIdentity = 1;
	function identity(value) {
	  return value;
	}

	identity_1 = identity;
	return identity_1;
}

/**
 * A faster alternative to `Function#apply`, this function invokes `func`
 * with the `this` binding of `thisArg` and the arguments of `args`.
 *
 * @private
 * @param {Function} func The function to invoke.
 * @param {*} thisArg The `this` binding of `func`.
 * @param {Array} args The arguments to invoke `func` with.
 * @returns {*} Returns the result of `func`.
 */

var _apply;
var hasRequired_apply;

function require_apply () {
	if (hasRequired_apply) return _apply;
	hasRequired_apply = 1;
	function apply(func, thisArg, args) {
	  switch (args.length) {
	    case 0: return func.call(thisArg);
	    case 1: return func.call(thisArg, args[0]);
	    case 2: return func.call(thisArg, args[0], args[1]);
	    case 3: return func.call(thisArg, args[0], args[1], args[2]);
	  }
	  return func.apply(thisArg, args);
	}

	_apply = apply;
	return _apply;
}

var _overRest;
var hasRequired_overRest;

function require_overRest () {
	if (hasRequired_overRest) return _overRest;
	hasRequired_overRest = 1;
	var apply = require_apply();

	/* Built-in method references for those with the same name as other `lodash` methods. */
	var nativeMax = Math.max;

	/**
	 * A specialized version of `baseRest` which transforms the rest array.
	 *
	 * @private
	 * @param {Function} func The function to apply a rest parameter to.
	 * @param {number} [start=func.length-1] The start position of the rest parameter.
	 * @param {Function} transform The rest array transform.
	 * @returns {Function} Returns the new function.
	 */
	function overRest(func, start, transform) {
	  start = nativeMax(start === undefined ? (func.length - 1) : start, 0);
	  return function() {
	    var args = arguments,
	        index = -1,
	        length = nativeMax(args.length - start, 0),
	        array = Array(length);

	    while (++index < length) {
	      array[index] = args[start + index];
	    }
	    index = -1;
	    var otherArgs = Array(start + 1);
	    while (++index < start) {
	      otherArgs[index] = args[index];
	    }
	    otherArgs[start] = transform(array);
	    return apply(func, this, otherArgs);
	  };
	}

	_overRest = overRest;
	return _overRest;
}

/**
 * Creates a function that returns `value`.
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Util
 * @param {*} value The value to return from the new function.
 * @returns {Function} Returns the new constant function.
 * @example
 *
 * var objects = _.times(2, _.constant({ 'a': 1 }));
 *
 * console.log(objects);
 * // => [{ 'a': 1 }, { 'a': 1 }]
 *
 * console.log(objects[0] === objects[1]);
 * // => true
 */

var constant_1;
var hasRequiredConstant;

function requireConstant () {
	if (hasRequiredConstant) return constant_1;
	hasRequiredConstant = 1;
	function constant(value) {
	  return function() {
	    return value;
	  };
	}

	constant_1 = constant;
	return constant_1;
}

var _baseSetToString;
var hasRequired_baseSetToString;

function require_baseSetToString () {
	if (hasRequired_baseSetToString) return _baseSetToString;
	hasRequired_baseSetToString = 1;
	var constant = requireConstant(),
	    defineProperty = require_defineProperty(),
	    identity = requireIdentity();

	/**
	 * The base implementation of `setToString` without support for hot loop shorting.
	 *
	 * @private
	 * @param {Function} func The function to modify.
	 * @param {Function} string The `toString` result.
	 * @returns {Function} Returns `func`.
	 */
	var baseSetToString = !defineProperty ? identity : function(func, string) {
	  return defineProperty(func, 'toString', {
	    'configurable': true,
	    'enumerable': false,
	    'value': constant(string),
	    'writable': true
	  });
	};

	_baseSetToString = baseSetToString;
	return _baseSetToString;
}

/** Used to detect hot functions by number of calls within a span of milliseconds. */

var _shortOut;
var hasRequired_shortOut;

function require_shortOut () {
	if (hasRequired_shortOut) return _shortOut;
	hasRequired_shortOut = 1;
	var HOT_COUNT = 800,
	    HOT_SPAN = 16;

	/* Built-in method references for those with the same name as other `lodash` methods. */
	var nativeNow = Date.now;

	/**
	 * Creates a function that'll short out and invoke `identity` instead
	 * of `func` when it's called `HOT_COUNT` or more times in `HOT_SPAN`
	 * milliseconds.
	 *
	 * @private
	 * @param {Function} func The function to restrict.
	 * @returns {Function} Returns the new shortable function.
	 */
	function shortOut(func) {
	  var count = 0,
	      lastCalled = 0;

	  return function() {
	    var stamp = nativeNow(),
	        remaining = HOT_SPAN - (stamp - lastCalled);

	    lastCalled = stamp;
	    if (remaining > 0) {
	      if (++count >= HOT_COUNT) {
	        return arguments[0];
	      }
	    } else {
	      count = 0;
	    }
	    return func.apply(undefined, arguments);
	  };
	}

	_shortOut = shortOut;
	return _shortOut;
}

var _setToString;
var hasRequired_setToString;

function require_setToString () {
	if (hasRequired_setToString) return _setToString;
	hasRequired_setToString = 1;
	var baseSetToString = require_baseSetToString(),
	    shortOut = require_shortOut();

	/**
	 * Sets the `toString` method of `func` to return `string`.
	 *
	 * @private
	 * @param {Function} func The function to modify.
	 * @param {Function} string The `toString` result.
	 * @returns {Function} Returns `func`.
	 */
	var setToString = shortOut(baseSetToString);

	_setToString = setToString;
	return _setToString;
}

var _baseRest;
var hasRequired_baseRest;

function require_baseRest () {
	if (hasRequired_baseRest) return _baseRest;
	hasRequired_baseRest = 1;
	var identity = requireIdentity(),
	    overRest = require_overRest(),
	    setToString = require_setToString();

	/**
	 * The base implementation of `_.rest` which doesn't validate or coerce arguments.
	 *
	 * @private
	 * @param {Function} func The function to apply a rest parameter to.
	 * @param {number} [start=func.length-1] The start position of the rest parameter.
	 * @returns {Function} Returns the new function.
	 */
	function baseRest(func, start) {
	  return setToString(overRest(func, start, identity), func + '');
	}

	_baseRest = baseRest;
	return _baseRest;
}

var _isIterateeCall;
var hasRequired_isIterateeCall;

function require_isIterateeCall () {
	if (hasRequired_isIterateeCall) return _isIterateeCall;
	hasRequired_isIterateeCall = 1;
	var eq = requireEq(),
	    isArrayLike = requireIsArrayLike(),
	    isIndex = require_isIndex(),
	    isObject = requireIsObject();

	/**
	 * Checks if the given arguments are from an iteratee call.
	 *
	 * @private
	 * @param {*} value The potential iteratee value argument.
	 * @param {*} index The potential iteratee index or key argument.
	 * @param {*} object The potential iteratee object argument.
	 * @returns {boolean} Returns `true` if the arguments are from an iteratee call,
	 *  else `false`.
	 */
	function isIterateeCall(value, index, object) {
	  if (!isObject(object)) {
	    return false;
	  }
	  var type = typeof index;
	  if (type == 'number'
	        ? (isArrayLike(object) && isIndex(index, object.length))
	        : (type == 'string' && index in object)
	      ) {
	    return eq(object[index], value);
	  }
	  return false;
	}

	_isIterateeCall = isIterateeCall;
	return _isIterateeCall;
}

var _createAssigner;
var hasRequired_createAssigner;

function require_createAssigner () {
	if (hasRequired_createAssigner) return _createAssigner;
	hasRequired_createAssigner = 1;
	var baseRest = require_baseRest(),
	    isIterateeCall = require_isIterateeCall();

	/**
	 * Creates a function like `_.assign`.
	 *
	 * @private
	 * @param {Function} assigner The function to assign values.
	 * @returns {Function} Returns the new assigner function.
	 */
	function createAssigner(assigner) {
	  return baseRest(function(object, sources) {
	    var index = -1,
	        length = sources.length,
	        customizer = length > 1 ? sources[length - 1] : undefined,
	        guard = length > 2 ? sources[2] : undefined;

	    customizer = (assigner.length > 3 && typeof customizer == 'function')
	      ? (length--, customizer)
	      : undefined;

	    if (guard && isIterateeCall(sources[0], sources[1], guard)) {
	      customizer = length < 3 ? undefined : customizer;
	      length = 1;
	    }
	    object = Object(object);
	    while (++index < length) {
	      var source = sources[index];
	      if (source) {
	        assigner(object, source, index, customizer);
	      }
	    }
	    return object;
	  });
	}

	_createAssigner = createAssigner;
	return _createAssigner;
}

var merge_1;
var hasRequiredMerge;

function requireMerge () {
	if (hasRequiredMerge) return merge_1;
	hasRequiredMerge = 1;
	var baseMerge = require_baseMerge(),
	    createAssigner = require_createAssigner();

	/**
	 * This method is like `_.assign` except that it recursively merges own and
	 * inherited enumerable string keyed properties of source objects into the
	 * destination object. Source properties that resolve to `undefined` are
	 * skipped if a destination value exists. Array and plain object properties
	 * are merged recursively. Other objects and value types are overridden by
	 * assignment. Source objects are applied from left to right. Subsequent
	 * sources overwrite property assignments of previous sources.
	 *
	 * **Note:** This method mutates `object`.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.5.0
	 * @category Object
	 * @param {Object} object The destination object.
	 * @param {...Object} [sources] The source objects.
	 * @returns {Object} Returns `object`.
	 * @example
	 *
	 * var object = {
	 *   'a': [{ 'b': 2 }, { 'd': 4 }]
	 * };
	 *
	 * var other = {
	 *   'a': [{ 'c': 3 }, { 'e': 5 }]
	 * };
	 *
	 * _.merge(object, other);
	 * // => { 'a': [{ 'b': 2, 'c': 3 }, { 'd': 4, 'e': 5 }] }
	 */
	var merge = createAssigner(function(object, source, srcIndex) {
	  baseMerge(object, source, srcIndex);
	});

	merge_1 = merge;
	return merge_1;
}

var mergeExports = requireMerge();
var merge = /*@__PURE__*/getDefaultExportFromCjs(mergeExports);

var op=i=>{throw TypeError(i)};var gp=(i=>typeof require<"u"?require:typeof Proxy<"u"?new Proxy(i,{get:(e,t)=>(typeof require<"u"?require:e)[t]}):i)(function(i){if(typeof require<"u")return require.apply(this,arguments);throw Error('Dynamic require of "'+i+'" is not supported')});var np=(i,e,t)=>e.has(i)||op("Cannot "+t);var o=(i,e,t)=>(np(i,e,"read from private field"),t?t.call(i):e.get(i)),u=(i,e,t)=>e.has(i)?op("Cannot add the same private member more than once"):e instanceof WeakSet?e.add(i):e.set(i,t),a=(i,e,t,r)=>(np(i,e,"write to private field"),e.set(i,t),t);var _p=(i,...e)=>{},ip=i=>_p;try{let i=gp("debug");i&&typeof i=="function"&&(ip=i);}catch{}var Pp="clsdk",hp=i=>ip(`${Pp}:${i}`),x=hp;var Ko=x("fetch"),$t,Bt,qt,Dt,Vo=class Vo extends Error{constructor(t,r,s,m){super(r);u(this,$t);u(this,Bt);u(this,qt);u(this,Dt);a(this,Bt,t),a(this,qt,r),s&&a(this,$t,s.errors),m&&a(this,Dt,m);}get errors(){return o(this,$t)}get status(){return o(this,Bt)}get statusText(){return o(this,qt)}get request(){return o(this,Dt)}};$t=new WeakMap,Bt=new WeakMap,qt=new WeakMap,Dt=new WeakMap,Vo.isFetchError=t=>t instanceof Vo;var Ft=Vo,Xo=async(i,e,t)=>{Ko("fetch: %s, %O, native[%s]",i,e||{},t?.fetch?"no":"yes");let r=t?.interceptors;r?.request?.onSuccess&&({url:i,options:e}=await r.request.onSuccess({url:i,options:e}));let m=await(t?.fetch||fetch)(i,e);m.ok?(r?.rawReader?.onSuccess&&await r.rawReader.onSuccess(m),r?.response?.onSuccess&&(m=await r.response.onSuccess(m))):r?.rawReader?.onFailure&&await r.rawReader.onFailure(m);let R=m.body&&m.status!==204?await m.json().then(d=>(Ko("response: %O",d),d)).catch(d=>{if(Ko("error: %s",d.message),m.ok)throw new P({message:"Error parsing API response body",type:"parse"})}):void 0;if(!m.ok){let d=new Ft(m.status,m.statusText,R,e);if(r?.response?.onFailure&&(d=await r.response.onFailure(d)),d)throw d}return R};var zt=(d=>(d.CLIENT="client",d.REQUEST="request",d.RESPONSE="response",d.CANCEL="cancel",d.PARSE="parse",d.TIMEOUT="timeout",d.TOKEN_REFRESH="token-refresh",d))(zt||{}),jt=class jt extends Error{static isSdkError(e){return e&&[jt.NAME,Pe.NAME].includes(e.name)&&Object.values(zt).includes(e.type)}constructor(e){super(e.message),this.name=jt.NAME,this.type=e.type||"client";}};jt.NAME="SdkError";var P=jt,Wt=class Wt extends P{constructor(t){super({...t,type:"response"});this.errors=[];this.name=Wt.NAME;}static isApiError(t){return P.isSdkError(t)&&t.name===Wt.NAME&&t.type==="response"}first(){return this.errors?.length>0?this.errors[0]:void 0}};Wt.NAME="ApiError";var Pe=Wt,fp=i=>i instanceof TypeError,kp=i=>i instanceof DOMException&&i.name==="AbortError",Cp=i=>i instanceof DOMException&&i.name==="TimeoutError",ap=i=>{let e=["INVALID_TOKEN"];return Pe.isApiError(i)&&i.status===401&&(e.includes(i.code||"")||i.errors&&i.errors.length>0&&e.includes(i.errors[0].code))},No=i=>{if(P.isSdkError(i)||Pe.isApiError(i))throw i;let e=new P({message:i.message});if(Ft.isFetchError(i)){let t=new Pe(e);t.type="response",t.status=i.status,t.statusText=i.statusText,t.code=String(t.status),t.errors=i.errors||[],!t.message&&t.statusText&&(t.message=t.statusText),e=t;}else fp(i)?e.type="request":kp(i)?e.type="cancel":Cp(i)?e.type="timeout":(e.type="client",e.source=i);throw e};var Tp={default:{domain:"commercelayer.io",pageNumber:1,pageSize:10},client:{timeout:15e3,requiredAttributes:["organization","accessToken"]},jsonapi:{maxResourceIncluded:2}},G=Tp;var Zo=i=>{try{return JSON.parse(atob(i.split(".")[1]))}catch{return}},Fo=i=>{try{return Zo(i).exp*1e3-Date.now()<0}catch{return  false}};var re=x("client"),Ho=(i,e)=>`https://${i.toLowerCase()}.${e||G.default.domain}/api`,Ot,Y,h,Kt,en=class en{constructor(e){u(this,Ot);u(this,Y);u(this,h);u(this,Kt);re("new client instance %O",e),a(this,Ot,Ho(e.organization??"",e.domain)),a(this,Y,e.accessToken);let t={timeout:e.timeout||G.client.timeout,fetch:e.fetch,refreshToken:e.refreshToken},s={...this.customHeaders(e.headers),Accept:"application/vnd.api+json","Content-Type":"application/vnd.api+json",Authorization:"Bearer "+o(this,Y)};e.userAgent&&(s["User-Agent"]=e.userAgent),t.headers=s,a(this,h,t),re("fetch config: %O",t),a(this,Kt,{});}static create(e){for(let t of G.client.requiredAttributes)if(!e||!e[t])throw new P({message:`Undefined '${t}' parameter`});return new en(e)}get interceptors(){return o(this,Kt)}get requestHeaders(){return o(this,h).headers||(o(this,h).headers={}),o(this,h).headers}config(e){re("config %o",e);let t=o(this,h);return t.headers||(t.headers={}),e.timeout&&(t.timeout=e.timeout),e.userAgent&&this.userAgent(e.userAgent),e.fetch&&(o(this,h).fetch=e.fetch),e.refreshToken&&(o(this,h).refreshToken=e.refreshToken),e.organization&&a(this,Ot,Ho(e.organization,e.domain)),e.accessToken&&(a(this,Y,e.accessToken),t.headers.Authorization="Bearer "+o(this,Y)),e.headers&&(t.headers={...t.headers,...this.customHeaders(e.headers)}),this}userAgent(e){return e&&(this.requestHeaders["User-Agent"]=e),this}async request(e,t,r,s){re("request %s %s, %O, %O",e,t,r||{},s||{}),s?.userAgent&&re("User-Agent header ignored in request config");let m=s?.organization?Ho(s.organization,s.domain):o(this,Ot),R=new URL(`${m}/${t}`),d=r?JSON.stringify({data:r}):void 0,Yt={...this.requestHeaders,...this.customHeaders(s?.headers)},Yo=s?.accessToken||o(this,Y);Yo&&(Yt.Authorization="Bearer "+Yo);let Ut={method:e,body:d,headers:Yt},rp=s?.timeout||o(this,h).timeout;rp&&(AbortSignal?.timeout?Ut.signal=AbortSignal.timeout(rp):re("Timeout not set. Undefined function: %s","AbortSignal.timeout")),s?.params&&Object.entries(s?.params).forEach(([At,Vt])=>{R.searchParams.append(At,String(Vt));});let sp={interceptors:this.interceptors,fetch:s?.fetch||o(this,h).fetch};try{return await Xo(R,Ut,sp).catch(At=>No(At))}catch(At){if(ap(At)&&o(this,h).refreshToken&&Fo(o(this,Y))){re("Access token has expired");let Vt=await o(this,h).refreshToken(o(this,Y)).catch(Wo=>{re("Refresh token error: %s",Wo.message);let Uo=new P({message:"Error refreshing access token",type:"token-refresh"});throw Uo.source=Wo,Uo});if(Vt)return re("Access token refreshed"),this.config({accessToken:Vt}),Ut.headers&&(Ut.headers.Authorization=`Bearer ${Vt}`),await Xo(R,Ut,sp).catch(Uo=>No(Uo))}else throw At}}customHeaders(e){let t={};if(e)for(let[r,s]of Object.entries(e))["accept","content-type","authorization","user-agent"].includes(r.toLowerCase())||(t[r]=s);return t}get currentAccessToken(){return o(this,Y)}};Ot=new WeakMap,Y=new WeakMap,h=new WeakMap,Kt=new WeakMap;var Jo=en,up=Jo;var $o=i=>i?.type&&i.id&&It.includes(i.type),tn=i=>i&&typeof i.type<"u"&&i.type&&It.includes(i.type);var Bo=x("jsonapi"),xt=i=>{if(!i)return i;let e;i.links&&delete i.links;let t=i.data,r=i.included;return t?Array.isArray(t)?e=t.map(s=>qo(s,r)):e=qo(t,r):e=t,e},cp=(i,e=[])=>e.find(r=>i.id===r.id&&i.type===r.type)||i,qo=(i,e,t=[])=>{if(Bo("denormalize resource: %O, %o",i,e||{}),!i)return i;let r={id:i.id,type:i.type,...i.attributes};return i.relationships&&Object.keys(i.relationships).forEach(s=>{let m=i.relationships[s].data;m?t.filter(R=>R.id===m.id&&R.type===m.type).length>=G.jsonapi.maxResourceIncluded?r[s]=m:Array.isArray(m)?r[s]=m.map(R=>qo(cp(R,e),e,[...t,R])):r[s]=qo(cp(m,e),e,[...t,m]):m===null&&(r[s]=null);}),Bo("denormalized resource: %O",r),r},rn=i=>{Bo("normalize resource: %O",i);let e={},t={};for(let s in i){if(["type","id"].includes(s))continue;let m=i[s];Array.isArray(m)&&m.length===1&&tn(m[0])&&m[0].id===null?t[s]={data:[]}:m&&tn(m)&&m.id===null?t[s]={data:null}:m&&($o(m)||Array.isArray(m)&&$o(m[0]))?t[s]={data:m}:e[s]=m;}let r={type:i.type,attributes:e,relationships:t};return $o(i)&&(r.id=i.id),Bo("normalized resource: %O",r),r};var pp=x("query"),lp=["_any","_all","_in","_not_in_or_null"],Sp=i=>lp.some(e=>i.endsWith(e)),mp=["_jcont"],vp=i=>mp.some(e=>i.endsWith(e)),sn=i=>i&&(i.filters||i.pageNumber||i.pageSize||i.sort),Lt=(i,e)=>{pp("generate query string params: %O, %O",i,e);let t={};return i&&(i.include&&(t.include=i.include.join(",")),i.fields&&(Array.isArray(i.fields)&&(i.fields={[e.type||e]:i.fields}),Object.entries(i.fields).forEach(([r,s])=>{t[`fields[${r}]`]=s.join(",");})),sn(i)&&(i.sort&&(Array.isArray(i.sort)?t.sort=i.sort.join(","):t.sort=Object.entries(i.sort).map(([r,s])=>`${s==="desc"?"-":""}${r}`).join(",")),i.pageNumber&&(t["page[number]"]=String(i.pageNumber)),i.pageSize&&(t["page[size]"]=String(i.pageSize)),i.filters&&Object.entries(i.filters).forEach(([r,s])=>{let m;if(Array.isArray(s)){if(!Sp(r))throw new P({message:`Incorrect filter [${r}]: Array value is supported only for the following filters: ${lp.join(", ")}`,type:"request"});m=s.join(",");}else if(typeof s=="object"){if(!vp(r))throw new P({message:`Incorrect filter [${r}]: Object value is supported only for the following filters: ${mp.join(", ")}`,type:"request"});m=JSON.stringify(s);}else m=String(s);t[`filter[q][${r}]`]=m;})),pp("query string params: %O",t)),t};var se=x("resource"),Do=class extends Array{constructor(e,t){super(...t||[]),this.meta=e;}first(){return this.length?this[0]:void 0}last(){return this.length?this[this.length-1]:void 0}get(e){return this.length&&e>=0?this[e]:void 0}hasNextPage(){return this.meta.currentPage<this.meta.pageCount}hasPrevPage(){return this.meta.currentPage>1}getRecordCount(){return this.meta.recordCount}getPageCount(){return this.meta.pageCount}get recordCount(){return this.meta.recordCount}get pageCount(){return this.meta.pageCount}};var T,nn,on=class{constructor(e){u(this,T);u(this,nn,{});a(this,T,up.create(e)),this.localConfig(e);}localConfig(e){}config(e){return se("config %o",e),this.localConfig(e),o(this,T).config(e),this}get client(){return o(this,T)}async singleton(e,t,r,s){se("singleton: %o, %O, %O",e,t||{},r||{});let m=Lt(t,e);r?.params&&Object.assign(m,r?.params);let R=await o(this,T).request("GET",`${s||e.type}`,void 0,{...r,params:m});return xt(R)}async retrieve(e,t,r){se("retrieve: %o, %O, %O",e,t||{},r||{});let s=Lt(t,e);r?.params&&Object.assign(s,r?.params);let m=await o(this,T).request("GET",`${e.type}/${e.id}`,void 0,{...r,params:s});return xt(m)}async list(e,t,r){se("list: %o, %O, %O",e,t||{},r||{});let s=Lt(t,e);r?.params&&Object.assign(s,r?.params),s["page[number]"]||(s["page[number]"]="1");let m=await o(this,T).request("GET",`${e.type}`,void 0,{...r,params:s}),R=xt(m),d={pageCount:Number(m.meta?.page_count),recordCount:Number(m.meta?.record_count),currentPage:t?.pageNumber||G.default.pageNumber,recordsPerPage:t?.pageSize||G.default.pageSize};return new Do(d,R)}async create(e,t,r){se("create: %o, %O, %O",e,t||{},r||{});let s=Lt(t,e);r?.params&&Object.assign(s,r?.params);let m=rn(e),R=await o(this,T).request("POST",e.type,m,{...r,params:s});return xt(R)}async update(e,t,r){se("update: %o, %O, %O",e,t||{},r||{});let s=Lt(t,e);r?.params&&Object.assign(s,r?.params);let m=rn(e),R=await o(this,T).request("PATCH",`${e.type}/${e.id}`,m,{...r,params:s});return xt(R)}async delete(e,t){se("delete: %o, %O",e,t||{}),await o(this,T).request("DELETE",`${e.type}/${e.id}`,void 0,t);}async fetch(e,t,r,s){se("fetch: %o, %O, %O",t,r||{},s||{});let m=Lt(r,e);s?.params&&Object.assign(m,s?.params);let R=await o(this,T).request("GET",t,void 0,{...s,params:m}),d=xt(R);if(Array.isArray(d)){let Yt=r,Yo={pageCount:Number(R.meta?.page_count),recordCount:Number(R.meta?.record_count),currentPage:Yt?.pageNumber||G.default.pageNumber,recordsPerPage:Yt?.pageSize||G.default.pageSize};return new Do(Yo,d)}else return d}};T=new WeakMap,nn=new WeakMap;var zo=class{constructor(e){se("new resource instance: %s",this.type()),this.resources=e;}relationshipOneToOne(e){return e===null||typeof e=="string"?{id:e,type:this.type()}:{id:e.id,type:this.type()}}relationshipOneToMany(...e){return e===null||e.length===0||e[0]===null?[{id:null,type:this.type()}]:e.map(t=>({id:t,type:this.type()}))}path(){return this.type()}async update(e,t,r){return this.resources.update({...e,type:this.type()},t,r)}},n=class extends zo{async retrieve(e,t,r){return this.resources.retrieve(typeof e=="string"?{type:this.type(),id:e}:e,t,r)}async list(e,t){return this.resources.list({type:this.type()},e,t)}async count(e,t){let r={filters:sn(e)?e.filters:e,pageNumber:1,pageSize:1},s=await this.list(r,t);return Promise.resolve(s.meta.recordCount)}},Mt=class extends zo{async retrieve(e,t){return this.resources.singleton({type:this.type()},e,t,this.path())}},yp=on;var q=class q extends n{async create(e,t,r){return this.resources.create({...e,type:q.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:q.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:q.TYPE}:e,t);}async geocoder(e,t,r){let s=e.id||e;return this.resources.fetch({type:"geocoders"},`addresses/${s}/geocoder`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`addresses/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`addresses/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`addresses/${s}/versions`,t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:q.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:q.TYPE,_remove_tags:t},r,s)}isAddress(e){return e.type&&e.type===q.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return q.TYPE}};q.TYPE="addresses";var an=q,un=an;var he=class he extends n{async create(e,t,r){return this.resources.create({...e,type:he.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:he.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:he.TYPE}:e,t);}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`adjustments/${s}/versions`,t,r)}isAdjustment(e){return e.type&&e.type===he.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return he.TYPE}};he.TYPE="adjustments";var cn=he,pn=cn;var fe=class fe extends n{async create(e,t,r){return this.resources.create({...e,type:fe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:fe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:fe.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`adyen_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`adyen_gateways/${s}/versions`,t,r)}async adyen_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"adyen_payments"},`adyen_gateways/${s}/adyen_payments`,t,r)}isAdyenGateway(e){return e.type&&e.type===fe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return fe.TYPE}};fe.TYPE="adyen_gateways";var ln=fe,mn=ln;var U=class U extends n{async create(e,t,r){return this.resources.create({...e,type:U.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:U.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:U.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`adyen_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`adyen_payments/${s}/payment_gateway`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`adyen_payments/${s}/versions`,t,r)}async _authorize(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:U.TYPE,_authorize:true},t,r)}async _details(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:U.TYPE,_details:true},t,r)}async _balance(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:U.TYPE,_balance:true},t,r)}isAdyenPayment(e){return e.type&&e.type===U.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return U.TYPE}};U.TYPE="adyen_payments";var yn=U,dn=yn;var Xt=class Xt extends Mt{isApplication(e){return e.type&&e.type===Xt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Xt.TYPE}path(){return "application"}};Xt.TYPE="applications";var Rn=Xt,gn=Rn;var ke=class ke extends n{async create(e,t,r){return this.resources.create({...e,type:ke.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ke.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ke.TYPE}:e,t);}isAttachment(e){return e.type&&e.type===ke.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ke.TYPE}};ke.TYPE="attachments";var _n=ke,Pn=_n;var V=class V extends n{async update(e,t,r){return this.resources.update({...e,type:V.TYPE},t,r)}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`authorizations/${s}/order`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`authorizations/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`authorizations/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`authorizations/${s}/versions`,t,r)}async captures(e,t,r){let s=e.id||e;return this.resources.fetch({type:"captures"},`authorizations/${s}/captures`,t,r)}async voids(e,t,r){let s=e.id||e;return this.resources.fetch({type:"voids"},`authorizations/${s}/voids`,t,r)}async _forward(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:V.TYPE,_forward:true},t,r)}async _capture(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:V.TYPE,_capture:true},t,r)}async _capture_amount_cents(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:V.TYPE,_capture_amount_cents:t},r,s)}async _void(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:V.TYPE,_void:true},t,r)}async _cancel(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:V.TYPE,_cancel:true},t,r)}isAuthorization(e){return e.type&&e.type===V.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return V.TYPE}};V.TYPE="authorizations";var hn=V,fn=hn;var Ce=class Ce extends n{async create(e,t,r){return this.resources.create({...e,type:Ce.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ce.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ce.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`avalara_accounts/${s}/markets`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`avalara_accounts/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`avalara_accounts/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`avalara_accounts/${s}/versions`,t,r)}async tax_categories(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tax_categories"},`avalara_accounts/${s}/tax_categories`,t,r)}isAvalaraAccount(e){return e.type&&e.type===Ce.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ce.TYPE}};Ce.TYPE="avalara_accounts";var kn=Ce,Cn=kn;var Te=class Te extends n{async create(e,t,r){return this.resources.create({...e,type:Te.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Te.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Te.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`axerve_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`axerve_gateways/${s}/versions`,t,r)}async axerve_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"axerve_payments"},`axerve_gateways/${s}/axerve_payments`,t,r)}isAxerveGateway(e){return e.type&&e.type===Te.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Te.TYPE}};Te.TYPE="axerve_gateways";var Tn=Te,Sn=Tn;var oe=class oe extends n{async create(e,t,r){return this.resources.create({...e,type:oe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:oe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:oe.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`axerve_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`axerve_payments/${s}/payment_gateway`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`axerve_payments/${s}/versions`,t,r)}async _update(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:oe.TYPE,_update:true},t,r)}isAxervePayment(e){return e.type&&e.type===oe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return oe.TYPE}};oe.TYPE="axerve_payments";var vn=oe,xn=vn;var Se=class Se extends n{async create(e,t,r){return this.resources.create({...e,type:Se.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Se.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Se.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`bing_geocoders/${s}/markets`,t,r)}async addresses(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`bing_geocoders/${s}/addresses`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`bing_geocoders/${s}/attachments`,t,r)}isBingGeocoder(e){return e.type&&e.type===Se.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Se.TYPE}};Se.TYPE="bing_geocoders";var Ln=Se,bn=Ln;var ve=class ve extends n{async create(e,t,r){return this.resources.create({...e,type:ve.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ve.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ve.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`braintree_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`braintree_gateways/${s}/versions`,t,r)}async braintree_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"braintree_payments"},`braintree_gateways/${s}/braintree_payments`,t,r)}isBraintreeGateway(e){return e.type&&e.type===ve.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ve.TYPE}};ve.TYPE="braintree_gateways";var En=ve,wn=En;var xe=class xe extends n{async create(e,t,r){return this.resources.create({...e,type:xe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:xe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:xe.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`braintree_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`braintree_payments/${s}/payment_gateway`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`braintree_payments/${s}/versions`,t,r)}isBraintreePayment(e){return e.type&&e.type===xe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return xe.TYPE}};xe.TYPE="braintree_payments";var An=xe,On=An;var L=class L extends n{async create(e,t,r){return this.resources.create({...e,type:L.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:L.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:L.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`bundles/${s}/market`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`bundles/${s}/sku_list`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`bundles/${s}/skus`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`bundles/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`bundles/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`bundles/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`bundles/${s}/versions`,t,r)}async _compute_price_amount(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:L.TYPE,_compute_price_amount:true},t,r)}async _compute_compare_at_amount(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:L.TYPE,_compute_compare_at_amount:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:L.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:L.TYPE,_remove_tags:t},r,s)}isBundle(e){return e.type&&e.type===L.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return L.TYPE}};L.TYPE="bundles";var In=L,Mn=In;var b=class b extends n{async create(e,t,r){return this.resources.create({...e,type:b.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:b.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:b.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`buy_x_pay_y_promotions/${s}/market`,t,r)}async order_amount_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_amount_promotion_rules"},`buy_x_pay_y_promotions/${s}/order_amount_promotion_rule`,t,r)}async sku_list_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_promotion_rules"},`buy_x_pay_y_promotions/${s}/sku_list_promotion_rule`,t,r)}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`buy_x_pay_y_promotions/${s}/coupon_codes_promotion_rule`,t,r)}async custom_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"custom_promotion_rules"},`buy_x_pay_y_promotions/${s}/custom_promotion_rule`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`buy_x_pay_y_promotions/${s}/sku_list`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`buy_x_pay_y_promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`buy_x_pay_y_promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`buy_x_pay_y_promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`buy_x_pay_y_promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`buy_x_pay_y_promotions/${s}/versions`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`buy_x_pay_y_promotions/${s}/skus`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:b.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:b.TYPE,_enable:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:b.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:b.TYPE,_remove_tags:t},r,s)}isBuyXPayYPromotion(e){return e.type&&e.type===b.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return b.TYPE}};b.TYPE="buy_x_pay_y_promotions";var Qn=b,Gn=Qn;var D=class D extends n{async update(e,t,r){return this.resources.update({...e,type:D.TYPE},t,r)}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`captures/${s}/order`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`captures/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`captures/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`captures/${s}/versions`,t,r)}async reference_authorization(e,t,r){let s=e.id||e;return this.resources.fetch({type:"authorizations"},`captures/${s}/reference_authorization`,t,r)}async refunds(e,t,r){let s=e.id||e;return this.resources.fetch({type:"refunds"},`captures/${s}/refunds`,t,r)}async return(e,t,r){let s=e.id||e;return this.resources.fetch({type:"returns"},`captures/${s}/return`,t,r)}async _forward(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:D.TYPE,_forward:true},t,r)}async _refund(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:D.TYPE,_refund:true},t,r)}async _refund_amount_cents(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:D.TYPE,_refund_amount_cents:t},r,s)}async _cancel(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:D.TYPE,_cancel:true},t,r)}isCapture(e){return e.type&&e.type===D.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return D.TYPE}};D.TYPE="captures";var Yn=D,Un=Yn;var Le=class Le extends n{async create(e,t,r){return this.resources.create({...e,type:Le.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Le.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Le.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`carrier_accounts/${s}/market`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`carrier_accounts/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`carrier_accounts/${s}/versions`,t,r)}isCarrierAccount(e){return e.type&&e.type===Le.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Le.TYPE}};Le.TYPE="carrier_accounts";var Vn=Le,Fn=Vn;var be=class be extends n{async create(e,t,r){return this.resources.create({...e,type:be.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:be.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:be.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`checkout_com_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`checkout_com_gateways/${s}/versions`,t,r)}async checkout_com_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"checkout_com_payments"},`checkout_com_gateways/${s}/checkout_com_payments`,t,r)}isCheckoutComGateway(e){return e.type&&e.type===be.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return be.TYPE}};be.TYPE="checkout_com_gateways";var $n=be,Bn=$n;var z=class z extends n{async create(e,t,r){return this.resources.create({...e,type:z.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:z.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:z.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`checkout_com_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`checkout_com_payments/${s}/payment_gateway`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`checkout_com_payments/${s}/versions`,t,r)}async _details(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:z.TYPE,_details:true},t,r)}async _refresh(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:z.TYPE,_refresh:true},t,r)}isCheckoutComPayment(e){return e.type&&e.type===z.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return z.TYPE}};z.TYPE="checkout_com_payments";var qn=z,Dn=qn;var ne=class ne extends n{async create(e,t,r){return this.resources.create({...e,type:ne.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ne.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ne.TYPE}:e,t);}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`cleanups/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`cleanups/${s}/versions`,t,r)}async _interrupt(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:ne.TYPE,_interrupt:true},t,r)}isCleanup(e){return e.type&&e.type===ne.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ne.TYPE}};ne.TYPE="cleanups";var zn=ne,jn=zn;var Ee=class Ee extends n{async create(e,t,r){return this.resources.create({...e,type:Ee.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ee.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ee.TYPE}:e,t);}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`coupon_codes_promotion_rules/${s}/versions`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`coupon_codes_promotion_rules/${s}/coupons`,t,r)}isCouponCodesPromotionRule(e){return e.type&&e.type===Ee.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ee.TYPE}};Ee.TYPE="coupon_codes_promotion_rules";var Wn=Ee,Kn=Wn;var we=class we extends n{async create(e,t,r){return this.resources.create({...e,type:we.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:we.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:we.TYPE}:e,t);}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`coupon_recipients/${s}/customer`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`coupon_recipients/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`coupon_recipients/${s}/versions`,t,r)}isCouponRecipient(e){return e.type&&e.type===we.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return we.TYPE}};we.TYPE="coupon_recipients";var Xn=we,Nn=Xn;var j=class j extends n{async create(e,t,r){return this.resources.create({...e,type:j.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:j.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:j.TYPE}:e,t);}async promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`coupons/${s}/promotion_rule`,t,r)}async coupon_recipient(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_recipients"},`coupons/${s}/coupon_recipient`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`coupons/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`coupons/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`coupons/${s}/versions`,t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:j.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:j.TYPE,_remove_tags:t},r,s)}isCoupon(e){return e.type&&e.type===j.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return j.TYPE}};j.TYPE="coupons";var Zn=j,Hn=Zn;var Ae=class Ae extends n{async create(e,t,r){return this.resources.create({...e,type:Ae.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ae.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ae.TYPE}:e,t);}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`custom_promotion_rules/${s}/versions`,t,r)}isCustomPromotionRule(e){return e.type&&e.type===Ae.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ae.TYPE}};Ae.TYPE="custom_promotion_rules";var Jn=Ae,ei=Jn;var Oe=class Oe extends n{async create(e,t,r){return this.resources.create({...e,type:Oe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Oe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Oe.TYPE}:e,t);}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`customer_addresses/${s}/customer`,t,r)}async address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`customer_addresses/${s}/address`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`customer_addresses/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`customer_addresses/${s}/versions`,t,r)}isCustomerAddress(e){return e.type&&e.type===Oe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Oe.TYPE}};Oe.TYPE="customer_addresses";var ti=Oe,ri=ti;var Ie=class Ie extends n{async create(e,t,r){return this.resources.create({...e,type:Ie.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ie.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ie.TYPE}:e,t);}async customers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`customer_groups/${s}/customers`,t,r)}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`customer_groups/${s}/markets`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`customer_groups/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`customer_groups/${s}/versions`,t,r)}isCustomerGroup(e){return e.type&&e.type===Ie.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ie.TYPE}};Ie.TYPE="customer_groups";var si=Ie,oi=si;var ie=class ie extends n{async create(e,t,r){return this.resources.create({...e,type:ie.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ie.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ie.TYPE}:e,t);}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`customer_password_resets/${s}/customer`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`customer_password_resets/${s}/events`,t,r)}async _reset_password_token(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:ie.TYPE,_reset_password_token:t},r,s)}isCustomerPasswordReset(e){return e.type&&e.type===ie.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ie.TYPE}};ie.TYPE="customer_password_resets";var ni=ie,ii=ni;var Me=class Me extends n{async create(e,t,r){return this.resources.create({...e,type:Me.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Me.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Me.TYPE}:e,t);}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`customer_payment_sources/${s}/customer`,t,r)}async payment_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`customer_payment_sources/${s}/payment_method`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`customer_payment_sources/${s}/versions`,t,r)}isCustomerPaymentSource(e){return e.type&&e.type===Me.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Me.TYPE}};Me.TYPE="customer_payment_sources";var ai=Me,ui=ai;var Qe=class Qe extends n{async create(e,t,r){return this.resources.create({...e,type:Qe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Qe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Qe.TYPE}:e,t);}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`customer_subscriptions/${s}/customer`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`customer_subscriptions/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`customer_subscriptions/${s}/versions`,t,r)}isCustomerSubscription(e){return e.type&&e.type===Qe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Qe.TYPE}};Qe.TYPE="customer_subscriptions";var ci=Qe,pi=ci;var E=class E extends n{async create(e,t,r){return this.resources.create({...e,type:E.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:E.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:E.TYPE}:e,t);}async customer_group(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customer_groups"},`customers/${s}/customer_group`,t,r)}async customer_addresses(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customer_addresses"},`customers/${s}/customer_addresses`,t,r)}async customer_payment_sources(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customer_payment_sources"},`customers/${s}/customer_payment_sources`,t,r)}async customer_subscriptions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customer_subscriptions"},`customers/${s}/customer_subscriptions`,t,r)}async orders(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`customers/${s}/orders`,t,r)}async order_subscriptions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_subscriptions"},`customers/${s}/order_subscriptions`,t,r)}async returns(e,t,r){let s=e.id||e;return this.resources.fetch({type:"returns"},`customers/${s}/returns`,t,r)}async sku_lists(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`customers/${s}/sku_lists`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`customers/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`customers/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`customers/${s}/tags`,t,r)}async jwt_customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`customers/${s}/jwt_customer`,t,r)}async jwt_markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`customers/${s}/jwt_markets`,t,r)}async jwt_stock_locations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`customers/${s}/jwt_stock_locations`,t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:E.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:E.TYPE,_remove_tags:t},r,s)}async _request_anonymization(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:E.TYPE,_request_anonymization:true},t,r)}async _cancel_anonymization(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:E.TYPE,_cancel_anonymization:true},t,r)}isCustomer(e){return e.type&&e.type===E.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return E.TYPE}};E.TYPE="customers";var li=E,mi=li;var Ge=class Ge extends n{async create(e,t,r){return this.resources.create({...e,type:Ge.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ge.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ge.TYPE}:e,t);}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`delivery_lead_times/${s}/stock_location`,t,r)}async shipping_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_methods"},`delivery_lead_times/${s}/shipping_method`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`delivery_lead_times/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`delivery_lead_times/${s}/versions`,t,r)}isDeliveryLeadTime(e){return e.type&&e.type===Ge.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ge.TYPE}};Ge.TYPE="delivery_lead_times";var yi=Ge,di=yi;var Nt=class Nt extends n{async discount_engine(e,t,r){let s=e.id||e;return this.resources.fetch({type:"discount_engines"},`discount_engine_items/${s}/discount_engine`,t,r)}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`discount_engine_items/${s}/order`,t,r)}isDiscountEngineItem(e){return e.type&&e.type===Nt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Nt.TYPE}};Nt.TYPE="discount_engine_items";var Ri=Nt,gi=Ri;var Zt=class Zt extends n{async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`discount_engines/${s}/markets`,t,r)}async discount_engine_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"discount_engine_items"},`discount_engines/${s}/discount_engine_items`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`discount_engines/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`discount_engines/${s}/versions`,t,r)}isDiscountEngine(e){return e.type&&e.type===Zt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Zt.TYPE}};Zt.TYPE="discount_engines";var _i=Zt,Pi=_i;var ae=class ae extends n{async create(e,t,r){return this.resources.create({...e,type:ae.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ae.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ae.TYPE}:e,t);}async shipment(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipments"},`easypost_pickups/${s}/shipment`,t,r)}async parcels(e,t,r){let s=e.id||e;return this.resources.fetch({type:"parcels"},`easypost_pickups/${s}/parcels`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`easypost_pickups/${s}/events`,t,r)}async _purchase(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:ae.TYPE,_purchase:true},t,r)}isEasypostPickup(e){return e.type&&e.type===ae.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ae.TYPE}};ae.TYPE="easypost_pickups";var hi=ae,fi=hi;var Ht=class Ht extends n{async webhook(e,t,r){let s=e.id||e;return this.resources.fetch({type:"webhooks"},`event_callbacks/${s}/webhook`,t,r)}isEventCallback(e){return e.type&&e.type===Ht.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ht.TYPE}};Ht.TYPE="event_callbacks";var ki=Ht,Ci=ki;var bt=class bt extends n{async update(e,t,r){return this.resources.update({...e,type:bt.TYPE},t,r)}async webhooks(e,t,r){let s=e.id||e;return this.resources.fetch({type:"webhooks"},`events/${s}/webhooks`,t,r)}async last_event_callbacks(e,t,r){let s=e.id||e;return this.resources.fetch({type:"event_callbacks"},`events/${s}/last_event_callbacks`,t,r)}async _trigger(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:bt.TYPE,_trigger:true},t,r)}isEvent(e){return e.type&&e.type===bt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return bt.TYPE}};bt.TYPE="events";var Ti=bt,Si=Ti;var ue=class ue extends n{async create(e,t,r){return this.resources.create({...e,type:ue.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ue.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ue.TYPE}:e,t);}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`exports/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`exports/${s}/versions`,t,r)}async _interrupt(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:ue.TYPE,_interrupt:true},t,r)}isExport(e){return e.type&&e.type===ue.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ue.TYPE}};ue.TYPE="exports";var vi=ue,xi=vi;var ce=class ce extends n{async create(e,t,r){return this.resources.create({...e,type:ce.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ce.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ce.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`external_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`external_gateways/${s}/versions`,t,r)}async external_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"external_payments"},`external_gateways/${s}/external_payments`,t,r)}async _reset_circuit(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:ce.TYPE,_reset_circuit:true},t,r)}isExternalGateway(e){return e.type&&e.type===ce.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ce.TYPE}};ce.TYPE="external_gateways";var Li=ce,bi=Li;var Ye=class Ye extends n{async create(e,t,r){return this.resources.create({...e,type:Ye.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ye.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ye.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`external_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`external_payments/${s}/payment_gateway`,t,r)}async wallet(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customer_payment_sources"},`external_payments/${s}/wallet`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`external_payments/${s}/versions`,t,r)}isExternalPayment(e){return e.type&&e.type===Ye.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ye.TYPE}};Ye.TYPE="external_payments";var Ei=Ye,wi=Ei;var S=class S extends n{async create(e,t,r){return this.resources.create({...e,type:S.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:S.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:S.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`external_promotions/${s}/market`,t,r)}async order_amount_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_amount_promotion_rules"},`external_promotions/${s}/order_amount_promotion_rule`,t,r)}async sku_list_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_promotion_rules"},`external_promotions/${s}/sku_list_promotion_rule`,t,r)}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`external_promotions/${s}/coupon_codes_promotion_rule`,t,r)}async custom_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"custom_promotion_rules"},`external_promotions/${s}/custom_promotion_rule`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`external_promotions/${s}/sku_list`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`external_promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`external_promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`external_promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`external_promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`external_promotions/${s}/versions`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`external_promotions/${s}/skus`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:S.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:S.TYPE,_enable:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:S.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:S.TYPE,_remove_tags:t},r,s)}async _reset_circuit(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:S.TYPE,_reset_circuit:true},t,r)}isExternalPromotion(e){return e.type&&e.type===S.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return S.TYPE}};S.TYPE="external_promotions";var Ai=S,Oi=Ai;var pe=class pe extends n{async create(e,t,r){return this.resources.create({...e,type:pe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:pe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:pe.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`external_tax_calculators/${s}/markets`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`external_tax_calculators/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`external_tax_calculators/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`external_tax_calculators/${s}/versions`,t,r)}async _reset_circuit(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:pe.TYPE,_reset_circuit:true},t,r)}isExternalTaxCalculator(e){return e.type&&e.type===pe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return pe.TYPE}};pe.TYPE="external_tax_calculators";var Ii=pe,Mi=Ii;var w=class w extends n{async create(e,t,r){return this.resources.create({...e,type:w.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:w.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:w.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`fixed_amount_promotions/${s}/market`,t,r)}async order_amount_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_amount_promotion_rules"},`fixed_amount_promotions/${s}/order_amount_promotion_rule`,t,r)}async sku_list_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_promotion_rules"},`fixed_amount_promotions/${s}/sku_list_promotion_rule`,t,r)}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`fixed_amount_promotions/${s}/coupon_codes_promotion_rule`,t,r)}async custom_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"custom_promotion_rules"},`fixed_amount_promotions/${s}/custom_promotion_rule`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`fixed_amount_promotions/${s}/sku_list`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`fixed_amount_promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`fixed_amount_promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`fixed_amount_promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`fixed_amount_promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`fixed_amount_promotions/${s}/versions`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`fixed_amount_promotions/${s}/skus`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:w.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:w.TYPE,_enable:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:w.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:w.TYPE,_remove_tags:t},r,s)}isFixedAmountPromotion(e){return e.type&&e.type===w.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return w.TYPE}};w.TYPE="fixed_amount_promotions";var Qi=w,Gi=Qi;var A=class A extends n{async create(e,t,r){return this.resources.create({...e,type:A.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:A.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:A.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`fixed_price_promotions/${s}/market`,t,r)}async order_amount_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_amount_promotion_rules"},`fixed_price_promotions/${s}/order_amount_promotion_rule`,t,r)}async sku_list_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_promotion_rules"},`fixed_price_promotions/${s}/sku_list_promotion_rule`,t,r)}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`fixed_price_promotions/${s}/coupon_codes_promotion_rule`,t,r)}async custom_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"custom_promotion_rules"},`fixed_price_promotions/${s}/custom_promotion_rule`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`fixed_price_promotions/${s}/sku_list`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`fixed_price_promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`fixed_price_promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`fixed_price_promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`fixed_price_promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`fixed_price_promotions/${s}/versions`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`fixed_price_promotions/${s}/skus`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:A.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:A.TYPE,_enable:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:A.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:A.TYPE,_remove_tags:t},r,s)}isFixedPricePromotion(e){return e.type&&e.type===A.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return A.TYPE}};A.TYPE="fixed_price_promotions";var Yi=A,Ui=Yi;var O=class O extends n{async create(e,t,r){return this.resources.create({...e,type:O.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:O.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:O.TYPE}:e,t);}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`flex_promotions/${s}/coupon_codes_promotion_rule`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`flex_promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`flex_promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`flex_promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`flex_promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`flex_promotions/${s}/versions`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:O.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:O.TYPE,_enable:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:O.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:O.TYPE,_remove_tags:t},r,s)}isFlexPromotion(e){return e.type&&e.type===O.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return O.TYPE}};O.TYPE="flex_promotions";var Vi=O,Fi=Vi;var I=class I extends n{async create(e,t,r){return this.resources.create({...e,type:I.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:I.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:I.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`free_gift_promotions/${s}/market`,t,r)}async order_amount_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_amount_promotion_rules"},`free_gift_promotions/${s}/order_amount_promotion_rule`,t,r)}async sku_list_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_promotion_rules"},`free_gift_promotions/${s}/sku_list_promotion_rule`,t,r)}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`free_gift_promotions/${s}/coupon_codes_promotion_rule`,t,r)}async custom_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"custom_promotion_rules"},`free_gift_promotions/${s}/custom_promotion_rule`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`free_gift_promotions/${s}/sku_list`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`free_gift_promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`free_gift_promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`free_gift_promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`free_gift_promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`free_gift_promotions/${s}/versions`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`free_gift_promotions/${s}/skus`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:I.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:I.TYPE,_enable:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:I.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:I.TYPE,_remove_tags:t},r,s)}isFreeGiftPromotion(e){return e.type&&e.type===I.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return I.TYPE}};I.TYPE="free_gift_promotions";var $i=I,Bi=$i;var M=class M extends n{async create(e,t,r){return this.resources.create({...e,type:M.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:M.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:M.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`free_shipping_promotions/${s}/market`,t,r)}async order_amount_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_amount_promotion_rules"},`free_shipping_promotions/${s}/order_amount_promotion_rule`,t,r)}async sku_list_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_promotion_rules"},`free_shipping_promotions/${s}/sku_list_promotion_rule`,t,r)}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`free_shipping_promotions/${s}/coupon_codes_promotion_rule`,t,r)}async custom_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"custom_promotion_rules"},`free_shipping_promotions/${s}/custom_promotion_rule`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`free_shipping_promotions/${s}/sku_list`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`free_shipping_promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`free_shipping_promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`free_shipping_promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`free_shipping_promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`free_shipping_promotions/${s}/versions`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:M.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:M.TYPE,_enable:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:M.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:M.TYPE,_remove_tags:t},r,s)}isFreeShippingPromotion(e){return e.type&&e.type===M.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return M.TYPE}};M.TYPE="free_shipping_promotions";var qi=M,Di=qi;var Jt=class Jt extends n{async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`geocoders/${s}/markets`,t,r)}async addresses(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`geocoders/${s}/addresses`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`geocoders/${s}/attachments`,t,r)}isGeocoder(e){return e.type&&e.type===Jt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Jt.TYPE}};Jt.TYPE="geocoders";var zi=Jt,ji=zi;var Ue=class Ue extends n{async create(e,t,r){return this.resources.create({...e,type:Ue.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ue.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ue.TYPE}:e,t);}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`gift_card_recipients/${s}/customer`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`gift_card_recipients/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`gift_card_recipients/${s}/versions`,t,r)}isGiftCardRecipient(e){return e.type&&e.type===Ue.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ue.TYPE}};Ue.TYPE="gift_card_recipients";var Wi=Ue,Ki=Wi;var f=class f extends n{async create(e,t,r){return this.resources.create({...e,type:f.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:f.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:f.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`gift_cards/${s}/market`,t,r)}async gift_card_recipient(e,t,r){let s=e.id||e;return this.resources.fetch({type:"gift_card_recipients"},`gift_cards/${s}/gift_card_recipient`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`gift_cards/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`gift_cards/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`gift_cards/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`gift_cards/${s}/versions`,t,r)}async _purchase(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:f.TYPE,_purchase:true},t,r)}async _activate(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:f.TYPE,_activate:true},t,r)}async _deactivate(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:f.TYPE,_deactivate:true},t,r)}async _balance_change_cents(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:f.TYPE,_balance_change_cents:t},r,s)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:f.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:f.TYPE,_remove_tags:t},r,s)}isGiftCard(e){return e.type&&e.type===f.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return f.TYPE}};f.TYPE="gift_cards";var Xi=f,Ni=Xi;var Ve=class Ve extends n{async create(e,t,r){return this.resources.create({...e,type:Ve.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ve.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ve.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`google_geocoders/${s}/markets`,t,r)}async addresses(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`google_geocoders/${s}/addresses`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`google_geocoders/${s}/attachments`,t,r)}isGoogleGeocoder(e){return e.type&&e.type===Ve.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ve.TYPE}};Ve.TYPE="google_geocoders";var Zi=Ve,Hi=Zi;var le=class le extends n{async create(e,t,r){return this.resources.create({...e,type:le.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:le.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:le.TYPE}:e,t);}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`imports/${s}/events`,t,r)}async _interrupt(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:le.TYPE,_interrupt:true},t,r)}isImport(e){return e.type&&e.type===le.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return le.TYPE}};le.TYPE="imports";var Ji=le,ea=Ji;var W=class W extends n{async create(e,t,r){return this.resources.create({...e,type:W.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:W.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:W.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`in_stock_subscriptions/${s}/market`,t,r)}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`in_stock_subscriptions/${s}/customer`,t,r)}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`in_stock_subscriptions/${s}/sku`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`in_stock_subscriptions/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`in_stock_subscriptions/${s}/versions`,t,r)}async _activate(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:W.TYPE,_activate:true},t,r)}async _deactivate(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:W.TYPE,_deactivate:true},t,r)}isInStockSubscription(e){return e.type&&e.type===W.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return W.TYPE}};W.TYPE="in_stock_subscriptions";var ta=W,ra=ta;var Fe=class Fe extends n{async create(e,t,r){return this.resources.create({...e,type:Fe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Fe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Fe.TYPE}:e,t);}async inventory_stock_locations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"inventory_stock_locations"},`inventory_models/${s}/inventory_stock_locations`,t,r)}async inventory_return_locations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"inventory_return_locations"},`inventory_models/${s}/inventory_return_locations`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`inventory_models/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`inventory_models/${s}/versions`,t,r)}isInventoryModel(e){return e.type&&e.type===Fe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Fe.TYPE}};Fe.TYPE="inventory_models";var sa=Fe,oa=sa;var $e=class $e extends n{async create(e,t,r){return this.resources.create({...e,type:$e.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:$e.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:$e.TYPE}:e,t);}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`inventory_return_locations/${s}/stock_location`,t,r)}async inventory_model(e,t,r){let s=e.id||e;return this.resources.fetch({type:"inventory_models"},`inventory_return_locations/${s}/inventory_model`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`inventory_return_locations/${s}/versions`,t,r)}isInventoryReturnLocation(e){return e.type&&e.type===$e.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return $e.TYPE}};$e.TYPE="inventory_return_locations";var na=$e,ia=na;var Be=class Be extends n{async create(e,t,r){return this.resources.create({...e,type:Be.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Be.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Be.TYPE}:e,t);}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`inventory_stock_locations/${s}/stock_location`,t,r)}async inventory_model(e,t,r){let s=e.id||e;return this.resources.fetch({type:"inventory_models"},`inventory_stock_locations/${s}/inventory_model`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`inventory_stock_locations/${s}/versions`,t,r)}isInventoryStockLocation(e){return e.type&&e.type===Be.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Be.TYPE}};Be.TYPE="inventory_stock_locations";var aa=Be,ua=aa;var qe=class qe extends n{async create(e,t,r){return this.resources.create({...e,type:qe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:qe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:qe.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`klarna_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`klarna_gateways/${s}/versions`,t,r)}async klarna_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"klarna_payments"},`klarna_gateways/${s}/klarna_payments`,t,r)}isKlarnaGateway(e){return e.type&&e.type===qe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return qe.TYPE}};qe.TYPE="klarna_gateways";var ca=qe,pa=ca;var me=class me extends n{async create(e,t,r){return this.resources.create({...e,type:me.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:me.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:me.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`klarna_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`klarna_payments/${s}/payment_gateway`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`klarna_payments/${s}/versions`,t,r)}async _update(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:me.TYPE,_update:true},t,r)}isKlarnaPayment(e){return e.type&&e.type===me.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return me.TYPE}};me.TYPE="klarna_payments";var la=me,ma=la;var K=class K extends n{async create(e,t,r){return this.resources.create({...e,type:K.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:K.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:K.TYPE}:e,t);}async line_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_items"},`line_item_options/${s}/line_item`,t,r)}async sku_option(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_options"},`line_item_options/${s}/sku_option`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`line_item_options/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`line_item_options/${s}/tags`,t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:K.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:K.TYPE,_remove_tags:t},r,s)}isLineItemOption(e){return e.type&&e.type===K.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return K.TYPE}};K.TYPE="line_item_options";var ya=K,da=ya;var v=class v extends n{async create(e,t,r){return this.resources.create({...e,type:v.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:v.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:v.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`line_items/${s}/order`,t,r)}async line_item_options(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_item_options"},`line_items/${s}/line_item_options`,t,r)}async return_line_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"return_line_items"},`line_items/${s}/return_line_items`,t,r)}async stock_reservations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_reservations"},`line_items/${s}/stock_reservations`,t,r)}async stock_line_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_line_items"},`line_items/${s}/stock_line_items`,t,r)}async stock_transfers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_transfers"},`line_items/${s}/stock_transfers`,t,r)}async notifications(e,t,r){let s=e.id||e;return this.resources.fetch({type:"notifications"},`line_items/${s}/notifications`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`line_items/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`line_items/${s}/tags`,t,r)}async _external_price(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:v.TYPE,_external_price:true},t,r)}async _reserve_stock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:v.TYPE,_reserve_stock:true},t,r)}async _reset_circuit(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:v.TYPE,_reset_circuit:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:v.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:v.TYPE,_remove_tags:t},r,s)}isLineItem(e){return e.type&&e.type===v.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return v.TYPE}};v.TYPE="line_items";var Ra=v,ga=Ra;var X=class X extends n{async create(e,t,r){return this.resources.create({...e,type:X.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:X.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:X.TYPE}:e,t);}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`links/${s}/events`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:X.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:X.TYPE,_enable:true},t,r)}isLink(e){return e.type&&e.type===X.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return X.TYPE}};X.TYPE="links";var _a=X,Pa=_a;var De=class De extends n{async create(e,t,r){return this.resources.create({...e,type:De.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:De.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:De.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`manual_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`manual_gateways/${s}/versions`,t,r)}isManualGateway(e){return e.type&&e.type===De.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return De.TYPE}};De.TYPE="manual_gateways";var ha=De,fa=ha;var ze=class ze extends n{async create(e,t,r){return this.resources.create({...e,type:ze.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ze.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ze.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`manual_tax_calculators/${s}/markets`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`manual_tax_calculators/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`manual_tax_calculators/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`manual_tax_calculators/${s}/versions`,t,r)}async tax_rules(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tax_rules"},`manual_tax_calculators/${s}/tax_rules`,t,r)}isManualTaxCalculator(e){return e.type&&e.type===ze.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ze.TYPE}};ze.TYPE="manual_tax_calculators";var ka=ze,Ca=ka;var N=class N extends n{async create(e,t,r){return this.resources.create({...e,type:N.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:N.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:N.TYPE}:e,t);}async merchant(e,t,r){let s=e.id||e;return this.resources.fetch({type:"merchants"},`markets/${s}/merchant`,t,r)}async price_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_lists"},`markets/${s}/price_list`,t,r)}async base_price_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_lists"},`markets/${s}/base_price_list`,t,r)}async inventory_model(e,t,r){let s=e.id||e;return this.resources.fetch({type:"inventory_models"},`markets/${s}/inventory_model`,t,r)}async subscription_model(e,t,r){let s=e.id||e;return this.resources.fetch({type:"subscription_models"},`markets/${s}/subscription_model`,t,r)}async discount_engine(e,t,r){let s=e.id||e;return this.resources.fetch({type:"discount_engines"},`markets/${s}/discount_engine`,t,r)}async tax_calculator(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tax_calculators"},`markets/${s}/tax_calculator`,t,r)}async customer_group(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customer_groups"},`markets/${s}/customer_group`,t,r)}async geocoder(e,t,r){let s=e.id||e;return this.resources.fetch({type:"geocoders"},`markets/${s}/geocoder`,t,r)}async default_shipping_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_methods"},`markets/${s}/default_shipping_method`,t,r)}async default_payment_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`markets/${s}/default_payment_method`,t,r)}async stores(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stores"},`markets/${s}/stores`,t,r)}async price_list_schedulers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_list_schedulers"},`markets/${s}/price_list_schedulers`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`markets/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`markets/${s}/versions`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:N.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:N.TYPE,_enable:true},t,r)}isMarket(e){return e.type&&e.type===N.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return N.TYPE}};N.TYPE="markets";var Ta=N,Sa=Ta;var je=class je extends n{async create(e,t,r){return this.resources.create({...e,type:je.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:je.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:je.TYPE}:e,t);}async address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`merchants/${s}/address`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`merchants/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`merchants/${s}/versions`,t,r)}isMerchant(e){return e.type&&e.type===je.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return je.TYPE}};je.TYPE="merchants";var va=je,xa=va;var We=class We extends n{async create(e,t,r){return this.resources.create({...e,type:We.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:We.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:We.TYPE}:e,t);}isNotification(e){return e.type&&e.type===We.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return We.TYPE}};We.TYPE="notifications";var La=We,ba=La;var Ke=class Ke extends n{async create(e,t,r){return this.resources.create({...e,type:Ke.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ke.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ke.TYPE}:e,t);}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`order_amount_promotion_rules/${s}/versions`,t,r)}isOrderAmountPromotionRule(e){return e.type&&e.type===Ke.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ke.TYPE}};Ke.TYPE="order_amount_promotion_rules";var Ea=Ke,wa=Ea;var Xe=class Xe extends n{async create(e,t,r){return this.resources.create({...e,type:Xe.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Xe.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Xe.TYPE}:e,t);}async source_order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`order_copies/${s}/source_order`,t,r)}async target_order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`order_copies/${s}/target_order`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`order_copies/${s}/events`,t,r)}async order_subscription(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_subscriptions"},`order_copies/${s}/order_subscription`,t,r)}isOrderCopy(e){return e.type&&e.type===Xe.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Xe.TYPE}};Xe.TYPE="order_copies";var Aa=Xe,Oa=Aa;var er=class er extends n{async source_order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`order_factories/${s}/source_order`,t,r)}async target_order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`order_factories/${s}/target_order`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`order_factories/${s}/events`,t,r)}isOrderFactory(e){return e.type&&e.type===er.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return er.TYPE}};er.TYPE="order_factories";var Ia=er,Ma=Ia;var Ne=class Ne extends n{async create(e,t,r){return this.resources.create({...e,type:Ne.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ne.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ne.TYPE}:e,t);}async order_subscription(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_subscriptions"},`order_subscription_items/${s}/order_subscription`,t,r)}async source_line_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_items"},`order_subscription_items/${s}/source_line_item`,t,r)}isOrderSubscriptionItem(e){return e.type&&e.type===Ne.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ne.TYPE}};Ne.TYPE="order_subscription_items";var Qa=Ne,Ga=Qa;var k=class k extends n{async create(e,t,r){return this.resources.create({...e,type:k.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:k.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:k.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`order_subscriptions/${s}/market`,t,r)}async subscription_model(e,t,r){let s=e.id||e;return this.resources.fetch({type:"subscription_models"},`order_subscriptions/${s}/subscription_model`,t,r)}async source_order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`order_subscriptions/${s}/source_order`,t,r)}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`order_subscriptions/${s}/customer`,t,r)}async customer_payment_source(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customer_payment_sources"},`order_subscriptions/${s}/customer_payment_source`,t,r)}async order_subscription_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_subscription_items"},`order_subscriptions/${s}/order_subscription_items`,t,r)}async order_factories(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_factories"},`order_subscriptions/${s}/order_factories`,t,r)}async recurring_order_copies(e,t,r){let s=e.id||e;return this.resources.fetch({type:"recurring_order_copies"},`order_subscriptions/${s}/recurring_order_copies`,t,r)}async orders(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`order_subscriptions/${s}/orders`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`order_subscriptions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`order_subscriptions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`order_subscriptions/${s}/versions`,t,r)}async _activate(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:k.TYPE,_activate:true},t,r)}async _deactivate(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:k.TYPE,_deactivate:true},t,r)}async _cancel(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:k.TYPE,_cancel:true},t,r)}async _convert(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:k.TYPE,_convert:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:k.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:k.TYPE,_remove_tags:t},r,s)}isOrderSubscription(e){return e.type&&e.type===k.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return k.TYPE}};k.TYPE="order_subscriptions";var Ya=k,Ua=Ya;var y=class y extends n{async create(e,t,r){return this.resources.create({...e,type:y.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:y.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:y.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`orders/${s}/market`,t,r)}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`orders/${s}/customer`,t,r)}async shipping_address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`orders/${s}/shipping_address`,t,r)}async billing_address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`orders/${s}/billing_address`,t,r)}async store(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stores"},`orders/${s}/store`,t,r)}async default_shipping_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_methods"},`orders/${s}/default_shipping_method`,t,r)}async default_payment_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`orders/${s}/default_payment_method`,t,r)}async available_payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`orders/${s}/available_payment_methods`,t,r)}async available_customer_payment_sources(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customer_payment_sources"},`orders/${s}/available_customer_payment_sources`,t,r)}async available_free_skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`orders/${s}/available_free_skus`,t,r)}async available_free_bundles(e,t,r){let s=e.id||e;return this.resources.fetch({type:"bundles"},`orders/${s}/available_free_bundles`,t,r)}async payment_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`orders/${s}/payment_method`,t,r)}async discount_engine_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"discount_engine_items"},`orders/${s}/discount_engine_item`,t,r)}async line_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_items"},`orders/${s}/line_items`,t,r)}async line_item_options(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_item_options"},`orders/${s}/line_item_options`,t,r)}async stock_reservations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_reservations"},`orders/${s}/stock_reservations`,t,r)}async stock_line_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_line_items"},`orders/${s}/stock_line_items`,t,r)}async stock_transfers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_transfers"},`orders/${s}/stock_transfers`,t,r)}async shipments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipments"},`orders/${s}/shipments`,t,r)}async payment_options(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_options"},`orders/${s}/payment_options`,t,r)}async authorizations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"authorizations"},`orders/${s}/authorizations`,t,r)}async captures(e,t,r){let s=e.id||e;return this.resources.fetch({type:"captures"},`orders/${s}/captures`,t,r)}async voids(e,t,r){let s=e.id||e;return this.resources.fetch({type:"voids"},`orders/${s}/voids`,t,r)}async refunds(e,t,r){let s=e.id||e;return this.resources.fetch({type:"refunds"},`orders/${s}/refunds`,t,r)}async returns(e,t,r){let s=e.id||e;return this.resources.fetch({type:"returns"},`orders/${s}/returns`,t,r)}async order_subscription(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_subscriptions"},`orders/${s}/order_subscription`,t,r)}async order_subscriptions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_subscriptions"},`orders/${s}/order_subscriptions`,t,r)}async order_factories(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_factories"},`orders/${s}/order_factories`,t,r)}async order_copies(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_copies"},`orders/${s}/order_copies`,t,r)}async recurring_order_copies(e,t,r){let s=e.id||e;return this.resources.fetch({type:"recurring_order_copies"},`orders/${s}/recurring_order_copies`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`orders/${s}/attachments`,t,r)}async notifications(e,t,r){let s=e.id||e;return this.resources.fetch({type:"notifications"},`orders/${s}/notifications`,t,r)}async links(e,t,r){let s=e.id||e;return this.resources.fetch({type:"links"},`orders/${s}/links`,t,r)}async resource_errors(e,t,r){let s=e.id||e;return this.resources.fetch({type:"resource_errors"},`orders/${s}/resource_errors`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`orders/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`orders/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`orders/${s}/versions`,t,r)}async _archive(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_archive:true},t,r)}async _unarchive(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_unarchive:true},t,r)}async _pending(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_pending:true},t,r)}async _place(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_place:true},t,r)}async _cancel(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_cancel:true},t,r)}async _approve(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_approve:true},t,r)}async _approve_and_capture(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_approve_and_capture:true},t,r)}async _authorize(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_authorize:true},t,r)}async _authorization_amount_cents(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_authorization_amount_cents:t},r,s)}async _capture(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_capture:true},t,r)}async _refund(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_refund:true},t,r)}async _fulfill(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_fulfill:true},t,r)}async _update_taxes(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_update_taxes:true},t,r)}async _nullify_payment_source(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_nullify_payment_source:true},t,r)}async _fix_payment_source(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_fix_payment_source:true},t,r)}async _billing_address_clone_id(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_billing_address_clone_id:t},r,s)}async _shipping_address_clone_id(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_shipping_address_clone_id:t},r,s)}async _customer_payment_source_id(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_customer_payment_source_id:t},r,s)}async _shipping_address_same_as_billing(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_shipping_address_same_as_billing:true},t,r)}async _billing_address_same_as_shipping(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_billing_address_same_as_shipping:true},t,r)}async _commit_invoice(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_commit_invoice:true},t,r)}async _refund_invoice(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_refund_invoice:true},t,r)}async _save_payment_source_to_customer_wallet(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_save_payment_source_to_customer_wallet:true},t,r)}async _save_shipping_address_to_customer_address_book(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_save_shipping_address_to_customer_address_book:true},t,r)}async _save_billing_address_to_customer_address_book(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_save_billing_address_to_customer_address_book:true},t,r)}async _refresh(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_refresh:true},t,r)}async _validate(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_validate:true},t,r)}async _create_subscriptions(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_create_subscriptions:true},t,r)}async _start_editing(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_start_editing:true},t,r)}async _stop_editing(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_stop_editing:true},t,r)}async _reset_circuit(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_reset_circuit:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:y.TYPE,_remove_tags:t},r,s)}isOrder(e){return e.type&&e.type===y.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return y.TYPE}};y.TYPE="orders";var Va=y,Fa=Va;var tr=class tr extends Mt{isOrganization(e){return e.type&&e.type===tr.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return tr.TYPE}path(){return "organization"}};tr.TYPE="organizations";var $a=tr,Ba=$a;var Ze=class Ze extends n{async create(e,t,r){return this.resources.create({...e,type:Ze.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ze.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ze.TYPE}:e,t);}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`packages/${s}/stock_location`,t,r)}async parcels(e,t,r){let s=e.id||e;return this.resources.fetch({type:"parcels"},`packages/${s}/parcels`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`packages/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`packages/${s}/versions`,t,r)}isPackage(e){return e.type&&e.type===Ze.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ze.TYPE}};Ze.TYPE="packages";var qa=Ze,Da=qa;var He=class He extends n{async create(e,t,r){return this.resources.create({...e,type:He.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:He.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:He.TYPE}:e,t);}async parcel(e,t,r){let s=e.id||e;return this.resources.fetch({type:"parcels"},`parcel_line_items/${s}/parcel`,t,r)}async stock_line_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_line_items"},`parcel_line_items/${s}/stock_line_item`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`parcel_line_items/${s}/versions`,t,r)}isParcelLineItem(e){return e.type&&e.type===He.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return He.TYPE}};He.TYPE="parcel_line_items";var za=He,ja=za;var Je=class Je extends n{async create(e,t,r){return this.resources.create({...e,type:Je.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Je.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Je.TYPE}:e,t);}async shipment(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipments"},`parcels/${s}/shipment`,t,r)}async package(e,t,r){let s=e.id||e;return this.resources.fetch({type:"packages"},`parcels/${s}/package`,t,r)}async parcel_line_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"parcel_line_items"},`parcels/${s}/parcel_line_items`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`parcels/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`parcels/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`parcels/${s}/versions`,t,r)}isParcel(e){return e.type&&e.type===Je.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Je.TYPE}};Je.TYPE="parcels";var Wa=Je,Ka=Wa;var rr=class rr extends n{async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`payment_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`payment_gateways/${s}/versions`,t,r)}isPaymentGateway(e){return e.type&&e.type===rr.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return rr.TYPE}};rr.TYPE="payment_gateways";var Xa=rr,Na=Xa;var Z=class Z extends n{async create(e,t,r){return this.resources.create({...e,type:Z.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Z.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Z.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`payment_methods/${s}/market`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`payment_methods/${s}/payment_gateway`,t,r)}async store(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stores"},`payment_methods/${s}/store`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`payment_methods/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`payment_methods/${s}/versions`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:Z.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:Z.TYPE,_enable:true},t,r)}isPaymentMethod(e){return e.type&&e.type===Z.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Z.TYPE}};Z.TYPE="payment_methods";var Za=Z,Ha=Za;var et=class et extends n{async create(e,t,r){return this.resources.create({...e,type:et.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:et.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:et.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`payment_options/${s}/order`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`payment_options/${s}/attachments`,t,r)}isPaymentOption(e){return e.type&&e.type===et.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return et.TYPE}};et.TYPE="payment_options";var Ja=et,eu=Ja;var tt=class tt extends n{async create(e,t,r){return this.resources.create({...e,type:tt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:tt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:tt.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`paypal_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`paypal_gateways/${s}/versions`,t,r)}async paypal_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"paypal_payments"},`paypal_gateways/${s}/paypal_payments`,t,r)}isPaypalGateway(e){return e.type&&e.type===tt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return tt.TYPE}};tt.TYPE="paypal_gateways";var tu=tt,ru=tu;var rt=class rt extends n{async create(e,t,r){return this.resources.create({...e,type:rt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:rt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:rt.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`paypal_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`paypal_payments/${s}/payment_gateway`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`paypal_payments/${s}/versions`,t,r)}isPaypalPayment(e){return e.type&&e.type===rt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return rt.TYPE}};rt.TYPE="paypal_payments";var su=rt,ou=su;var Q=class Q extends n{async create(e,t,r){return this.resources.create({...e,type:Q.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Q.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Q.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`percentage_discount_promotions/${s}/market`,t,r)}async order_amount_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_amount_promotion_rules"},`percentage_discount_promotions/${s}/order_amount_promotion_rule`,t,r)}async sku_list_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_promotion_rules"},`percentage_discount_promotions/${s}/sku_list_promotion_rule`,t,r)}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`percentage_discount_promotions/${s}/coupon_codes_promotion_rule`,t,r)}async custom_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"custom_promotion_rules"},`percentage_discount_promotions/${s}/custom_promotion_rule`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`percentage_discount_promotions/${s}/sku_list`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`percentage_discount_promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`percentage_discount_promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`percentage_discount_promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`percentage_discount_promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`percentage_discount_promotions/${s}/versions`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`percentage_discount_promotions/${s}/skus`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:Q.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:Q.TYPE,_enable:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:Q.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:Q.TYPE,_remove_tags:t},r,s)}isPercentageDiscountPromotion(e){return e.type&&e.type===Q.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Q.TYPE}};Q.TYPE="percentage_discount_promotions";var nu=Q,iu=nu;var sr=class sr extends n{async shipment(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipments"},`pickups/${s}/shipment`,t,r)}async parcels(e,t,r){let s=e.id||e;return this.resources.fetch({type:"parcels"},`pickups/${s}/parcels`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`pickups/${s}/events`,t,r)}isPickup(e){return e.type&&e.type===sr.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return sr.TYPE}};sr.TYPE="pickups";var au=sr,uu=au;var st=class st extends n{async create(e,t,r){return this.resources.create({...e,type:st.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:st.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:st.TYPE}:e,t);}async price(e,t,r){let s=e.id||e;return this.resources.fetch({type:"prices"},`price_frequency_tiers/${s}/price`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`price_frequency_tiers/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`price_frequency_tiers/${s}/versions`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`price_frequency_tiers/${s}/events`,t,r)}isPriceFrequencyTier(e){return e.type&&e.type===st.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return st.TYPE}};st.TYPE="price_frequency_tiers";var cu=st,pu=cu;var H=class H extends n{async create(e,t,r){return this.resources.create({...e,type:H.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:H.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:H.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`price_list_schedulers/${s}/market`,t,r)}async price_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_lists"},`price_list_schedulers/${s}/price_list`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`price_list_schedulers/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`price_list_schedulers/${s}/versions`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:H.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:H.TYPE,_enable:true},t,r)}isPriceListScheduler(e){return e.type&&e.type===H.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return H.TYPE}};H.TYPE="price_list_schedulers";var lu=H,mu=lu;var ot=class ot extends n{async create(e,t,r){return this.resources.create({...e,type:ot.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ot.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ot.TYPE}:e,t);}async prices(e,t,r){let s=e.id||e;return this.resources.fetch({type:"prices"},`price_lists/${s}/prices`,t,r)}async price_list_schedulers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_list_schedulers"},`price_lists/${s}/price_list_schedulers`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`price_lists/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`price_lists/${s}/versions`,t,r)}isPriceList(e){return e.type&&e.type===ot.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ot.TYPE}};ot.TYPE="price_lists";var yu=ot,du=yu;var or=class or extends n{async price(e,t,r){let s=e.id||e;return this.resources.fetch({type:"prices"},`price_tiers/${s}/price`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`price_tiers/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`price_tiers/${s}/versions`,t,r)}isPriceTier(e){return e.type&&e.type===or.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return or.TYPE}};or.TYPE="price_tiers";var Ru=or,gu=Ru;var nt=class nt extends n{async create(e,t,r){return this.resources.create({...e,type:nt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:nt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:nt.TYPE}:e,t);}async price(e,t,r){let s=e.id||e;return this.resources.fetch({type:"prices"},`price_volume_tiers/${s}/price`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`price_volume_tiers/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`price_volume_tiers/${s}/versions`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`price_volume_tiers/${s}/events`,t,r)}isPriceVolumeTier(e){return e.type&&e.type===nt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return nt.TYPE}};nt.TYPE="price_volume_tiers";var _u=nt,Pu=_u;var it=class it extends n{async create(e,t,r){return this.resources.create({...e,type:it.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:it.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:it.TYPE}:e,t);}async price_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_lists"},`prices/${s}/price_list`,t,r)}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`prices/${s}/sku`,t,r)}async price_tiers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_tiers"},`prices/${s}/price_tiers`,t,r)}async price_volume_tiers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_volume_tiers"},`prices/${s}/price_volume_tiers`,t,r)}async price_frequency_tiers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"price_frequency_tiers"},`prices/${s}/price_frequency_tiers`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`prices/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`prices/${s}/versions`,t,r)}async jwt_customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`prices/${s}/jwt_customer`,t,r)}async jwt_markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`prices/${s}/jwt_markets`,t,r)}async jwt_stock_locations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`prices/${s}/jwt_stock_locations`,t,r)}isPrice(e){return e.type&&e.type===it.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return it.TYPE}};it.TYPE="prices";var hu=it,fu=hu;var nr=class nr extends n{async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`promotion_rules/${s}/versions`,t,r)}isPromotionRule(e){return e.type&&e.type===nr.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return nr.TYPE}};nr.TYPE="promotion_rules";var ku=nr,Cu=ku;var ir=class ir extends n{async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`promotions/${s}/market`,t,r)}async order_amount_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_amount_promotion_rules"},`promotions/${s}/order_amount_promotion_rule`,t,r)}async sku_list_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_promotion_rules"},`promotions/${s}/sku_list_promotion_rule`,t,r)}async coupon_codes_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupon_codes_promotion_rules"},`promotions/${s}/coupon_codes_promotion_rule`,t,r)}async custom_promotion_rule(e,t,r){let s=e.id||e;return this.resources.fetch({type:"custom_promotion_rules"},`promotions/${s}/custom_promotion_rule`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`promotions/${s}/sku_list`,t,r)}async coupons(e,t,r){let s=e.id||e;return this.resources.fetch({type:"coupons"},`promotions/${s}/coupons`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`promotions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`promotions/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`promotions/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`promotions/${s}/versions`,t,r)}isPromotion(e){return e.type&&e.type===ir.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ir.TYPE}};ir.TYPE="promotions";var Tu=ir,Su=Tu;var at=class at extends n{async create(e,t,r){return this.resources.create({...e,type:at.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:at.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:at.TYPE}:e,t);}async source_order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`recurring_order_copies/${s}/source_order`,t,r)}async target_order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`recurring_order_copies/${s}/target_order`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`recurring_order_copies/${s}/events`,t,r)}async order_subscription(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_subscriptions"},`recurring_order_copies/${s}/order_subscription`,t,r)}isRecurringOrderCopy(e){return e.type&&e.type===at.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return at.TYPE}};at.TYPE="recurring_order_copies";var vu=at,xu=vu;var Et=class Et extends n{async update(e,t,r){return this.resources.update({...e,type:Et.TYPE},t,r)}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`refunds/${s}/order`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`refunds/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`refunds/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`refunds/${s}/versions`,t,r)}async reference_capture(e,t,r){let s=e.id||e;return this.resources.fetch({type:"captures"},`refunds/${s}/reference_capture`,t,r)}async return(e,t,r){let s=e.id||e;return this.resources.fetch({type:"returns"},`refunds/${s}/return`,t,r)}async _forward(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:Et.TYPE,_forward:true},t,r)}isRefund(e){return e.type&&e.type===Et.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Et.TYPE}};Et.TYPE="refunds";var Lu=Et,bu=Lu;var ar=class ar extends n{async stock_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_items"},`reserved_stocks/${s}/stock_item`,t,r)}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`reserved_stocks/${s}/sku`,t,r)}async stock_reservations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_reservations"},`reserved_stocks/${s}/stock_reservations`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`reserved_stocks/${s}/versions`,t,r)}isReservedStock(e){return e.type&&e.type===ar.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ar.TYPE}};ar.TYPE="reserved_stocks";var Eu=ar,wu=Eu;var ur=class ur extends n{isResourceError(e){return e.type&&e.type===ur.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ur.TYPE}};ur.TYPE="resource_errors";var Au=ur,Ou=Au;var ye=class ye extends n{async create(e,t,r){return this.resources.create({...e,type:ye.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ye.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ye.TYPE}:e,t);}async return(e,t,r){let s=e.id||e;return this.resources.fetch({type:"returns"},`return_line_items/${s}/return`,t,r)}async line_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_items"},`return_line_items/${s}/line_item`,t,r)}async _restock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:ye.TYPE,_restock:true},t,r)}isReturnLineItem(e){return e.type&&e.type===ye.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ye.TYPE}};ye.TYPE="return_line_items";var Iu=ye,Mu=Iu;var _=class _ extends n{async create(e,t,r){return this.resources.create({...e,type:_.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:_.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:_.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`returns/${s}/order`,t,r)}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`returns/${s}/customer`,t,r)}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`returns/${s}/stock_location`,t,r)}async origin_address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`returns/${s}/origin_address`,t,r)}async destination_address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`returns/${s}/destination_address`,t,r)}async reference_capture(e,t,r){let s=e.id||e;return this.resources.fetch({type:"captures"},`returns/${s}/reference_capture`,t,r)}async reference_refund(e,t,r){let s=e.id||e;return this.resources.fetch({type:"refunds"},`returns/${s}/reference_refund`,t,r)}async return_line_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"return_line_items"},`returns/${s}/return_line_items`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`returns/${s}/attachments`,t,r)}async resource_errors(e,t,r){let s=e.id||e;return this.resources.fetch({type:"resource_errors"},`returns/${s}/resource_errors`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`returns/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`returns/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`returns/${s}/versions`,t,r)}async _request(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_request:true},t,r)}async _approve(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_approve:true},t,r)}async _cancel(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_cancel:true},t,r)}async _ship(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_ship:true},t,r)}async _reject(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_reject:true},t,r)}async _receive(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_receive:true},t,r)}async _restock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_restock:true},t,r)}async _archive(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_archive:true},t,r)}async _unarchive(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_unarchive:true},t,r)}async _refund(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_refund:true},t,r)}async _refund_amount_cents(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_refund_amount_cents:t},r,s)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:_.TYPE,_remove_tags:t},r,s)}isReturn(e){return e.type&&e.type===_.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return _.TYPE}};_.TYPE="returns";var Qu=_,Gu=Qu;var ut=class ut extends n{async create(e,t,r){return this.resources.create({...e,type:ut.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ut.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ut.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`satispay_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`satispay_gateways/${s}/versions`,t,r)}async satispay_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"satispay_payments"},`satispay_gateways/${s}/satispay_payments`,t,r)}isSatispayGateway(e){return e.type&&e.type===ut.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ut.TYPE}};ut.TYPE="satispay_gateways";var Yu=ut,Uu=Yu;var de=class de extends n{async create(e,t,r){return this.resources.create({...e,type:de.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:de.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:de.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`satispay_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`satispay_payments/${s}/payment_gateway`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`satispay_payments/${s}/versions`,t,r)}async _refresh(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:de.TYPE,_refresh:true},t,r)}isSatispayPayment(e){return e.type&&e.type===de.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return de.TYPE}};de.TYPE="satispay_payments";var Vu=de,Fu=Vu;var g=class g extends n{async create(e,t,r){return this.resources.create({...e,type:g.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:g.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:g.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`shipments/${s}/order`,t,r)}async shipping_category(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_categories"},`shipments/${s}/shipping_category`,t,r)}async inventory_stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"inventory_stock_locations"},`shipments/${s}/inventory_stock_location`,t,r)}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`shipments/${s}/stock_location`,t,r)}async origin_address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`shipments/${s}/origin_address`,t,r)}async shipping_address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`shipments/${s}/shipping_address`,t,r)}async shipping_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_methods"},`shipments/${s}/shipping_method`,t,r)}async delivery_lead_time(e,t,r){let s=e.id||e;return this.resources.fetch({type:"delivery_lead_times"},`shipments/${s}/delivery_lead_time`,t,r)}async pickup(e,t,r){let s=e.id||e;return this.resources.fetch({type:"pickups"},`shipments/${s}/pickup`,t,r)}async stock_line_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_line_items"},`shipments/${s}/stock_line_items`,t,r)}async stock_transfers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_transfers"},`shipments/${s}/stock_transfers`,t,r)}async line_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_items"},`shipments/${s}/line_items`,t,r)}async available_shipping_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_methods"},`shipments/${s}/available_shipping_methods`,t,r)}async carrier_accounts(e,t,r){let s=e.id||e;return this.resources.fetch({type:"carrier_accounts"},`shipments/${s}/carrier_accounts`,t,r)}async parcels(e,t,r){let s=e.id||e;return this.resources.fetch({type:"parcels"},`shipments/${s}/parcels`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`shipments/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`shipments/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`shipments/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`shipments/${s}/versions`,t,r)}async _upcoming(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_upcoming:true},t,r)}async _cancel(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_cancel:true},t,r)}async _on_hold(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_on_hold:true},t,r)}async _picking(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_picking:true},t,r)}async _packing(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_packing:true},t,r)}async _ready_to_ship(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_ready_to_ship:true},t,r)}async _ship(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_ship:true},t,r)}async _deliver(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_deliver:true},t,r)}async _reserve_stock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_reserve_stock:true},t,r)}async _release_stock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_release_stock:true},t,r)}async _decrement_stock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_decrement_stock:true},t,r)}async _get_rates(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_get_rates:true},t,r)}async _purchase(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_purchase:true},t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:g.TYPE,_remove_tags:t},r,s)}isShipment(e){return e.type&&e.type===g.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return g.TYPE}};g.TYPE="shipments";var $u=g,Bu=$u;var ct=class ct extends n{async create(e,t,r){return this.resources.create({...e,type:ct.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ct.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ct.TYPE}:e,t);}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`shipping_categories/${s}/skus`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`shipping_categories/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`shipping_categories/${s}/versions`,t,r)}isShippingCategory(e){return e.type&&e.type===ct.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ct.TYPE}};ct.TYPE="shipping_categories";var qu=ct,Du=qu;var cr=class cr extends n{async shipping_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_methods"},`shipping_method_tiers/${s}/shipping_method`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`shipping_method_tiers/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`shipping_method_tiers/${s}/versions`,t,r)}isShippingMethodTier(e){return e.type&&e.type===cr.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return cr.TYPE}};cr.TYPE="shipping_method_tiers";var zu=cr,ju=zu;var F=class F extends n{async create(e,t,r){return this.resources.create({...e,type:F.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:F.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:F.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`shipping_methods/${s}/market`,t,r)}async shipping_zone(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_zones"},`shipping_methods/${s}/shipping_zone`,t,r)}async shipping_category(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_categories"},`shipping_methods/${s}/shipping_category`,t,r)}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`shipping_methods/${s}/stock_location`,t,r)}async delivery_lead_time_for_shipment(e,t,r){let s=e.id||e;return this.resources.fetch({type:"delivery_lead_times"},`shipping_methods/${s}/delivery_lead_time_for_shipment`,t,r)}async shipping_method_tiers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_method_tiers"},`shipping_methods/${s}/shipping_method_tiers`,t,r)}async shipping_weight_tiers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_weight_tiers"},`shipping_methods/${s}/shipping_weight_tiers`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`shipping_methods/${s}/attachments`,t,r)}async notifications(e,t,r){let s=e.id||e;return this.resources.fetch({type:"notifications"},`shipping_methods/${s}/notifications`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`shipping_methods/${s}/versions`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:F.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:F.TYPE,_enable:true},t,r)}async _reset_circuit(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:F.TYPE,_reset_circuit:true},t,r)}isShippingMethod(e){return e.type&&e.type===F.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return F.TYPE}};F.TYPE="shipping_methods";var Wu=F,Ku=Wu;var pt=class pt extends n{async create(e,t,r){return this.resources.create({...e,type:pt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:pt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:pt.TYPE}:e,t);}async shipping_method(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_methods"},`shipping_weight_tiers/${s}/shipping_method`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`shipping_weight_tiers/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`shipping_weight_tiers/${s}/versions`,t,r)}isShippingWeightTier(e){return e.type&&e.type===pt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return pt.TYPE}};pt.TYPE="shipping_weight_tiers";var Xu=pt,Nu=Xu;var lt=class lt extends n{async create(e,t,r){return this.resources.create({...e,type:lt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:lt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:lt.TYPE}:e,t);}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`shipping_zones/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`shipping_zones/${s}/versions`,t,r)}isShippingZone(e){return e.type&&e.type===lt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return lt.TYPE}};lt.TYPE="shipping_zones";var Zu=lt,Hu=Zu;var mt=class mt extends n{async create(e,t,r){return this.resources.create({...e,type:mt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:mt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:mt.TYPE}:e,t);}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`sku_list_items/${s}/sku_list`,t,r)}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`sku_list_items/${s}/sku`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`sku_list_items/${s}/versions`,t,r)}isSkuListItem(e){return e.type&&e.type===mt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return mt.TYPE}};mt.TYPE="sku_list_items";var Ju=mt,ec=Ju;var yt=class yt extends n{async create(e,t,r){return this.resources.create({...e,type:yt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:yt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:yt.TYPE}:e,t);}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`sku_list_promotion_rules/${s}/versions`,t,r)}async sku_list(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`sku_list_promotion_rules/${s}/sku_list`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`sku_list_promotion_rules/${s}/skus`,t,r)}isSkuListPromotionRule(e){return e.type&&e.type===yt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return yt.TYPE}};yt.TYPE="sku_list_promotion_rules";var tc=yt,rc=tc;var dt=class dt extends n{async create(e,t,r){return this.resources.create({...e,type:dt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:dt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:dt.TYPE}:e,t);}async customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`sku_lists/${s}/customer`,t,r)}async skus(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`sku_lists/${s}/skus`,t,r)}async sku_list_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_items"},`sku_lists/${s}/sku_list_items`,t,r)}async bundles(e,t,r){let s=e.id||e;return this.resources.fetch({type:"bundles"},`sku_lists/${s}/bundles`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`sku_lists/${s}/attachments`,t,r)}async links(e,t,r){let s=e.id||e;return this.resources.fetch({type:"links"},`sku_lists/${s}/links`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`sku_lists/${s}/versions`,t,r)}isSkuList(e){return e.type&&e.type===dt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return dt.TYPE}};dt.TYPE="sku_lists";var sc=dt,oc=sc;var J=class J extends n{async create(e,t,r){return this.resources.create({...e,type:J.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:J.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:J.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`sku_options/${s}/market`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`sku_options/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`sku_options/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`sku_options/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`sku_options/${s}/versions`,t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:J.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:J.TYPE,_remove_tags:t},r,s)}isSkuOption(e){return e.type&&e.type===J.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return J.TYPE}};J.TYPE="sku_options";var nc=J,ic=nc;var ee=class ee extends n{async create(e,t,r){return this.resources.create({...e,type:ee.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ee.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ee.TYPE}:e,t);}async shipping_category(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipping_categories"},`skus/${s}/shipping_category`,t,r)}async prices(e,t,r){let s=e.id||e;return this.resources.fetch({type:"prices"},`skus/${s}/prices`,t,r)}async stock_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_items"},`skus/${s}/stock_items`,t,r)}async stock_reservations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_reservations"},`skus/${s}/stock_reservations`,t,r)}async delivery_lead_times(e,t,r){let s=e.id||e;return this.resources.fetch({type:"delivery_lead_times"},`skus/${s}/delivery_lead_times`,t,r)}async sku_options(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_options"},`skus/${s}/sku_options`,t,r)}async sku_list_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_list_items"},`skus/${s}/sku_list_items`,t,r)}async sku_lists(e,t,r){let s=e.id||e;return this.resources.fetch({type:"sku_lists"},`skus/${s}/sku_lists`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`skus/${s}/attachments`,t,r)}async links(e,t,r){let s=e.id||e;return this.resources.fetch({type:"links"},`skus/${s}/links`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`skus/${s}/events`,t,r)}async tags(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tags"},`skus/${s}/tags`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`skus/${s}/versions`,t,r)}async jwt_customer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"customers"},`skus/${s}/jwt_customer`,t,r)}async jwt_markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`skus/${s}/jwt_markets`,t,r)}async jwt_stock_locations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`skus/${s}/jwt_stock_locations`,t,r)}async _add_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:ee.TYPE,_add_tags:t},r,s)}async _remove_tags(e,t,r,s){return this.resources.update({id:typeof e=="string"?e:e.id,type:ee.TYPE,_remove_tags:t},r,s)}isSku(e){return e.type&&e.type===ee.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ee.TYPE}};ee.TYPE="skus";var ac=ee,uc=ac;var Re=class Re extends n{async create(e,t,r){return this.resources.create({...e,type:Re.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Re.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Re.TYPE}:e,t);}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`stock_items/${s}/stock_location`,t,r)}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`stock_items/${s}/sku`,t,r)}async reserved_stock(e,t,r){let s=e.id||e;return this.resources.fetch({type:"reserved_stocks"},`stock_items/${s}/reserved_stock`,t,r)}async stock_reservations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_reservations"},`stock_items/${s}/stock_reservations`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`stock_items/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`stock_items/${s}/versions`,t,r)}async _validate(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:Re.TYPE,_validate:true},t,r)}isStockItem(e){return e.type&&e.type===Re.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Re.TYPE}};Re.TYPE="stock_items";var cc=Re,pc=cc;var $=class $ extends n{async create(e,t,r){return this.resources.create({...e,type:$.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:$.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:$.TYPE}:e,t);}async shipment(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipments"},`stock_line_items/${s}/shipment`,t,r)}async line_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_items"},`stock_line_items/${s}/line_item`,t,r)}async stock_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_items"},`stock_line_items/${s}/stock_item`,t,r)}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`stock_line_items/${s}/sku`,t,r)}async stock_reservation(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_reservations"},`stock_line_items/${s}/stock_reservation`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`stock_line_items/${s}/versions`,t,r)}async _reserve_stock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:$.TYPE,_reserve_stock:true},t,r)}async _release_stock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:$.TYPE,_release_stock:true},t,r)}async _decrement_stock(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:$.TYPE,_decrement_stock:true},t,r)}isStockLineItem(e){return e.type&&e.type===$.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return $.TYPE}};$.TYPE="stock_line_items";var lc=$,mc=lc;var Rt=class Rt extends n{async create(e,t,r){return this.resources.create({...e,type:Rt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Rt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Rt.TYPE}:e,t);}async address(e,t,r){let s=e.id||e;return this.resources.fetch({type:"addresses"},`stock_locations/${s}/address`,t,r)}async inventory_stock_locations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"inventory_stock_locations"},`stock_locations/${s}/inventory_stock_locations`,t,r)}async inventory_return_locations(e,t,r){let s=e.id||e;return this.resources.fetch({type:"inventory_return_locations"},`stock_locations/${s}/inventory_return_locations`,t,r)}async stock_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_items"},`stock_locations/${s}/stock_items`,t,r)}async stock_transfers(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_transfers"},`stock_locations/${s}/stock_transfers`,t,r)}async stores(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stores"},`stock_locations/${s}/stores`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`stock_locations/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`stock_locations/${s}/versions`,t,r)}isStockLocation(e){return e.type&&e.type===Rt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Rt.TYPE}};Rt.TYPE="stock_locations";var yc=Rt,dc=yc;var ge=class ge extends n{async create(e,t,r){return this.resources.create({...e,type:ge.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ge.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ge.TYPE}:e,t);}async line_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_items"},`stock_reservations/${s}/line_item`,t,r)}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`stock_reservations/${s}/order`,t,r)}async stock_line_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_line_items"},`stock_reservations/${s}/stock_line_item`,t,r)}async stock_transfer(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_transfers"},`stock_reservations/${s}/stock_transfer`,t,r)}async stock_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_items"},`stock_reservations/${s}/stock_item`,t,r)}async reserved_stock(e,t,r){let s=e.id||e;return this.resources.fetch({type:"reserved_stocks"},`stock_reservations/${s}/reserved_stock`,t,r)}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`stock_reservations/${s}/sku`,t,r)}async _pending(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:ge.TYPE,_pending:true},t,r)}isStockReservation(e){return e.type&&e.type===ge.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ge.TYPE}};ge.TYPE="stock_reservations";var Rc=ge,gc=Rc;var C=class C extends n{async create(e,t,r){return this.resources.create({...e,type:C.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:C.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:C.TYPE}:e,t);}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`stock_transfers/${s}/sku`,t,r)}async origin_stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`stock_transfers/${s}/origin_stock_location`,t,r)}async destination_stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`stock_transfers/${s}/destination_stock_location`,t,r)}async shipment(e,t,r){let s=e.id||e;return this.resources.fetch({type:"shipments"},`stock_transfers/${s}/shipment`,t,r)}async line_item(e,t,r){let s=e.id||e;return this.resources.fetch({type:"line_items"},`stock_transfers/${s}/line_item`,t,r)}async stock_reservation(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_reservations"},`stock_transfers/${s}/stock_reservation`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`stock_transfers/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`stock_transfers/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`stock_transfers/${s}/versions`,t,r)}async _upcoming(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:C.TYPE,_upcoming:true},t,r)}async _on_hold(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:C.TYPE,_on_hold:true},t,r)}async _picking(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:C.TYPE,_picking:true},t,r)}async _in_transit(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:C.TYPE,_in_transit:true},t,r)}async _complete(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:C.TYPE,_complete:true},t,r)}async _cancel(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:C.TYPE,_cancel:true},t,r)}isStockTransfer(e){return e.type&&e.type===C.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return C.TYPE}};C.TYPE="stock_transfers";var _c=C,Pc=_c;var gt=class gt extends n{async create(e,t,r){return this.resources.create({...e,type:gt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:gt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:gt.TYPE}:e,t);}async market(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`stores/${s}/market`,t,r)}async merchant(e,t,r){let s=e.id||e;return this.resources.fetch({type:"merchants"},`stores/${s}/merchant`,t,r)}async stock_location(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stock_locations"},`stores/${s}/stock_location`,t,r)}async orders(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`stores/${s}/orders`,t,r)}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`stores/${s}/payment_methods`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`stores/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`stores/${s}/versions`,t,r)}isStore(e){return e.type&&e.type===gt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return gt.TYPE}};gt.TYPE="stores";var hc=gt,fc=hc;var _t=class _t extends n{async create(e,t,r){return this.resources.create({...e,type:_t.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:_t.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:_t.TYPE}:e,t);}async payment_methods(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_methods"},`stripe_gateways/${s}/payment_methods`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`stripe_gateways/${s}/versions`,t,r)}async stripe_payments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"stripe_payments"},`stripe_gateways/${s}/stripe_payments`,t,r)}isStripeGateway(e){return e.type&&e.type===_t.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return _t.TYPE}};_t.TYPE="stripe_gateways";var kc=_t,Cc=kc;var te=class te extends n{async create(e,t,r){return this.resources.create({...e,type:te.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:te.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:te.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`stripe_payments/${s}/order`,t,r)}async payment_gateway(e,t,r){let s=e.id||e;return this.resources.fetch({type:"payment_gateways"},`stripe_payments/${s}/payment_gateway`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`stripe_payments/${s}/versions`,t,r)}async _update(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:te.TYPE,_update:true},t,r)}async _refresh(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:te.TYPE,_refresh:true},t,r)}isStripePayment(e){return e.type&&e.type===te.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return te.TYPE}};te.TYPE="stripe_payments";var Tc=te,Sc=Tc;var Pt=class Pt extends n{async create(e,t,r){return this.resources.create({...e,type:Pt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Pt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Pt.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`stripe_tax_accounts/${s}/markets`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`stripe_tax_accounts/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`stripe_tax_accounts/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`stripe_tax_accounts/${s}/versions`,t,r)}async tax_categories(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tax_categories"},`stripe_tax_accounts/${s}/tax_categories`,t,r)}isStripeTaxAccount(e){return e.type&&e.type===Pt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Pt.TYPE}};Pt.TYPE="stripe_tax_accounts";var vc=Pt,xc=vc;var ht=class ht extends n{async create(e,t,r){return this.resources.create({...e,type:ht.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ht.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ht.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`subscription_models/${s}/markets`,t,r)}async order_subscriptions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"order_subscriptions"},`subscription_models/${s}/order_subscriptions`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`subscription_models/${s}/attachments`,t,r)}isSubscriptionModel(e){return e.type&&e.type===ht.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ht.TYPE}};ht.TYPE="subscription_models";var Lc=ht,bc=Lc;var ft=class ft extends n{async create(e,t,r){return this.resources.create({...e,type:ft.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:ft.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:ft.TYPE}:e,t);}isTag(e){return e.type&&e.type===ft.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return ft.TYPE}};ft.TYPE="tags";var Ec=ft,wc=Ec;var kt=class kt extends n{async create(e,t,r){return this.resources.create({...e,type:kt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:kt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:kt.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`talon_one_accounts/${s}/markets`,t,r)}async discount_engine_items(e,t,r){let s=e.id||e;return this.resources.fetch({type:"discount_engine_items"},`talon_one_accounts/${s}/discount_engine_items`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`talon_one_accounts/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`talon_one_accounts/${s}/versions`,t,r)}isTalonOneAccount(e){return e.type&&e.type===kt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return kt.TYPE}};kt.TYPE="talon_one_accounts";var Ac=kt,Oc=Ac;var pr=class pr extends n{async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`tax_calculators/${s}/markets`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`tax_calculators/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`tax_calculators/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`tax_calculators/${s}/versions`,t,r)}isTaxCalculator(e){return e.type&&e.type===pr.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return pr.TYPE}};pr.TYPE="tax_calculators";var Ic=pr,Mc=Ic;var Ct=class Ct extends n{async create(e,t,r){return this.resources.create({...e,type:Ct.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Ct.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Ct.TYPE}:e,t);}async sku(e,t,r){let s=e.id||e;return this.resources.fetch({type:"skus"},`tax_categories/${s}/sku`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`tax_categories/${s}/attachments`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`tax_categories/${s}/versions`,t,r)}isTaxCategory(e){return e.type&&e.type===Ct.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Ct.TYPE}};Ct.TYPE="tax_categories";var Qc=Ct,Gc=Qc;var Tt=class Tt extends n{async create(e,t,r){return this.resources.create({...e,type:Tt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:Tt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:Tt.TYPE}:e,t);}async manual_tax_calculator(e,t,r){let s=e.id||e;return this.resources.fetch({type:"manual_tax_calculators"},`tax_rules/${s}/manual_tax_calculator`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`tax_rules/${s}/versions`,t,r)}isTaxRule(e){return e.type&&e.type===Tt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return Tt.TYPE}};Tt.TYPE="tax_rules";var Yc=Tt,Uc=Yc;var St=class St extends n{async create(e,t,r){return this.resources.create({...e,type:St.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:St.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:St.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`taxjar_accounts/${s}/markets`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`taxjar_accounts/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`taxjar_accounts/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`taxjar_accounts/${s}/versions`,t,r)}async tax_categories(e,t,r){let s=e.id||e;return this.resources.fetch({type:"tax_categories"},`taxjar_accounts/${s}/tax_categories`,t,r)}isTaxjarAccount(e){return e.type&&e.type===St.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return St.TYPE}};St.TYPE="taxjar_accounts";var Vc=St,Fc=Vc;var lr=class lr extends n{async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`transactions/${s}/order`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`transactions/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`transactions/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`transactions/${s}/versions`,t,r)}isTransaction(e){return e.type&&e.type===lr.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return lr.TYPE}};lr.TYPE="transactions";var $c=lr,Bc=$c;var mr=class mr extends n{isVersion(e){return e.type&&e.type===mr.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return mr.TYPE}};mr.TYPE="versions";var qc=mr,Dc=qc;var _e=class _e extends n{async create(e,t,r){return this.resources.create({...e,type:_e.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:_e.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:_e.TYPE}:e,t);}async markets(e,t,r){let s=e.id||e;return this.resources.fetch({type:"markets"},`vertex_accounts/${s}/markets`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`vertex_accounts/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`vertex_accounts/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`vertex_accounts/${s}/versions`,t,r)}async _refresh_token(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:_e.TYPE,_refresh_token:true},t,r)}isVertexAccount(e){return e.type&&e.type===_e.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return _e.TYPE}};_e.TYPE="vertex_accounts";var zc=_e,jc=zc;var wt=class wt extends n{async update(e,t,r){return this.resources.update({...e,type:wt.TYPE},t,r)}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`voids/${s}/order`,t,r)}async attachments(e,t,r){let s=e.id||e;return this.resources.fetch({type:"attachments"},`voids/${s}/attachments`,t,r)}async events(e,t,r){let s=e.id||e;return this.resources.fetch({type:"events"},`voids/${s}/events`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`voids/${s}/versions`,t,r)}async reference_authorization(e,t,r){let s=e.id||e;return this.resources.fetch({type:"authorizations"},`voids/${s}/reference_authorization`,t,r)}async _forward(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:wt.TYPE,_forward:true},t,r)}isVoid(e){return e.type&&e.type===wt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return wt.TYPE}};wt.TYPE="voids";var Wc=wt,Kc=Wc;var B=class B extends n{async create(e,t,r){return this.resources.create({...e,type:B.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:B.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:B.TYPE}:e,t);}async last_event_callbacks(e,t,r){let s=e.id||e;return this.resources.fetch({type:"event_callbacks"},`webhooks/${s}/last_event_callbacks`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`webhooks/${s}/versions`,t,r)}async _disable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:B.TYPE,_disable:true},t,r)}async _enable(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:B.TYPE,_enable:true},t,r)}async _reset_circuit(e,t,r){return this.resources.update({id:typeof e=="string"?e:e.id,type:B.TYPE,_reset_circuit:true},t,r)}isWebhook(e){return e.type&&e.type===B.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return B.TYPE}};B.TYPE="webhooks";var Xc=B,Nc=Xc;var vt=class vt extends n{async create(e,t,r){return this.resources.create({...e,type:vt.TYPE},t,r)}async update(e,t,r){return this.resources.update({...e,type:vt.TYPE},t,r)}async delete(e,t){await this.resources.delete(typeof e=="string"?{id:e,type:vt.TYPE}:e,t);}async order(e,t,r){let s=e.id||e;return this.resources.fetch({type:"orders"},`wire_transfers/${s}/order`,t,r)}async versions(e,t,r){let s=e.id||e;return this.resources.fetch({type:"versions"},`wire_transfers/${s}/versions`,t,r)}isWireTransfer(e){return e.type&&e.type===vt.TYPE}relationship(e){return super.relationshipOneToOne(e)}relationshipToMany(...e){return super.relationshipOneToMany(...e)}type(){return vt.TYPE}};vt.TYPE="wire_transfers";var Zc=vt,Hc=Zc;var It=["addresses","adjustments","adyen_gateways","adyen_payments","applications","attachments","authorizations","avalara_accounts","axerve_gateways","axerve_payments","bing_geocoders","braintree_gateways","braintree_payments","bundles","buy_x_pay_y_promotions","captures","carrier_accounts","checkout_com_gateways","checkout_com_payments","cleanups","coupon_codes_promotion_rules","coupon_recipients","coupons","custom_promotion_rules","customer_addresses","customer_groups","customer_password_resets","customer_payment_sources","customer_subscriptions","customers","delivery_lead_times","discount_engine_items","discount_engines","easypost_pickups","event_callbacks","events","exports","external_gateways","external_payments","external_promotions","external_tax_calculators","fixed_amount_promotions","fixed_price_promotions","flex_promotions","free_gift_promotions","free_shipping_promotions","geocoders","gift_card_recipients","gift_cards","google_geocoders","imports","in_stock_subscriptions","inventory_models","inventory_return_locations","inventory_stock_locations","klarna_gateways","klarna_payments","line_item_options","line_items","links","manual_gateways","manual_tax_calculators","markets","merchants","notifications","order_amount_promotion_rules","order_copies","order_factories","order_subscription_items","order_subscriptions","orders","organizations","packages","parcel_line_items","parcels","payment_gateways","payment_methods","payment_options","paypal_gateways","paypal_payments","percentage_discount_promotions","pickups","price_frequency_tiers","price_list_schedulers","price_lists","price_tiers","price_volume_tiers","prices","promotion_rules","promotions","recurring_order_copies","refunds","reserved_stocks","resource_errors","return_line_items","returns","satispay_gateways","satispay_payments","shipments","shipping_categories","shipping_method_tiers","shipping_methods","shipping_weight_tiers","shipping_zones","sku_list_items","sku_list_promotion_rules","sku_lists","sku_options","skus","stock_items","stock_line_items","stock_locations","stock_reservations","stock_transfers","stores","stripe_gateways","stripe_payments","stripe_tax_accounts","subscription_models","tags","talon_one_accounts","tax_calculators","tax_categories","tax_rules","taxjar_accounts","transactions","versions","vertex_accounts","voids","webhooks","wire_transfers"],jo=["applications","organizations"];var Qt={resources:i=>i?[...It].sort():It,singletons:i=>i?[...jo].sort():jo,isSingleton:i=>jo.includes(i),isSdkError:i=>P.isSdkError(i),isApiError:i=>Pe.isApiError(i),init:i=>ep(i),isTokenExpired:i=>Fo(i),get schemaVersion(){return Jc}};var dp=x("commercelayer"),Jc="7.8.9";var l,Gt,yr,dr,Rr,gr,_r,Pr,hr,fr,kr,Cr,Tr,Sr,vr,xr,Lr,br,Er,wr,Ar,Or,Ir,Mr,Qr,Gr,Yr,Ur,Vr,Fr,$r,Br,qr,Dr,zr,jr,Wr,Kr,Xr,Nr,Zr,Hr,Jr,es,ts,rs,ss,os,ns,is,as,us,cs,ps,ls,ms,ys,ds,Rs,gs,_s,Ps,hs,fs,ks,Cs,Ts,Ss,vs,xs,Ls,bs,Es,ws,As,Os,Is,Ms,Qs,Gs,Ys,Us,Vs,Fs,$s,Bs,qs,Ds,zs,js,Ws,Ks,Xs,Ns,Zs,Hs,Js,eo,to,ro,so,oo,no,io,ao,uo,co,po,lo,mo,yo,Ro,go,_o,Po,ho,fo,ko,Co,To,So,vo,xo,Lo,bo,Eo,wo,Ao,Oo,Io,Mo,Qo,Go,tp=class{constructor(e){this.openApiSchemaVersion=Jc;u(this,l);u(this,Gt);u(this,yr);u(this,dr);u(this,Rr);u(this,gr);u(this,_r);u(this,Pr);u(this,hr);u(this,fr);u(this,kr);u(this,Cr);u(this,Tr);u(this,Sr);u(this,vr);u(this,xr);u(this,Lr);u(this,br);u(this,Er);u(this,wr);u(this,Ar);u(this,Or);u(this,Ir);u(this,Mr);u(this,Qr);u(this,Gr);u(this,Yr);u(this,Ur);u(this,Vr);u(this,Fr);u(this,$r);u(this,Br);u(this,qr);u(this,Dr);u(this,zr);u(this,jr);u(this,Wr);u(this,Kr);u(this,Xr);u(this,Nr);u(this,Zr);u(this,Hr);u(this,Jr);u(this,es);u(this,ts);u(this,rs);u(this,ss);u(this,os);u(this,ns);u(this,is);u(this,as);u(this,us);u(this,cs);u(this,ps);u(this,ls);u(this,ms);u(this,ys);u(this,ds);u(this,Rs);u(this,gs);u(this,_s);u(this,Ps);u(this,hs);u(this,fs);u(this,ks);u(this,Cs);u(this,Ts);u(this,Ss);u(this,vs);u(this,xs);u(this,Ls);u(this,bs);u(this,Es);u(this,ws);u(this,As);u(this,Os);u(this,Is);u(this,Ms);u(this,Qs);u(this,Gs);u(this,Ys);u(this,Us);u(this,Vs);u(this,Fs);u(this,$s);u(this,Bs);u(this,qs);u(this,Ds);u(this,zs);u(this,js);u(this,Ws);u(this,Ks);u(this,Xs);u(this,Ns);u(this,Zs);u(this,Hs);u(this,Js);u(this,eo);u(this,to);u(this,ro);u(this,so);u(this,oo);u(this,no);u(this,io);u(this,ao);u(this,uo);u(this,co);u(this,po);u(this,lo);u(this,mo);u(this,yo);u(this,Ro);u(this,go);u(this,_o);u(this,Po);u(this,ho);u(this,fo);u(this,ko);u(this,Co);u(this,To);u(this,So);u(this,vo);u(this,xo);u(this,Lo);u(this,bo);u(this,Eo);u(this,wo);u(this,Ao);u(this,Oo);u(this,Io);u(this,Mo);u(this,Qo);u(this,Go);if(dp("new commercelayer instance %O",e),(!e.organization||!e.domain)&&e.accessToken){let t=Zo(e.accessToken);!e.organization&&t?.organization?.slug&&(e.organization=t.organization.slug),!e.domain&&t?.iss&&(e.domain=String(t.iss).replace("https://auth.",""));}a(this,l,new yp(e)),a(this,Gt,e.organization??"");}get addresses(){return o(this,yr)||a(this,yr,new un(o(this,l)))}get adjustments(){return o(this,dr)||a(this,dr,new pn(o(this,l)))}get adyen_gateways(){return o(this,Rr)||a(this,Rr,new mn(o(this,l)))}get adyen_payments(){return o(this,gr)||a(this,gr,new dn(o(this,l)))}get application(){return o(this,_r)||a(this,_r,new gn(o(this,l)))}get attachments(){return o(this,Pr)||a(this,Pr,new Pn(o(this,l)))}get authorizations(){return o(this,hr)||a(this,hr,new fn(o(this,l)))}get avalara_accounts(){return o(this,fr)||a(this,fr,new Cn(o(this,l)))}get axerve_gateways(){return o(this,kr)||a(this,kr,new Sn(o(this,l)))}get axerve_payments(){return o(this,Cr)||a(this,Cr,new xn(o(this,l)))}get bing_geocoders(){return o(this,Tr)||a(this,Tr,new bn(o(this,l)))}get braintree_gateways(){return o(this,Sr)||a(this,Sr,new wn(o(this,l)))}get braintree_payments(){return o(this,vr)||a(this,vr,new On(o(this,l)))}get bundles(){return o(this,xr)||a(this,xr,new Mn(o(this,l)))}get buy_x_pay_y_promotions(){return o(this,Lr)||a(this,Lr,new Gn(o(this,l)))}get captures(){return o(this,br)||a(this,br,new Un(o(this,l)))}get carrier_accounts(){return o(this,Er)||a(this,Er,new Fn(o(this,l)))}get checkout_com_gateways(){return o(this,wr)||a(this,wr,new Bn(o(this,l)))}get checkout_com_payments(){return o(this,Ar)||a(this,Ar,new Dn(o(this,l)))}get cleanups(){return o(this,Or)||a(this,Or,new jn(o(this,l)))}get coupon_codes_promotion_rules(){return o(this,Ir)||a(this,Ir,new Kn(o(this,l)))}get coupon_recipients(){return o(this,Mr)||a(this,Mr,new Nn(o(this,l)))}get coupons(){return o(this,Qr)||a(this,Qr,new Hn(o(this,l)))}get custom_promotion_rules(){return o(this,Gr)||a(this,Gr,new ei(o(this,l)))}get customer_addresses(){return o(this,Yr)||a(this,Yr,new ri(o(this,l)))}get customer_groups(){return o(this,Ur)||a(this,Ur,new oi(o(this,l)))}get customer_password_resets(){return o(this,Vr)||a(this,Vr,new ii(o(this,l)))}get customer_payment_sources(){return o(this,Fr)||a(this,Fr,new ui(o(this,l)))}get customer_subscriptions(){return o(this,$r)||a(this,$r,new pi(o(this,l)))}get customers(){return o(this,Br)||a(this,Br,new mi(o(this,l)))}get delivery_lead_times(){return o(this,qr)||a(this,qr,new di(o(this,l)))}get discount_engine_items(){return o(this,Dr)||a(this,Dr,new gi(o(this,l)))}get discount_engines(){return o(this,zr)||a(this,zr,new Pi(o(this,l)))}get easypost_pickups(){return o(this,jr)||a(this,jr,new fi(o(this,l)))}get event_callbacks(){return o(this,Wr)||a(this,Wr,new Ci(o(this,l)))}get events(){return o(this,Kr)||a(this,Kr,new Si(o(this,l)))}get exports(){return o(this,Xr)||a(this,Xr,new xi(o(this,l)))}get external_gateways(){return o(this,Nr)||a(this,Nr,new bi(o(this,l)))}get external_payments(){return o(this,Zr)||a(this,Zr,new wi(o(this,l)))}get external_promotions(){return o(this,Hr)||a(this,Hr,new Oi(o(this,l)))}get external_tax_calculators(){return o(this,Jr)||a(this,Jr,new Mi(o(this,l)))}get fixed_amount_promotions(){return o(this,es)||a(this,es,new Gi(o(this,l)))}get fixed_price_promotions(){return o(this,ts)||a(this,ts,new Ui(o(this,l)))}get flex_promotions(){return o(this,rs)||a(this,rs,new Fi(o(this,l)))}get free_gift_promotions(){return o(this,ss)||a(this,ss,new Bi(o(this,l)))}get free_shipping_promotions(){return o(this,os)||a(this,os,new Di(o(this,l)))}get geocoders(){return o(this,ns)||a(this,ns,new ji(o(this,l)))}get gift_card_recipients(){return o(this,is)||a(this,is,new Ki(o(this,l)))}get gift_cards(){return o(this,as)||a(this,as,new Ni(o(this,l)))}get google_geocoders(){return o(this,us)||a(this,us,new Hi(o(this,l)))}get imports(){return o(this,cs)||a(this,cs,new ea(o(this,l)))}get in_stock_subscriptions(){return o(this,ps)||a(this,ps,new ra(o(this,l)))}get inventory_models(){return o(this,ls)||a(this,ls,new oa(o(this,l)))}get inventory_return_locations(){return o(this,ms)||a(this,ms,new ia(o(this,l)))}get inventory_stock_locations(){return o(this,ys)||a(this,ys,new ua(o(this,l)))}get klarna_gateways(){return o(this,ds)||a(this,ds,new pa(o(this,l)))}get klarna_payments(){return o(this,Rs)||a(this,Rs,new ma(o(this,l)))}get line_item_options(){return o(this,gs)||a(this,gs,new da(o(this,l)))}get line_items(){return o(this,_s)||a(this,_s,new ga(o(this,l)))}get links(){return o(this,Ps)||a(this,Ps,new Pa(o(this,l)))}get manual_gateways(){return o(this,hs)||a(this,hs,new fa(o(this,l)))}get manual_tax_calculators(){return o(this,fs)||a(this,fs,new Ca(o(this,l)))}get markets(){return o(this,ks)||a(this,ks,new Sa(o(this,l)))}get merchants(){return o(this,Cs)||a(this,Cs,new xa(o(this,l)))}get notifications(){return o(this,Ts)||a(this,Ts,new ba(o(this,l)))}get order_amount_promotion_rules(){return o(this,Ss)||a(this,Ss,new wa(o(this,l)))}get order_copies(){return o(this,vs)||a(this,vs,new Oa(o(this,l)))}get order_factories(){return o(this,xs)||a(this,xs,new Ma(o(this,l)))}get order_subscription_items(){return o(this,Ls)||a(this,Ls,new Ga(o(this,l)))}get order_subscriptions(){return o(this,bs)||a(this,bs,new Ua(o(this,l)))}get orders(){return o(this,Es)||a(this,Es,new Fa(o(this,l)))}get organization(){return o(this,ws)||a(this,ws,new Ba(o(this,l)))}get packages(){return o(this,As)||a(this,As,new Da(o(this,l)))}get parcel_line_items(){return o(this,Os)||a(this,Os,new ja(o(this,l)))}get parcels(){return o(this,Is)||a(this,Is,new Ka(o(this,l)))}get payment_gateways(){return o(this,Ms)||a(this,Ms,new Na(o(this,l)))}get payment_methods(){return o(this,Qs)||a(this,Qs,new Ha(o(this,l)))}get payment_options(){return o(this,Gs)||a(this,Gs,new eu(o(this,l)))}get paypal_gateways(){return o(this,Ys)||a(this,Ys,new ru(o(this,l)))}get paypal_payments(){return o(this,Us)||a(this,Us,new ou(o(this,l)))}get percentage_discount_promotions(){return o(this,Vs)||a(this,Vs,new iu(o(this,l)))}get pickups(){return o(this,Fs)||a(this,Fs,new uu(o(this,l)))}get price_frequency_tiers(){return o(this,$s)||a(this,$s,new pu(o(this,l)))}get price_list_schedulers(){return o(this,Bs)||a(this,Bs,new mu(o(this,l)))}get price_lists(){return o(this,qs)||a(this,qs,new du(o(this,l)))}get price_tiers(){return o(this,Ds)||a(this,Ds,new gu(o(this,l)))}get price_volume_tiers(){return o(this,zs)||a(this,zs,new Pu(o(this,l)))}get prices(){return o(this,js)||a(this,js,new fu(o(this,l)))}get promotion_rules(){return o(this,Ws)||a(this,Ws,new Cu(o(this,l)))}get promotions(){return o(this,Ks)||a(this,Ks,new Su(o(this,l)))}get recurring_order_copies(){return o(this,Xs)||a(this,Xs,new xu(o(this,l)))}get refunds(){return o(this,Ns)||a(this,Ns,new bu(o(this,l)))}get reserved_stocks(){return o(this,Zs)||a(this,Zs,new wu(o(this,l)))}get resource_errors(){return o(this,Hs)||a(this,Hs,new Ou(o(this,l)))}get return_line_items(){return o(this,Js)||a(this,Js,new Mu(o(this,l)))}get returns(){return o(this,eo)||a(this,eo,new Gu(o(this,l)))}get satispay_gateways(){return o(this,to)||a(this,to,new Uu(o(this,l)))}get satispay_payments(){return o(this,ro)||a(this,ro,new Fu(o(this,l)))}get shipments(){return o(this,so)||a(this,so,new Bu(o(this,l)))}get shipping_categories(){return o(this,oo)||a(this,oo,new Du(o(this,l)))}get shipping_method_tiers(){return o(this,no)||a(this,no,new ju(o(this,l)))}get shipping_methods(){return o(this,io)||a(this,io,new Ku(o(this,l)))}get shipping_weight_tiers(){return o(this,ao)||a(this,ao,new Nu(o(this,l)))}get shipping_zones(){return o(this,uo)||a(this,uo,new Hu(o(this,l)))}get sku_list_items(){return o(this,co)||a(this,co,new ec(o(this,l)))}get sku_list_promotion_rules(){return o(this,po)||a(this,po,new rc(o(this,l)))}get sku_lists(){return o(this,lo)||a(this,lo,new oc(o(this,l)))}get sku_options(){return o(this,mo)||a(this,mo,new ic(o(this,l)))}get skus(){return o(this,yo)||a(this,yo,new uc(o(this,l)))}get stock_items(){return o(this,Ro)||a(this,Ro,new pc(o(this,l)))}get stock_line_items(){return o(this,go)||a(this,go,new mc(o(this,l)))}get stock_locations(){return o(this,_o)||a(this,_o,new dc(o(this,l)))}get stock_reservations(){return o(this,Po)||a(this,Po,new gc(o(this,l)))}get stock_transfers(){return o(this,ho)||a(this,ho,new Pc(o(this,l)))}get stores(){return o(this,fo)||a(this,fo,new fc(o(this,l)))}get stripe_gateways(){return o(this,ko)||a(this,ko,new Cc(o(this,l)))}get stripe_payments(){return o(this,Co)||a(this,Co,new Sc(o(this,l)))}get stripe_tax_accounts(){return o(this,To)||a(this,To,new xc(o(this,l)))}get subscription_models(){return o(this,So)||a(this,So,new bc(o(this,l)))}get tags(){return o(this,vo)||a(this,vo,new wc(o(this,l)))}get talon_one_accounts(){return o(this,xo)||a(this,xo,new Oc(o(this,l)))}get tax_calculators(){return o(this,Lo)||a(this,Lo,new Mc(o(this,l)))}get tax_categories(){return o(this,bo)||a(this,bo,new Gc(o(this,l)))}get tax_rules(){return o(this,Eo)||a(this,Eo,new Uc(o(this,l)))}get taxjar_accounts(){return o(this,wo)||a(this,wo,new Fc(o(this,l)))}get transactions(){return o(this,Ao)||a(this,Ao,new Bc(o(this,l)))}get versions(){return o(this,Oo)||a(this,Oo,new Dc(o(this,l)))}get vertex_accounts(){return o(this,Io)||a(this,Io,new jc(o(this,l)))}get voids(){return o(this,Mo)||a(this,Mo,new Kc(o(this,l)))}get webhooks(){return o(this,Qo)||a(this,Qo,new Nc(o(this,l)))}get wire_transfers(){return o(this,Go)||a(this,Go,new Hc(o(this,l)))}get currentOrganization(){return o(this,Gt)}get currentAccessToken(){return o(this,l)?.client?.currentAccessToken}get interceptors(){return o(this,l).client.interceptors}localConfig(e){e.organization&&a(this,Gt,e.organization);}config(e){return dp("config %o",e),this.localConfig(e),e.organization||(e.organization=this.currentOrganization),o(this,l).config(e),this}resources(){return Qt.resources()}singletons(){return Qt.singletons()}isSingleton(e){return Qt.isSingleton(e)}isApiError(e){return Qt.isApiError(e)}addRequestInterceptor(e,t){return this.interceptors.request={onSuccess:e,onFailure:t},1}addResponseInterceptor(e,t){return this.interceptors.response={onSuccess:e,onFailure:t},1}removeInterceptor(e,t=1){this.interceptors[e]=void 0;}removeInterceptors(){this.removeInterceptor("request"),this.removeInterceptor("response"),this.removeRawResponseReader();}addRawResponseReader(e){let t={id:0,rawResponse:void 0,headers:void 0,ok:true};async function r(s){if(t.rawResponse=await s?.clone().json().catch(()=>{}),t.ok=s.ok,e?.headers){let m={};s.headers.forEach((R,d)=>{m[d]=R;}),t.headers=m;}return s}return this.interceptors.rawReader={onSuccess:r,onFailure:r},t.id=1,t}removeRawResponseReader(){this.interceptors.rawReader=void 0;}};l=new WeakMap,Gt=new WeakMap,yr=new WeakMap,dr=new WeakMap,Rr=new WeakMap,gr=new WeakMap,_r=new WeakMap,Pr=new WeakMap,hr=new WeakMap,fr=new WeakMap,kr=new WeakMap,Cr=new WeakMap,Tr=new WeakMap,Sr=new WeakMap,vr=new WeakMap,xr=new WeakMap,Lr=new WeakMap,br=new WeakMap,Er=new WeakMap,wr=new WeakMap,Ar=new WeakMap,Or=new WeakMap,Ir=new WeakMap,Mr=new WeakMap,Qr=new WeakMap,Gr=new WeakMap,Yr=new WeakMap,Ur=new WeakMap,Vr=new WeakMap,Fr=new WeakMap,$r=new WeakMap,Br=new WeakMap,qr=new WeakMap,Dr=new WeakMap,zr=new WeakMap,jr=new WeakMap,Wr=new WeakMap,Kr=new WeakMap,Xr=new WeakMap,Nr=new WeakMap,Zr=new WeakMap,Hr=new WeakMap,Jr=new WeakMap,es=new WeakMap,ts=new WeakMap,rs=new WeakMap,ss=new WeakMap,os=new WeakMap,ns=new WeakMap,is=new WeakMap,as=new WeakMap,us=new WeakMap,cs=new WeakMap,ps=new WeakMap,ls=new WeakMap,ms=new WeakMap,ys=new WeakMap,ds=new WeakMap,Rs=new WeakMap,gs=new WeakMap,_s=new WeakMap,Ps=new WeakMap,hs=new WeakMap,fs=new WeakMap,ks=new WeakMap,Cs=new WeakMap,Ts=new WeakMap,Ss=new WeakMap,vs=new WeakMap,xs=new WeakMap,Ls=new WeakMap,bs=new WeakMap,Es=new WeakMap,ws=new WeakMap,As=new WeakMap,Os=new WeakMap,Is=new WeakMap,Ms=new WeakMap,Qs=new WeakMap,Gs=new WeakMap,Ys=new WeakMap,Us=new WeakMap,Vs=new WeakMap,Fs=new WeakMap,$s=new WeakMap,Bs=new WeakMap,qs=new WeakMap,Ds=new WeakMap,zs=new WeakMap,js=new WeakMap,Ws=new WeakMap,Ks=new WeakMap,Xs=new WeakMap,Ns=new WeakMap,Zs=new WeakMap,Hs=new WeakMap,Js=new WeakMap,eo=new WeakMap,to=new WeakMap,ro=new WeakMap,so=new WeakMap,oo=new WeakMap,no=new WeakMap,io=new WeakMap,ao=new WeakMap,uo=new WeakMap,co=new WeakMap,po=new WeakMap,lo=new WeakMap,mo=new WeakMap,yo=new WeakMap,Ro=new WeakMap,go=new WeakMap,_o=new WeakMap,Po=new WeakMap,ho=new WeakMap,fo=new WeakMap,ko=new WeakMap,Co=new WeakMap,To=new WeakMap,So=new WeakMap,vo=new WeakMap,xo=new WeakMap,Lo=new WeakMap,bo=new WeakMap,Eo=new WeakMap,wo=new WeakMap,Ao=new WeakMap,Oo=new WeakMap,Io=new WeakMap,Mo=new WeakMap,Qo=new WeakMap,Go=new WeakMap;var Rp=i=>new tp(i),ep=Rp;

/*! js-cookie v3.0.5 | MIT */
/* eslint-disable no-var */
function assign (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];
    for (var key in source) {
      target[key] = source[key];
    }
  }
  return target
}
/* eslint-enable no-var */

/* eslint-disable no-var */
var defaultConverter = {
  read: function (value) {
    if (value[0] === '"') {
      value = value.slice(1, -1);
    }
    return value.replace(/(%[\dA-F]{2})+/gi, decodeURIComponent)
  },
  write: function (value) {
    return encodeURIComponent(value).replace(
      /%(2[346BF]|3[AC-F]|40|5[BDE]|60|7[BCD])/g,
      decodeURIComponent
    )
  }
};
/* eslint-enable no-var */

/* eslint-disable no-var */

function init (converter, defaultAttributes) {
  function set (name, value, attributes) {
    if (typeof document === 'undefined') {
      return
    }

    attributes = assign({}, defaultAttributes, attributes);

    if (typeof attributes.expires === 'number') {
      attributes.expires = new Date(Date.now() + attributes.expires * 864e5);
    }
    if (attributes.expires) {
      attributes.expires = attributes.expires.toUTCString();
    }

    name = encodeURIComponent(name)
      .replace(/%(2[346B]|5E|60|7C)/g, decodeURIComponent)
      .replace(/[()]/g, escape);

    var stringifiedAttributes = '';
    for (var attributeName in attributes) {
      if (!attributes[attributeName]) {
        continue
      }

      stringifiedAttributes += '; ' + attributeName;

      if (attributes[attributeName] === true) {
        continue
      }

      // Considers RFC 6265 section 5.2:
      // ...
      // 3.  If the remaining unparsed-attributes contains a %x3B (";")
      //     character:
      // Consume the characters of the unparsed-attributes up to,
      // not including, the first %x3B (";") character.
      // ...
      stringifiedAttributes += '=' + attributes[attributeName].split(';')[0];
    }

    return (document.cookie =
      name + '=' + converter.write(value, name) + stringifiedAttributes)
  }

  function get (name) {
    if (typeof document === 'undefined' || (arguments.length && !name)) {
      return
    }

    // To prevent the for loop in the first place assign an empty array
    // in case there are no cookies at all.
    var cookies = document.cookie ? document.cookie.split('; ') : [];
    var jar = {};
    for (var i = 0; i < cookies.length; i++) {
      var parts = cookies[i].split('=');
      var value = parts.slice(1).join('=');

      try {
        var found = decodeURIComponent(parts[0]);
        jar[found] = converter.read(value, found);

        if (name === found) {
          break
        }
      } catch (e) {}
    }

    return name ? jar[name] : jar
  }

  return Object.create(
    {
      set,
      get,
      remove: function (name, attributes) {
        set(
          name,
          '',
          assign({}, attributes, {
            expires: -1
          })
        );
      },
      withAttributes: function (attributes) {
        return init(this.converter, assign({}, this.attributes, attributes))
      },
      withConverter: function (converter) {
        return init(assign({}, this.converter, converter), this.attributes)
      }
    },
    {
      attributes: { value: Object.freeze(defaultAttributes) },
      converter: { value: Object.freeze(converter) }
    }
  )
}

var api = init(defaultConverter, { path: '/' });

const prefix = "commercelayer_";
function getKeyForCart(config) {
    const scope = (config.scope ?? "undefined").replace(" ", "-");
    const suffix = config.storageOrderKeySuffix != null
        ? `-${config.storageOrderKeySuffix}`
        : "";
    return `${prefix}order-id-${config.clientId}-${scope}${suffix}`;
}
function getKeyForGuestToken(clientCredentials) {
    const scope = (clientCredentials.scope ?? "undefined").replace(" ", "-");
    return `${prefix}token-${clientCredentials.clientId}-${scope}`;
}
function getKeyForCustomerToken(clientCredentials) {
    const scope = (clientCredentials.scope ?? "undefined").replace(" ", "-");
    return `${prefix}session-${clientCredentials.clientId}-${scope}`;
}

function setToken(key, value, expires) {
    api.set(key, JSON.stringify(value), { expires });
}
function clearToken(key) {
    api.remove(key);
}
function getToken(key) {
    const cookie = api.get(key);
    if (cookie == null) {
        return undefined;
    }
    try {
        return JSON.parse(cookie);
    }
    catch (e) {
        return undefined;
    }
}
async function revokeToken(clientCredentials, accessToken) {
    const res = await A$1({
        clientId: clientCredentials.clientId,
        token: accessToken,
    });
    return res.errors == null;
}
async function getSalesChannelToken(clientCredentials) {
    return await x$1("client_credentials", {
        clientId: clientCredentials.clientId,
        scope: clientCredentials.scope,
        domain: clientCredentials.domain,
    }).then((res) => (res.errors == null ? res : null));
}
const getCustomerInfoFromUrl = () => {
    const url = new URL(window.location.href);
    const { searchParams } = url;
    const accessToken = searchParams.get("accessToken") ?? undefined;
    const scope = searchParams.get("scope") ?? undefined;
    searchParams.delete("accessToken");
    searchParams.delete("scope");
    window.history.replaceState({}, "", url.toString());
    return {
        accessToken,
        scope,
    };
};
async function readCustomerToken(clientCredentials) {
    const cookieName = getKeyForCustomerToken(clientCredentials);
    const cookieValue = getToken(cookieName) ?? null;
    // const searchParams = new window.URL(window.location.href).searchParams
    // const accessToken = searchParams.get('accessToken')
    // const scope = searchParams.get('scope') ?? clientCredentials.scope
    const { accessToken, scope = clientCredentials.scope } = getCustomerInfoFromUrl();
    if (accessToken == null) {
        return cookieValue;
    }
    const jwt = i(accessToken);
    if (S$1(jwt.payload) && jwt.payload.owner != null) {
        const token = {
            type: "customer",
            customerId: jwt.payload.owner.id,
            accessToken,
            scope,
        };
        setToken(cookieName, token, new Date(jwt.payload.exp * 1000));
        return token;
    }
    return cookieValue;
}
async function readGuestToken(clientCredentials) {
    const cookieName = getKeyForGuestToken(clientCredentials);
    const value = getToken(cookieName);
    if (value !== undefined) {
        return value;
    }
    const salesChannelToken = await getSalesChannelToken(clientCredentials).catch((error) => {
        throw new Error(`Cannot get a sales channel token. ${error.body.error}. ${error.body.error_description}`);
    });
    if (salesChannelToken == null) {
        throw new Error("Unable to get a valid sales channel token.");
    }
    const { accessToken, expires } = salesChannelToken;
    const token = {
        type: "guest",
        accessToken,
        scope: clientCredentials.scope,
    };
    setToken(cookieName, token, expires);
    return token;
}
const getAccessToken = memoize$1(async (clientCredentials) => {
    let token = await readCustomerToken(clientCredentials);
    if (token == null) {
        token = await readGuestToken(clientCredentials);
    }
    fireEvent("cl-identity-gettoken", [], token);
    return token;
}, (clientCredentials) => JSON.stringify(clientCredentials));
async function createClient(config) {
    const token = await getAccessToken(config);
    return ep({
        accessToken: token.accessToken,
        domain: config.domain,
    });
}
async function logout() {
    const config = getConfig();
    const token = await getAccessToken(config);
    if (token.type === "customer") {
        const cookieName = getKeyForCustomerToken(config);
        clearToken(cookieName);
        await revokeToken(config, token.accessToken);
        getAccessToken.cache.clear?.();
        // await getAccessToken(config)
    }
}

const documentationLink = "Read more here: https://commercelayer.github.io/drop-in.js/?path=/docs/getting-started--docs";
const defaultLanguageCode = "en";
function getConfig() {
    if (!("commercelayerConfig" in window)) {
        throw new Error(`"window.commercelayerConfig" is required.\n${documentationLink}\n`);
    }
    const commercelayerConfig = window.commercelayerConfig;
    if (typeof commercelayerConfig.clientId !== "string") {
        throw new Error(`"window.commercelayerConfig.clientId" is required.\n${documentationLink}\n`);
    }
    if (typeof commercelayerConfig.scope !== "string") {
        throw new Error(`"window.commercelayerConfig.scope" is required.\n${documentationLink}\n`);
    }
    if (![undefined, "none", "all"].includes(commercelayerConfig.debug)) {
        throw new Error(`"window.commercelayerConfig.debug" should one of 'none' (default) or 'all'.\n${documentationLink}\n`);
    }
    if (typeof commercelayerConfig.domain !== "string" ||
        commercelayerConfig.domain === "") {
        commercelayerConfig.domain = "commercelayer.io";
    }
    const debug = commercelayerConfig.debug ?? "none";
    // START-BLOCK // TODO: Remove deprecated properties in the next major version.
    commercelayerConfig.defaultAttributes ??= {};
    commercelayerConfig.defaultAttributes.orders ??= {};
    commercelayerConfig.defaultAttributes.orders.language_code ??=
        commercelayerConfig.languageCode ?? defaultLanguageCode;
    commercelayerConfig.defaultAttributes.orders.return_url ??=
        commercelayerConfig.orderReturnUrl;
    // END-BLOCK
    return {
        ...commercelayerConfig,
        debug,
    };
}
const getOrganization = memoize(async () => {
    const config = getConfig();
    const client = await createClient(config);
    return await client.organization.retrieve({
        fields: {
            organizations: ["config"],
        },
    });
});
async function getOrganizationConfig(params) {
    const config = getConfig();
    const { accessToken } = await getAccessToken(config);
    const jwt = i(accessToken);
    if (!("organization" in jwt.payload)) {
        throw new Error("The access token does not contain the organization information.");
    }
    const organization = await getOrganization();
    const domainPrefix = config.domain === "commercelayer.co" ? ".stg" : "";
    const appEndpoint = `https://:slug${domainPrefix}.commercelayer.app`;
    const defaultConfig = {
        mfe: {
            default: {
                links: {
                    cart: `${appEndpoint}/cart/:order_id?accessToken=:access_token`,
                    checkout: `${appEndpoint}/checkout/:order_id?accessToken=:access_token`,
                    my_account: `${appEndpoint}/my-account?accessToken=:access_token`,
                    identity: `${appEndpoint}/identity`,
                },
            },
        },
    };
    const mergeConfigOptions = {
        jsonConfig: merge({}, defaultConfig, organization.config),
        market: S$1(jwt.payload) && jwt.payload.market?.id[0] != null
            ? `market:id:${jwt.payload.market.id[0]}`
            : undefined,
        params: {
            ...params,
            accessToken,
            slug: jwt.payload.organization.slug,
            lang: config.defaultAttributes?.orders?.language_code ?? defaultLanguageCode,
        },
    };
    return I$1(mergeConfigOptions);
}

export { require_getNative as A, require_root as B, require_Map as C, require_baseGetTag as D, require_toSource as E, require_Stack as F, requireIsBuffer as G, requireIsTypedArray as H, requireIsObjectLike as I, requireIsObject as J, requireMemoize as K, requireIsArguments as L, require_isIndex as M, requireIsLength as N, requireIdentity as O, getDefaultExportFromCjs as P, memoize$1 as a, getAccessToken as b, createClient as c, api as d, getKeyForCart as e, fireEvent as f, getConfig as g, getOrganizationConfig as h, i, chunk as j, debounce as k, listenTo as l, memoize as m, logout as n, require_MapCache as o, pDebounce as p, require_Symbol as q, requireIsSymbol as r, require_Uint8Array as s, requireEq as t, uniq as u, requireIsArray as v, require_overArg as w, require_isPrototype as x, require_arrayLikeKeys as y, requireIsArrayLike as z };
